@@ -32,60 +32,24 @@ namespace Model
   class ProgressUpdateStreamSummary
   {
   public:
-    AWS_MIGRATIONHUB_API ProgressUpdateStreamSummary();
+    AWS_MIGRATIONHUB_API ProgressUpdateStreamSummary() = default;
     AWS_MIGRATIONHUB_API ProgressUpdateStreamSummary(Aws::Utils::Json::JsonView jsonValue);
     AWS_MIGRATIONHUB_API ProgressUpdateStreamSummary& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MIGRATIONHUB_API Aws::Utils::Json::JsonValue Jsonize() const;
 
 
+    ///@{
     /**
      * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
      * field.</i> </p>
      */
-    inline const Aws::String& GetProgressUpdateStreamName() const{ return m_progressUpdateStreamName; }
-
-    /**
-     * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
-     * field.</i> </p>
-     */
+    inline const Aws::String& GetProgressUpdateStreamName() const { return m_progressUpdateStreamName; }
     inline bool ProgressUpdateStreamNameHasBeenSet() const { return m_progressUpdateStreamNameHasBeenSet; }
-
-    /**
-     * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
-     * field.</i> </p>
-     */
-    inline void SetProgressUpdateStreamName(const Aws::String& value) { m_progressUpdateStreamNameHasBeenSet = true; m_progressUpdateStreamName = value; }
-
-    /**
-     * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
-     * field.</i> </p>
-     */
-    inline void SetProgressUpdateStreamName(Aws::String&& value) { m_progressUpdateStreamNameHasBeenSet = true; m_progressUpdateStreamName = std::move(value); }
-
-    /**
-     * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
-     * field.</i> </p>
-     */
-    inline void SetProgressUpdateStreamName(const char* value) { m_progressUpdateStreamNameHasBeenSet = true; m_progressUpdateStreamName.assign(value); }
-
-    /**
-     * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
-     * field.</i> </p>
-     */
-    inline ProgressUpdateStreamSummary& WithProgressUpdateStreamName(const Aws::String& value) { SetProgressUpdateStreamName(value); return *this;}
-
-    /**
-     * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
-     * field.</i> </p>
-     */
-    inline ProgressUpdateStreamSummary& WithProgressUpdateStreamName(Aws::String&& value) { SetProgressUpdateStreamName(std::move(value)); return *this;}
-
-    /**
-     * <p>The name of the ProgressUpdateStream. <i>Do not store personal data in this
-     * field.</i> </p>
-     */
-    inline ProgressUpdateStreamSummary& WithProgressUpdateStreamName(const char* value) { SetProgressUpdateStreamName(value); return *this;}
-
+    template<typename ProgressUpdateStreamNameT = Aws::String>
+    void SetProgressUpdateStreamName(ProgressUpdateStreamNameT&& value) { m_progressUpdateStreamNameHasBeenSet = true; m_progressUpdateStreamName = std::forward<ProgressUpdateStreamNameT>(value); }
+    template<typename ProgressUpdateStreamNameT = Aws::String>
+    ProgressUpdateStreamSummary& WithProgressUpdateStreamName(ProgressUpdateStreamNameT&& value) { SetProgressUpdateStreamName(std::forward<ProgressUpdateStreamNameT>(value)); return *this;}
+    ///@}
   private:
 
     Aws::String m_progressUpdateStreamName;
