@@ -7,10 +7,12 @@
 
 /* Generic header includes */
 #include <aws/appmesh/AppMeshErrors.h>
+#include <aws/core/client/GenericClientConfiguration.h>
 #include <aws/core/client/AWSError.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/client/AsyncCallerContext.h>
 #include <aws/core/http/HttpTypes.h>
+#include <aws/appmesh/AppMeshEndpointProvider.h>
 #include <future>
 #include <functional>
 /* End of generic header includes */
@@ -54,6 +56,7 @@
 #include <aws/appmesh/model/UpdateVirtualNodeResult.h>
 #include <aws/appmesh/model/UpdateVirtualRouterResult.h>
 #include <aws/appmesh/model/UpdateVirtualServiceResult.h>
+#include <aws/appmesh/model/ListMeshesRequest.h>
 /* End of service model headers required in AppMeshClient header */
 
 namespace Aws
@@ -87,6 +90,10 @@ namespace Aws
 
   namespace AppMesh
   {
+    using AppMeshClientConfiguration = Aws::Client::GenericClientConfiguration;
+    using AppMeshEndpointProviderBase = Aws::AppMesh::Endpoint::AppMeshEndpointProviderBase;
+    using AppMeshEndpointProvider = Aws::AppMesh::Endpoint::AppMeshEndpointProvider;
+
     namespace Model
     {
       /* Service model forward declarations required in AppMeshClient header */
