@@ -27,7 +27,7 @@ namespace Model
   class ListGraphqlApisRequest : public AppSyncRequest
   {
   public:
-    AWS_APPSYNC_API ListGraphqlApisRequest();
+    AWS_APPSYNC_API ListGraphqlApisRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -45,21 +45,19 @@ namespace Model
      * <p>An identifier that was returned from the previous call to this operation,
      * which you can use to return the next set of items in the list.</p>
      */
-    inline const Aws::String& GetNextToken() const{ return m_nextToken; }
+    inline const Aws::String& GetNextToken() const { return m_nextToken; }
     inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }
-    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }
-    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }
-    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }
-    inline ListGraphqlApisRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}
-    inline ListGraphqlApisRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}
-    inline ListGraphqlApisRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}
+    template<typename NextTokenT = Aws::String>
+    void SetNextToken(NextTokenT&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::forward<NextTokenT>(value); }
+    template<typename NextTokenT = Aws::String>
+    ListGraphqlApisRequest& WithNextToken(NextTokenT&& value) { SetNextToken(std::forward<NextTokenT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The maximum number of results that you want the request to return.</p>
      */
-    inline int GetMaxResults() const{ return m_maxResults; }
+    inline int GetMaxResults() const { return m_maxResults; }
     inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }
     inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }
     inline ListGraphqlApisRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}
@@ -70,37 +68,33 @@ namespace Model
      * <p>The value that indicates whether the GraphQL API is a standard API
      * (<code>GRAPHQL</code>) or merged API (<code>MERGED</code>).</p>
      */
-    inline const GraphQLApiType& GetApiType() const{ return m_apiType; }
+    inline GraphQLApiType GetApiType() const { return m_apiType; }
     inline bool ApiTypeHasBeenSet() const { return m_apiTypeHasBeenSet; }
-    inline void SetApiType(const GraphQLApiType& value) { m_apiTypeHasBeenSet = true; m_apiType = value; }
-    inline void SetApiType(GraphQLApiType&& value) { m_apiTypeHasBeenSet = true; m_apiType = std::move(value); }
-    inline ListGraphqlApisRequest& WithApiType(const GraphQLApiType& value) { SetApiType(value); return *this;}
-    inline ListGraphqlApisRequest& WithApiType(GraphQLApiType&& value) { SetApiType(std::move(value)); return *this;}
+    inline void SetApiType(GraphQLApiType value) { m_apiTypeHasBeenSet = true; m_apiType = value; }
+    inline ListGraphqlApisRequest& WithApiType(GraphQLApiType value) { SetApiType(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The account owner of the GraphQL API.</p>
      */
-    inline const Ownership& GetOwner() const{ return m_owner; }
+    inline Ownership GetOwner() const { return m_owner; }
     inline bool OwnerHasBeenSet() const { return m_ownerHasBeenSet; }
-    inline void SetOwner(const Ownership& value) { m_ownerHasBeenSet = true; m_owner = value; }
-    inline void SetOwner(Ownership&& value) { m_ownerHasBeenSet = true; m_owner = std::move(value); }
-    inline ListGraphqlApisRequest& WithOwner(const Ownership& value) { SetOwner(value); return *this;}
-    inline ListGraphqlApisRequest& WithOwner(Ownership&& value) { SetOwner(std::move(value)); return *this;}
+    inline void SetOwner(Ownership value) { m_ownerHasBeenSet = true; m_owner = value; }
+    inline ListGraphqlApisRequest& WithOwner(Ownership value) { SetOwner(value); return *this;}
     ///@}
   private:
 
     Aws::String m_nextToken;
     bool m_nextTokenHasBeenSet = false;
 
-    int m_maxResults;
+    int m_maxResults{0};
     bool m_maxResultsHasBeenSet = false;
 
-    GraphQLApiType m_apiType;
+    GraphQLApiType m_apiType{GraphQLApiType::NOT_SET};
     bool m_apiTypeHasBeenSet = false;
 
-    Ownership m_owner;
+    Ownership m_owner{Ownership::NOT_SET};
     bool m_ownerHasBeenSet = false;
   };
 
