@@ -16,10 +16,10 @@ namespace Model
 
   /**
    */
-  class AWS_AUDITMANAGER_API DeregisterAccountRequest : public AuditManagerRequest
+  class DeregisterAccountRequest : public AuditManagerRequest
   {
   public:
-    DeregisterAccountRequest();
+    AWS_AUDITMANAGER_API DeregisterAccountRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -27,7 +27,7 @@ namespace Model
     // so we can not get operation's name from response.
     inline virtual const char* GetServiceRequestName() const override { return "DeregisterAccount"; }
 
-    Aws::String SerializePayload() const override;
+    AWS_AUDITMANAGER_API Aws::String SerializePayload() const override;
 
   };
 
