@@ -193,6 +193,19 @@ namespace Model
     RecoveryPointByBackupVault& WithCreationDate(CreationDateT&& value) { SetCreationDate(std::forward<CreationDateT>(value)); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The date and time when the backup job that created this recovery point was
+     * initiated, in Unix format and Coordinated Universal Time (UTC).</p>
+     */
+    inline const Aws::Utils::DateTime& GetInitiationDate() const { return m_initiationDate; }
+    inline bool InitiationDateHasBeenSet() const { return m_initiationDateHasBeenSet; }
+    template<typename InitiationDateT = Aws::Utils::DateTime>
+    void SetInitiationDate(InitiationDateT&& value) { m_initiationDateHasBeenSet = true; m_initiationDate = std::forward<InitiationDateT>(value); }
+    template<typename InitiationDateT = Aws::Utils::DateTime>
+    RecoveryPointByBackupVault& WithInitiationDate(InitiationDateT&& value) { SetInitiationDate(std::forward<InitiationDateT>(value)); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>The date and time a job to restore a recovery point is completed, in Unix
@@ -416,6 +429,9 @@ namespace Model
     Aws::Utils::DateTime m_creationDate{};
     bool m_creationDateHasBeenSet = false;
 
+    Aws::Utils::DateTime m_initiationDate{};
+    bool m_initiationDateHasBeenSet = false;
+
     Aws::Utils::DateTime m_completionDate{};
     bool m_completionDateHasBeenSet = false;
 
