@@ -5,19 +5,13 @@
 
 #pragma once
 #include <aws/bedrock-agent-runtime/BedrockAgentRuntime_EXPORTS.h>
-#include <aws/bedrock-agent-runtime/model/AccessDeniedException.h>
 #include <aws/bedrock-agent-runtime/model/BadGatewayException.h>
-#include <aws/bedrock-agent-runtime/model/ConflictException.h>
 #include <aws/bedrock-agent-runtime/model/DependencyFailedException.h>
 #include <aws/bedrock-agent-runtime/model/FlowCompletionEvent.h>
 #include <aws/bedrock-agent-runtime/model/FlowMultiTurnInputRequestEvent.h>
 #include <aws/bedrock-agent-runtime/model/FlowOutputEvent.h>
 #include <aws/bedrock-agent-runtime/model/FlowTraceEvent.h>
 #include <aws/bedrock-agent-runtime/model/InternalServerException.h>
-#include <aws/bedrock-agent-runtime/model/ResourceNotFoundException.h>
-#include <aws/bedrock-agent-runtime/model/ServiceQuotaExceededException.h>
-#include <aws/bedrock-agent-runtime/model/ThrottlingException.h>
-#include <aws/bedrock-agent-runtime/model/ValidationException.h>
 #include <utility>
 
 namespace Aws
@@ -54,11 +48,11 @@ namespace Model
      * <p>The request is denied because of missing access permissions. Check your
      * permissions and retry your request.</p>
      */
-    inline const AccessDeniedException& GetAccessDeniedException() const { return m_accessDeniedException; }
+    inline const BedrockAgentRuntimeError& GetAccessDeniedException() const { return m_accessDeniedException; }
     inline bool AccessDeniedExceptionHasBeenSet() const { return m_accessDeniedExceptionHasBeenSet; }
-    template<typename AccessDeniedExceptionT = AccessDeniedException>
+    template<typename AccessDeniedExceptionT = BedrockAgentRuntimeError>
     void SetAccessDeniedException(AccessDeniedExceptionT&& value) { m_accessDeniedExceptionHasBeenSet = true; m_accessDeniedException = std::forward<AccessDeniedExceptionT>(value); }
-    template<typename AccessDeniedExceptionT = AccessDeniedException>
+    template<typename AccessDeniedExceptionT = BedrockAgentRuntimeError>
     FlowResponseStream& WithAccessDeniedException(AccessDeniedExceptionT&& value) { SetAccessDeniedException(std::forward<AccessDeniedExceptionT>(value)); return *this;}
     ///@}
 
@@ -80,11 +74,11 @@ namespace Model
      * <p>There was a conflict performing an operation. Resolve the conflict and retry
      * your request.</p>
      */
-    inline const ConflictException& GetConflictException() const { return m_conflictException; }
+    inline const BedrockAgentRuntimeError& GetConflictException() const { return m_conflictException; }
     inline bool ConflictExceptionHasBeenSet() const { return m_conflictExceptionHasBeenSet; }
-    template<typename ConflictExceptionT = ConflictException>
+    template<typename ConflictExceptionT = BedrockAgentRuntimeError>
     void SetConflictException(ConflictExceptionT&& value) { m_conflictExceptionHasBeenSet = true; m_conflictException = std::forward<ConflictExceptionT>(value); }
-    template<typename ConflictExceptionT = ConflictException>
+    template<typename ConflictExceptionT = BedrockAgentRuntimeError>
     FlowResponseStream& WithConflictException(ConflictExceptionT&& value) { SetConflictException(std::forward<ConflictExceptionT>(value)); return *this;}
     ///@}
 
@@ -168,11 +162,11 @@ namespace Model
      * <p>The specified resource Amazon Resource Name (ARN) was not found. Check the
      * Amazon Resource Name (ARN) and try your request again.</p>
      */
-    inline const ResourceNotFoundException& GetResourceNotFoundException() const { return m_resourceNotFoundException; }
+    inline const BedrockAgentRuntimeError& GetResourceNotFoundException() const { return m_resourceNotFoundException; }
     inline bool ResourceNotFoundExceptionHasBeenSet() const { return m_resourceNotFoundExceptionHasBeenSet; }
-    template<typename ResourceNotFoundExceptionT = ResourceNotFoundException>
+    template<typename ResourceNotFoundExceptionT = BedrockAgentRuntimeError>
     void SetResourceNotFoundException(ResourceNotFoundExceptionT&& value) { m_resourceNotFoundExceptionHasBeenSet = true; m_resourceNotFoundException = std::forward<ResourceNotFoundExceptionT>(value); }
-    template<typename ResourceNotFoundExceptionT = ResourceNotFoundException>
+    template<typename ResourceNotFoundExceptionT = BedrockAgentRuntimeError>
     FlowResponseStream& WithResourceNotFoundException(ResourceNotFoundExceptionT&& value) { SetResourceNotFoundException(std::forward<ResourceNotFoundExceptionT>(value)); return *this;}
     ///@}
 
@@ -181,11 +175,11 @@ namespace Model
      * <p>The number of requests exceeds the service quota. Resubmit your request
      * later.</p>
      */
-    inline const ServiceQuotaExceededException& GetServiceQuotaExceededException() const { return m_serviceQuotaExceededException; }
+    inline const BedrockAgentRuntimeError& GetServiceQuotaExceededException() const { return m_serviceQuotaExceededException; }
     inline bool ServiceQuotaExceededExceptionHasBeenSet() const { return m_serviceQuotaExceededExceptionHasBeenSet; }
-    template<typename ServiceQuotaExceededExceptionT = ServiceQuotaExceededException>
+    template<typename ServiceQuotaExceededExceptionT = BedrockAgentRuntimeError>
     void SetServiceQuotaExceededException(ServiceQuotaExceededExceptionT&& value) { m_serviceQuotaExceededExceptionHasBeenSet = true; m_serviceQuotaExceededException = std::forward<ServiceQuotaExceededExceptionT>(value); }
-    template<typename ServiceQuotaExceededExceptionT = ServiceQuotaExceededException>
+    template<typename ServiceQuotaExceededExceptionT = BedrockAgentRuntimeError>
     FlowResponseStream& WithServiceQuotaExceededException(ServiceQuotaExceededExceptionT&& value) { SetServiceQuotaExceededException(std::forward<ServiceQuotaExceededExceptionT>(value)); return *this;}
     ///@}
 
@@ -193,11 +187,11 @@ namespace Model
     /**
      * <p>The number of requests exceeds the limit. Resubmit your request later.</p>
      */
-    inline const ThrottlingException& GetThrottlingException() const { return m_throttlingException; }
+    inline const BedrockAgentRuntimeError& GetThrottlingException() const { return m_throttlingException; }
     inline bool ThrottlingExceptionHasBeenSet() const { return m_throttlingExceptionHasBeenSet; }
-    template<typename ThrottlingExceptionT = ThrottlingException>
+    template<typename ThrottlingExceptionT = BedrockAgentRuntimeError>
     void SetThrottlingException(ThrottlingExceptionT&& value) { m_throttlingExceptionHasBeenSet = true; m_throttlingException = std::forward<ThrottlingExceptionT>(value); }
-    template<typename ThrottlingExceptionT = ThrottlingException>
+    template<typename ThrottlingExceptionT = BedrockAgentRuntimeError>
     FlowResponseStream& WithThrottlingException(ThrottlingExceptionT&& value) { SetThrottlingException(std::forward<ThrottlingExceptionT>(value)); return *this;}
     ///@}
 
@@ -206,22 +200,22 @@ namespace Model
      * <p>Input validation failed. Check your request parameters and retry the
      * request.</p>
      */
-    inline const ValidationException& GetValidationException() const { return m_validationException; }
+    inline const BedrockAgentRuntimeError& GetValidationException() const { return m_validationException; }
     inline bool ValidationExceptionHasBeenSet() const { return m_validationExceptionHasBeenSet; }
-    template<typename ValidationExceptionT = ValidationException>
+    template<typename ValidationExceptionT = BedrockAgentRuntimeError>
     void SetValidationException(ValidationExceptionT&& value) { m_validationExceptionHasBeenSet = true; m_validationException = std::forward<ValidationExceptionT>(value); }
-    template<typename ValidationExceptionT = ValidationException>
+    template<typename ValidationExceptionT = BedrockAgentRuntimeError>
     FlowResponseStream& WithValidationException(ValidationExceptionT&& value) { SetValidationException(std::forward<ValidationExceptionT>(value)); return *this;}
     ///@}
   private:
 
-    AccessDeniedException m_accessDeniedException;
+    BedrockAgentRuntimeError m_accessDeniedException;
     bool m_accessDeniedExceptionHasBeenSet = false;
 
     BadGatewayException m_badGatewayException;
     bool m_badGatewayExceptionHasBeenSet = false;
 
-    ConflictException m_conflictException;
+    BedrockAgentRuntimeError m_conflictException;
     bool m_conflictExceptionHasBeenSet = false;
 
     DependencyFailedException m_dependencyFailedException;
@@ -242,16 +236,16 @@ namespace Model
     InternalServerException m_internalServerException;
     bool m_internalServerExceptionHasBeenSet = false;
 
-    ResourceNotFoundException m_resourceNotFoundException;
+    BedrockAgentRuntimeError m_resourceNotFoundException;
     bool m_resourceNotFoundExceptionHasBeenSet = false;
 
-    ServiceQuotaExceededException m_serviceQuotaExceededException;
+    BedrockAgentRuntimeError m_serviceQuotaExceededException;
     bool m_serviceQuotaExceededExceptionHasBeenSet = false;
 
-    ThrottlingException m_throttlingException;
+    BedrockAgentRuntimeError m_throttlingException;
     bool m_throttlingExceptionHasBeenSet = false;
 
-    ValidationException m_validationException;
+    BedrockAgentRuntimeError m_validationException;
     bool m_validationExceptionHasBeenSet = false;
   };
 
