@@ -83,6 +83,17 @@ namespace Model
     inline void SetAction(GuardrailSensitiveInformationPolicyAction value) { m_actionHasBeenSet = true; m_action = value; }
     inline GuardrailRegexFilter& WithAction(GuardrailSensitiveInformationPolicyAction value) { SetAction(value); return *this;}
     ///@}
+
+    ///@{
+    /**
+     * <p>Indicates whether custom regex entities that breach the guardrail
+     * configuration are detected.</p>
+     */
+    inline bool GetDetected() const { return m_detected; }
+    inline bool DetectedHasBeenSet() const { return m_detectedHasBeenSet; }
+    inline void SetDetected(bool value) { m_detectedHasBeenSet = true; m_detected = value; }
+    inline GuardrailRegexFilter& WithDetected(bool value) { SetDetected(value); return *this;}
+    ///@}
   private:
 
     Aws::String m_name;
@@ -96,6 +107,9 @@ namespace Model
 
     GuardrailSensitiveInformationPolicyAction m_action{GuardrailSensitiveInformationPolicyAction::NOT_SET};
     bool m_actionHasBeenSet = false;
+
+    bool m_detected{false};
+    bool m_detectedHasBeenSet = false;
   };
 
 } // namespace Model
