@@ -31,7 +31,7 @@ namespace Model
   class Parameter
   {
   public:
-    AWS_CLOUDFORMATION_API Parameter();
+    AWS_CLOUDFORMATION_API Parameter() = default;
     AWS_CLOUDFORMATION_API Parameter(const Aws::Utils::Xml::XmlNode& xmlNode);
     AWS_CLOUDFORMATION_API Parameter& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);
 
@@ -45,28 +45,24 @@ namespace Model
      * for a particular parameter, CloudFormation uses the default value that's
      * specified in your template.</p>
      */
-    inline const Aws::String& GetParameterKey() const{ return m_parameterKey; }
+    inline const Aws::String& GetParameterKey() const { return m_parameterKey; }
     inline bool ParameterKeyHasBeenSet() const { return m_parameterKeyHasBeenSet; }
-    inline void SetParameterKey(const Aws::String& value) { m_parameterKeyHasBeenSet = true; m_parameterKey = value; }
-    inline void SetParameterKey(Aws::String&& value) { m_parameterKeyHasBeenSet = true; m_parameterKey = std::move(value); }
-    inline void SetParameterKey(const char* value) { m_parameterKeyHasBeenSet = true; m_parameterKey.assign(value); }
-    inline Parameter& WithParameterKey(const Aws::String& value) { SetParameterKey(value); return *this;}
-    inline Parameter& WithParameterKey(Aws::String&& value) { SetParameterKey(std::move(value)); return *this;}
-    inline Parameter& WithParameterKey(const char* value) { SetParameterKey(value); return *this;}
+    template<typename ParameterKeyT = Aws::String>
+    void SetParameterKey(ParameterKeyT&& value) { m_parameterKeyHasBeenSet = true; m_parameterKey = std::forward<ParameterKeyT>(value); }
+    template<typename ParameterKeyT = Aws::String>
+    Parameter& WithParameterKey(ParameterKeyT&& value) { SetParameterKey(std::forward<ParameterKeyT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The input value associated with the parameter.</p>
      */
-    inline const Aws::String& GetParameterValue() const{ return m_parameterValue; }
+    inline const Aws::String& GetParameterValue() const { return m_parameterValue; }
     inline bool ParameterValueHasBeenSet() const { return m_parameterValueHasBeenSet; }
-    inline void SetParameterValue(const Aws::String& value) { m_parameterValueHasBeenSet = true; m_parameterValue = value; }
-    inline void SetParameterValue(Aws::String&& value) { m_parameterValueHasBeenSet = true; m_parameterValue = std::move(value); }
-    inline void SetParameterValue(const char* value) { m_parameterValueHasBeenSet = true; m_parameterValue.assign(value); }
-    inline Parameter& WithParameterValue(const Aws::String& value) { SetParameterValue(value); return *this;}
-    inline Parameter& WithParameterValue(Aws::String&& value) { SetParameterValue(std::move(value)); return *this;}
-    inline Parameter& WithParameterValue(const char* value) { SetParameterValue(value); return *this;}
+    template<typename ParameterValueT = Aws::String>
+    void SetParameterValue(ParameterValueT&& value) { m_parameterValueHasBeenSet = true; m_parameterValue = std::forward<ParameterValueT>(value); }
+    template<typename ParameterValueT = Aws::String>
+    Parameter& WithParameterValue(ParameterValueT&& value) { SetParameterValue(std::forward<ParameterValueT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -75,7 +71,7 @@ namespace Model
      * using for a given parameter key. If you specify <code>true</code>, do not
      * specify a parameter value.</p>
      */
-    inline bool GetUsePreviousValue() const{ return m_usePreviousValue; }
+    inline bool GetUsePreviousValue() const { return m_usePreviousValue; }
     inline bool UsePreviousValueHasBeenSet() const { return m_usePreviousValueHasBeenSet; }
     inline void SetUsePreviousValue(bool value) { m_usePreviousValueHasBeenSet = true; m_usePreviousValue = value; }
     inline Parameter& WithUsePreviousValue(bool value) { SetUsePreviousValue(value); return *this;}
@@ -90,14 +86,12 @@ namespace Model
      * existing resources at runtime with CloudFormation-supplied parameter types</a>
      * in the <i>CloudFormation User Guide</i>.</p>
      */
-    inline const Aws::String& GetResolvedValue() const{ return m_resolvedValue; }
+    inline const Aws::String& GetResolvedValue() const { return m_resolvedValue; }
     inline bool ResolvedValueHasBeenSet() const { return m_resolvedValueHasBeenSet; }
-    inline void SetResolvedValue(const Aws::String& value) { m_resolvedValueHasBeenSet = true; m_resolvedValue = value; }
-    inline void SetResolvedValue(Aws::String&& value) { m_resolvedValueHasBeenSet = true; m_resolvedValue = std::move(value); }
-    inline void SetResolvedValue(const char* value) { m_resolvedValueHasBeenSet = true; m_resolvedValue.assign(value); }
-    inline Parameter& WithResolvedValue(const Aws::String& value) { SetResolvedValue(value); return *this;}
-    inline Parameter& WithResolvedValue(Aws::String&& value) { SetResolvedValue(std::move(value)); return *this;}
-    inline Parameter& WithResolvedValue(const char* value) { SetResolvedValue(value); return *this;}
+    template<typename ResolvedValueT = Aws::String>
+    void SetResolvedValue(ResolvedValueT&& value) { m_resolvedValueHasBeenSet = true; m_resolvedValue = std::forward<ResolvedValueT>(value); }
+    template<typename ResolvedValueT = Aws::String>
+    Parameter& WithResolvedValue(ResolvedValueT&& value) { SetResolvedValue(std::forward<ResolvedValueT>(value)); return *this;}
     ///@}
   private:
 
@@ -107,7 +101,7 @@ namespace Model
     Aws::String m_parameterValue;
     bool m_parameterValueHasBeenSet = false;
 
-    bool m_usePreviousValue;
+    bool m_usePreviousValue{false};
     bool m_usePreviousValueHasBeenSet = false;
 
     Aws::String m_resolvedValue;
