@@ -39,7 +39,7 @@ namespace Model
   class QueryStringCacheKeys
   {
   public:
-    AWS_CLOUDFRONT_API QueryStringCacheKeys();
+    AWS_CLOUDFRONT_API QueryStringCacheKeys() = default;
     AWS_CLOUDFRONT_API QueryStringCacheKeys(const Aws::Utils::Xml::XmlNode& xmlNode);
     AWS_CLOUDFRONT_API QueryStringCacheKeys& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);
 
@@ -51,7 +51,7 @@ namespace Model
      * <p>The number of <code>whitelisted</code> query string parameters for a cache
      * behavior.</p>
      */
-    inline int GetQuantity() const{ return m_quantity; }
+    inline int GetQuantity() const { return m_quantity; }
     inline bool QuantityHasBeenSet() const { return m_quantityHasBeenSet; }
     inline void SetQuantity(int value) { m_quantityHasBeenSet = true; m_quantity = value; }
     inline QueryStringCacheKeys& WithQuantity(int value) { SetQuantity(value); return *this;}
@@ -63,19 +63,18 @@ namespace Model
      * use as a basis for caching for a cache behavior. If <code>Quantity</code> is 0,
      * you can omit <code>Items</code>.</p>
      */
-    inline const Aws::Vector<Aws::String>& GetItems() const{ return m_items; }
+    inline const Aws::Vector<Aws::String>& GetItems() const { return m_items; }
     inline bool ItemsHasBeenSet() const { return m_itemsHasBeenSet; }
-    inline void SetItems(const Aws::Vector<Aws::String>& value) { m_itemsHasBeenSet = true; m_items = value; }
-    inline void SetItems(Aws::Vector<Aws::String>&& value) { m_itemsHasBeenSet = true; m_items = std::move(value); }
-    inline QueryStringCacheKeys& WithItems(const Aws::Vector<Aws::String>& value) { SetItems(value); return *this;}
-    inline QueryStringCacheKeys& WithItems(Aws::Vector<Aws::String>&& value) { SetItems(std::move(value)); return *this;}
-    inline QueryStringCacheKeys& AddItems(const Aws::String& value) { m_itemsHasBeenSet = true; m_items.push_back(value); return *this; }
-    inline QueryStringCacheKeys& AddItems(Aws::String&& value) { m_itemsHasBeenSet = true; m_items.push_back(std::move(value)); return *this; }
-    inline QueryStringCacheKeys& AddItems(const char* value) { m_itemsHasBeenSet = true; m_items.push_back(value); return *this; }
+    template<typename ItemsT = Aws::Vector<Aws::String>>
+    void SetItems(ItemsT&& value) { m_itemsHasBeenSet = true; m_items = std::forward<ItemsT>(value); }
+    template<typename ItemsT = Aws::Vector<Aws::String>>
+    QueryStringCacheKeys& WithItems(ItemsT&& value) { SetItems(std::forward<ItemsT>(value)); return *this;}
+    template<typename ItemsT = Aws::String>
+    QueryStringCacheKeys& AddItems(ItemsT&& value) { m_itemsHasBeenSet = true; m_items.emplace_back(std::forward<ItemsT>(value)); return *this; }
     ///@}
   private:
 
-    int m_quantity;
+    int m_quantity{0};
     bool m_quantityHasBeenSet = false;
 
     Aws::Vector<Aws::String> m_items;
