@@ -32,7 +32,7 @@ namespace Model
   class SuggestionMatch
   {
   public:
-    AWS_CLOUDSEARCHDOMAIN_API SuggestionMatch();
+    AWS_CLOUDSEARCHDOMAIN_API SuggestionMatch() = default;
     AWS_CLOUDSEARCHDOMAIN_API SuggestionMatch(Aws::Utils::Json::JsonView jsonValue);
     AWS_CLOUDSEARCHDOMAIN_API SuggestionMatch& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_CLOUDSEARCHDOMAIN_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,21 +43,19 @@ namespace Model
      * <p>The string that matches the query string specified in the
      * <code>SuggestRequest</code>. </p>
      */
-    inline const Aws::String& GetSuggestion() const{ return m_suggestion; }
+    inline const Aws::String& GetSuggestion() const { return m_suggestion; }
     inline bool SuggestionHasBeenSet() const { return m_suggestionHasBeenSet; }
-    inline void SetSuggestion(const Aws::String& value) { m_suggestionHasBeenSet = true; m_suggestion = value; }
-    inline void SetSuggestion(Aws::String&& value) { m_suggestionHasBeenSet = true; m_suggestion = std::move(value); }
-    inline void SetSuggestion(const char* value) { m_suggestionHasBeenSet = true; m_suggestion.assign(value); }
-    inline SuggestionMatch& WithSuggestion(const Aws::String& value) { SetSuggestion(value); return *this;}
-    inline SuggestionMatch& WithSuggestion(Aws::String&& value) { SetSuggestion(std::move(value)); return *this;}
-    inline SuggestionMatch& WithSuggestion(const char* value) { SetSuggestion(value); return *this;}
+    template<typename SuggestionT = Aws::String>
+    void SetSuggestion(SuggestionT&& value) { m_suggestionHasBeenSet = true; m_suggestion = std::forward<SuggestionT>(value); }
+    template<typename SuggestionT = Aws::String>
+    SuggestionMatch& WithSuggestion(SuggestionT&& value) { SetSuggestion(std::forward<SuggestionT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The relevance score of a suggested match.</p>
      */
-    inline long long GetScore() const{ return m_score; }
+    inline long long GetScore() const { return m_score; }
     inline bool ScoreHasBeenSet() const { return m_scoreHasBeenSet; }
     inline void SetScore(long long value) { m_scoreHasBeenSet = true; m_score = value; }
     inline SuggestionMatch& WithScore(long long value) { SetScore(value); return *this;}
@@ -67,21 +65,19 @@ namespace Model
     /**
      * <p>The document ID of the suggested document.</p>
      */
-    inline const Aws::String& GetId() const{ return m_id; }
+    inline const Aws::String& GetId() const { return m_id; }
     inline bool IdHasBeenSet() const { return m_idHasBeenSet; }
-    inline void SetId(const Aws::String& value) { m_idHasBeenSet = true; m_id = value; }
-    inline void SetId(Aws::String&& value) { m_idHasBeenSet = true; m_id = std::move(value); }
-    inline void SetId(const char* value) { m_idHasBeenSet = true; m_id.assign(value); }
-    inline SuggestionMatch& WithId(const Aws::String& value) { SetId(value); return *this;}
-    inline SuggestionMatch& WithId(Aws::String&& value) { SetId(std::move(value)); return *this;}
-    inline SuggestionMatch& WithId(const char* value) { SetId(value); return *this;}
+    template<typename IdT = Aws::String>
+    void SetId(IdT&& value) { m_idHasBeenSet = true; m_id = std::forward<IdT>(value); }
+    template<typename IdT = Aws::String>
+    SuggestionMatch& WithId(IdT&& value) { SetId(std::forward<IdT>(value)); return *this;}
     ///@}
   private:
 
     Aws::String m_suggestion;
     bool m_suggestionHasBeenSet = false;
 
-    long long m_score;
+    long long m_score{0};
     bool m_scoreHasBeenSet = false;
 
     Aws::String m_id;
