@@ -16,10 +16,10 @@ namespace Model
 
   /**
    */
-  class AWS_CODEBUILD_API ListSourceCredentialsRequest : public CodeBuildRequest
+  class ListSourceCredentialsRequest : public CodeBuildRequest
   {
   public:
-    ListSourceCredentialsRequest();
+    AWS_CODEBUILD_API ListSourceCredentialsRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -27,9 +27,9 @@ namespace Model
     // so we can not get operation's name from response.
     inline virtual const char* GetServiceRequestName() const override { return "ListSourceCredentials"; }
 
-    Aws::String SerializePayload() const override;
+    AWS_CODEBUILD_API Aws::String SerializePayload() const override;
 
-    Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;
+    AWS_CODEBUILD_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;
 
   };
 
