@@ -33,7 +33,7 @@ namespace Model
   class AccountTakeoverRiskConfigurationType
   {
   public:
-    AWS_COGNITOIDENTITYPROVIDER_API AccountTakeoverRiskConfigurationType();
+    AWS_COGNITOIDENTITYPROVIDER_API AccountTakeoverRiskConfigurationType() = default;
     AWS_COGNITOIDENTITYPROVIDER_API AccountTakeoverRiskConfigurationType(Aws::Utils::Json::JsonView jsonValue);
     AWS_COGNITOIDENTITYPROVIDER_API AccountTakeoverRiskConfigurationType& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_COGNITOIDENTITYPROVIDER_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -47,12 +47,12 @@ namespace Model
      * sends an email message using the method and template that you set with this data
      * type.</p>
      */
-    inline const NotifyConfigurationType& GetNotifyConfiguration() const{ return m_notifyConfiguration; }
+    inline const NotifyConfigurationType& GetNotifyConfiguration() const { return m_notifyConfiguration; }
     inline bool NotifyConfigurationHasBeenSet() const { return m_notifyConfigurationHasBeenSet; }
-    inline void SetNotifyConfiguration(const NotifyConfigurationType& value) { m_notifyConfigurationHasBeenSet = true; m_notifyConfiguration = value; }
-    inline void SetNotifyConfiguration(NotifyConfigurationType&& value) { m_notifyConfigurationHasBeenSet = true; m_notifyConfiguration = std::move(value); }
-    inline AccountTakeoverRiskConfigurationType& WithNotifyConfiguration(const NotifyConfigurationType& value) { SetNotifyConfiguration(value); return *this;}
-    inline AccountTakeoverRiskConfigurationType& WithNotifyConfiguration(NotifyConfigurationType&& value) { SetNotifyConfiguration(std::move(value)); return *this;}
+    template<typename NotifyConfigurationT = NotifyConfigurationType>
+    void SetNotifyConfiguration(NotifyConfigurationT&& value) { m_notifyConfigurationHasBeenSet = true; m_notifyConfiguration = std::forward<NotifyConfigurationT>(value); }
+    template<typename NotifyConfigurationT = NotifyConfigurationType>
+    AccountTakeoverRiskConfigurationType& WithNotifyConfiguration(NotifyConfigurationT&& value) { SetNotifyConfiguration(std::forward<NotifyConfigurationT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -60,12 +60,12 @@ namespace Model
      * <p>A list of account-takeover actions for each level of risk that Amazon Cognito
      * might assess with threat protection.</p>
      */
-    inline const AccountTakeoverActionsType& GetActions() const{ return m_actions; }
+    inline const AccountTakeoverActionsType& GetActions() const { return m_actions; }
     inline bool ActionsHasBeenSet() const { return m_actionsHasBeenSet; }
-    inline void SetActions(const AccountTakeoverActionsType& value) { m_actionsHasBeenSet = true; m_actions = value; }
-    inline void SetActions(AccountTakeoverActionsType&& value) { m_actionsHasBeenSet = true; m_actions = std::move(value); }
-    inline AccountTakeoverRiskConfigurationType& WithActions(const AccountTakeoverActionsType& value) { SetActions(value); return *this;}
-    inline AccountTakeoverRiskConfigurationType& WithActions(AccountTakeoverActionsType&& value) { SetActions(std::move(value)); return *this;}
+    template<typename ActionsT = AccountTakeoverActionsType>
+    void SetActions(ActionsT&& value) { m_actionsHasBeenSet = true; m_actions = std::forward<ActionsT>(value); }
+    template<typename ActionsT = AccountTakeoverActionsType>
+    AccountTakeoverRiskConfigurationType& WithActions(ActionsT&& value) { SetActions(std::forward<ActionsT>(value)); return *this;}
     ///@}
   private:
 
