@@ -24,7 +24,7 @@ namespace Model
   class GetConnectInstanceConfigRequest : public ConnectCampaignsRequest
   {
   public:
-    AWS_CONNECTCAMPAIGNS_API GetConnectInstanceConfigRequest();
+    AWS_CONNECTCAMPAIGNS_API GetConnectInstanceConfigRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -37,14 +37,12 @@ namespace Model
 
     ///@{
     
-    inline const Aws::String& GetConnectInstanceId() const{ return m_connectInstanceId; }
+    inline const Aws::String& GetConnectInstanceId() const { return m_connectInstanceId; }
     inline bool ConnectInstanceIdHasBeenSet() const { return m_connectInstanceIdHasBeenSet; }
-    inline void SetConnectInstanceId(const Aws::String& value) { m_connectInstanceIdHasBeenSet = true; m_connectInstanceId = value; }
-    inline void SetConnectInstanceId(Aws::String&& value) { m_connectInstanceIdHasBeenSet = true; m_connectInstanceId = std::move(value); }
-    inline void SetConnectInstanceId(const char* value) { m_connectInstanceIdHasBeenSet = true; m_connectInstanceId.assign(value); }
-    inline GetConnectInstanceConfigRequest& WithConnectInstanceId(const Aws::String& value) { SetConnectInstanceId(value); return *this;}
-    inline GetConnectInstanceConfigRequest& WithConnectInstanceId(Aws::String&& value) { SetConnectInstanceId(std::move(value)); return *this;}
-    inline GetConnectInstanceConfigRequest& WithConnectInstanceId(const char* value) { SetConnectInstanceId(value); return *this;}
+    template<typename ConnectInstanceIdT = Aws::String>
+    void SetConnectInstanceId(ConnectInstanceIdT&& value) { m_connectInstanceIdHasBeenSet = true; m_connectInstanceId = std::forward<ConnectInstanceIdT>(value); }
+    template<typename ConnectInstanceIdT = Aws::String>
+    GetConnectInstanceConfigRequest& WithConnectInstanceId(ConnectInstanceIdT&& value) { SetConnectInstanceId(std::forward<ConnectInstanceIdT>(value)); return *this;}
     ///@}
   private:
 
