@@ -101,8 +101,8 @@ namespace Model
     Aws::String m_content;
     bool m_contentHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
 
     Aws::String m_connectionToken;
     bool m_connectionTokenHasBeenSet = false;
