@@ -22,7 +22,9 @@ namespace Model
     EXPORT_ASSET_TO_SIGNED_URL,
     EXPORT_REVISIONS_TO_S3,
     IMPORT_ASSETS_FROM_REDSHIFT_DATA_SHARES,
-    IMPORT_ASSET_FROM_API_GATEWAY_API
+    IMPORT_ASSET_FROM_API_GATEWAY_API,
+    CREATE_S3_DATA_ACCESS_FROM_S3_BUCKET,
+    IMPORT_ASSETS_FROM_LAKE_FORMATION_TAG_POLICY
   };
 
 namespace TypeMapper
