@@ -33,79 +33,39 @@ namespace Model
   class RecurringCharge
   {
   public:
-    AWS_DEVICEFARM_API RecurringCharge();
+    AWS_DEVICEFARM_API RecurringCharge() = default;
     AWS_DEVICEFARM_API RecurringCharge(Aws::Utils::Json::JsonView jsonValue);
     AWS_DEVICEFARM_API RecurringCharge& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_DEVICEFARM_API Aws::Utils::Json::JsonValue Jsonize() const;
 
 
+    ///@{
     /**
      * <p>The cost of the recurring charge.</p>
      */
-    inline const MonetaryAmount& GetCost() const{ return m_cost; }
-
-    /**
-     * <p>The cost of the recurring charge.</p>
-     */
+    inline const MonetaryAmount& GetCost() const { return m_cost; }
     inline bool CostHasBeenSet() const { return m_costHasBeenSet; }
+    template<typename CostT = MonetaryAmount>
+    void SetCost(CostT&& value) { m_costHasBeenSet = true; m_cost = std::forward<CostT>(value); }
+    template<typename CostT = MonetaryAmount>
+    RecurringCharge& WithCost(CostT&& value) { SetCost(std::forward<CostT>(value)); return *this;}
+    ///@}
 
-    /**
-     * <p>The cost of the recurring charge.</p>
-     */
-    inline void SetCost(const MonetaryAmount& value) { m_costHasBeenSet = true; m_cost = value; }
-
-    /**
-     * <p>The cost of the recurring charge.</p>
-     */
-    inline void SetCost(MonetaryAmount&& value) { m_costHasBeenSet = true; m_cost = std::move(value); }
-
-    /**
-     * <p>The cost of the recurring charge.</p>
-     */
-    inline RecurringCharge& WithCost(const MonetaryAmount& value) { SetCost(value); return *this;}
-
-    /**
-     * <p>The cost of the recurring charge.</p>
-     */
-    inline RecurringCharge& WithCost(MonetaryAmount&& value) { SetCost(std::move(value)); return *this;}
-
-
-    /**
-     * <p>The frequency in which charges recur.</p>
-     */
-    inline const RecurringChargeFrequency& GetFrequency() const{ return m_frequency; }
-
+    ///@{
     /**
      * <p>The frequency in which charges recur.</p>
      */
+    inline RecurringChargeFrequency GetFrequency() const { return m_frequency; }
     inline bool FrequencyHasBeenSet() const { return m_frequencyHasBeenSet; }
-
-    /**
-     * <p>The frequency in which charges recur.</p>
-     */
-    inline void SetFrequency(const RecurringChargeFrequency& value) { m_frequencyHasBeenSet = true; m_frequency = value; }
-
-    /**
-     * <p>The frequency in which charges recur.</p>
-     */
-    inline void SetFrequency(RecurringChargeFrequency&& value) { m_frequencyHasBeenSet = true; m_frequency = std::move(value); }
-
-    /**
-     * <p>The frequency in which charges recur.</p>
-     */
-    inline RecurringCharge& WithFrequency(const RecurringChargeFrequency& value) { SetFrequency(value); return *this;}
-
-    /**
-     * <p>The frequency in which charges recur.</p>
-     */
-    inline RecurringCharge& WithFrequency(RecurringChargeFrequency&& value) { SetFrequency(std::move(value)); return *this;}
-
+    inline void SetFrequency(RecurringChargeFrequency value) { m_frequencyHasBeenSet = true; m_frequency = value; }
+    inline RecurringCharge& WithFrequency(RecurringChargeFrequency value) { SetFrequency(value); return *this;}
+    ///@}
   private:
 
     MonetaryAmount m_cost;
     bool m_costHasBeenSet = false;
 
-    RecurringChargeFrequency m_frequency;
+    RecurringChargeFrequency m_frequency{RecurringChargeFrequency::NOT_SET};
     bool m_frequencyHasBeenSet = false;
   };
 
