@@ -16,10 +16,10 @@ namespace Model
 
   /**
    */
-  class AWS_DEVOPSGURU_API DescribeAccountHealthRequest : public DevOpsGuruRequest
+  class DescribeAccountHealthRequest : public DevOpsGuruRequest
   {
   public:
-    DescribeAccountHealthRequest();
+    AWS_DEVOPSGURU_API DescribeAccountHealthRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -27,7 +27,7 @@ namespace Model
     // so we can not get operation's name from response.
     inline virtual const char* GetServiceRequestName() const override { return "DescribeAccountHealth"; }
 
-    Aws::String SerializePayload() const override;
+    AWS_DEVOPSGURU_API Aws::String SerializePayload() const override;
 
   };
 
