@@ -31,7 +31,7 @@ namespace Model
   class HealthCheck
   {
   public:
-    AWS_ELASTICLOADBALANCING_API HealthCheck();
+    AWS_ELASTICLOADBALANCING_API HealthCheck() = default;
     AWS_ELASTICLOADBALANCING_API HealthCheck(const Aws::Utils::Xml::XmlNode& xmlNode);
     AWS_ELASTICLOADBALANCING_API HealthCheck& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);
 
@@ -54,14 +54,12 @@ namespace Model
      * the timeout period is considered unhealthy.</p> <p>The total length of the HTTP
      * ping target must be 1024 16-bit Unicode characters or less.</p>
      */
-    inline const Aws::String& GetTarget() const{ return m_target; }
+    inline const Aws::String& GetTarget() const { return m_target; }
     inline bool TargetHasBeenSet() const { return m_targetHasBeenSet; }
-    inline void SetTarget(const Aws::String& value) { m_targetHasBeenSet = true; m_target = value; }
-    inline void SetTarget(Aws::String&& value) { m_targetHasBeenSet = true; m_target = std::move(value); }
-    inline void SetTarget(const char* value) { m_targetHasBeenSet = true; m_target.assign(value); }
-    inline HealthCheck& WithTarget(const Aws::String& value) { SetTarget(value); return *this;}
-    inline HealthCheck& WithTarget(Aws::String&& value) { SetTarget(std::move(value)); return *this;}
-    inline HealthCheck& WithTarget(const char* value) { SetTarget(value); return *this;}
+    template<typename TargetT = Aws::String>
+    void SetTarget(TargetT&& value) { m_targetHasBeenSet = true; m_target = std::forward<TargetT>(value); }
+    template<typename TargetT = Aws::String>
+    HealthCheck& WithTarget(TargetT&& value) { SetTarget(std::forward<TargetT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -69,7 +67,7 @@ namespace Model
      * <p>The approximate interval, in seconds, between health checks of an individual
      * instance.</p>
      */
-    inline int GetInterval() const{ return m_interval; }
+    inline int GetInterval() const { return m_interval; }
     inline bool IntervalHasBeenSet() const { return m_intervalHasBeenSet; }
     inline void SetInterval(int value) { m_intervalHasBeenSet = true; m_interval = value; }
     inline HealthCheck& WithInterval(int value) { SetInterval(value); return *this;}
@@ -81,7 +79,7 @@ namespace Model
      * health check.</p> <p>This value must be less than the <code>Interval</code>
      * value.</p>
      */
-    inline int GetTimeout() const{ return m_timeout; }
+    inline int GetTimeout() const { return m_timeout; }
     inline bool TimeoutHasBeenSet() const { return m_timeoutHasBeenSet; }
     inline void SetTimeout(int value) { m_timeoutHasBeenSet = true; m_timeout = value; }
     inline HealthCheck& WithTimeout(int value) { SetTimeout(value); return *this;}
@@ -92,7 +90,7 @@ namespace Model
      * <p>The number of consecutive health check failures required before moving the
      * instance to the <code>Unhealthy</code> state.</p>
      */
-    inline int GetUnhealthyThreshold() const{ return m_unhealthyThreshold; }
+    inline int GetUnhealthyThreshold() const { return m_unhealthyThreshold; }
     inline bool UnhealthyThresholdHasBeenSet() const { return m_unhealthyThresholdHasBeenSet; }
     inline void SetUnhealthyThreshold(int value) { m_unhealthyThresholdHasBeenSet = true; m_unhealthyThreshold = value; }
     inline HealthCheck& WithUnhealthyThreshold(int value) { SetUnhealthyThreshold(value); return *this;}
@@ -103,7 +101,7 @@ namespace Model
      * <p>The number of consecutive health checks successes required before moving the
      * instance to the <code>Healthy</code> state.</p>
      */
-    inline int GetHealthyThreshold() const{ return m_healthyThreshold; }
+    inline int GetHealthyThreshold() const { return m_healthyThreshold; }
     inline bool HealthyThresholdHasBeenSet() const { return m_healthyThresholdHasBeenSet; }
     inline void SetHealthyThreshold(int value) { m_healthyThresholdHasBeenSet = true; m_healthyThreshold = value; }
     inline HealthCheck& WithHealthyThreshold(int value) { SetHealthyThreshold(value); return *this;}
@@ -113,16 +111,16 @@ namespace Model
     Aws::String m_target;
     bool m_targetHasBeenSet = false;
 
-    int m_interval;
+    int m_interval{0};
     bool m_intervalHasBeenSet = false;
 
-    int m_timeout;
+    int m_timeout{0};
     bool m_timeoutHasBeenSet = false;
 
-    int m_unhealthyThreshold;
+    int m_unhealthyThreshold{0};
     bool m_unhealthyThresholdHasBeenSet = false;
 
-    int m_healthyThreshold;
+    int m_healthyThreshold{0};
     bool m_healthyThresholdHasBeenSet = false;
   };
 
