@@ -33,7 +33,7 @@ namespace Model
   class ClusterStateChangeReason
   {
   public:
-    AWS_EMR_API ClusterStateChangeReason();
+    AWS_EMR_API ClusterStateChangeReason() = default;
     AWS_EMR_API ClusterStateChangeReason(Aws::Utils::Json::JsonView jsonValue);
     AWS_EMR_API ClusterStateChangeReason& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_EMR_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,30 +43,26 @@ namespace Model
     /**
      * <p>The programmatic code for the state change reason.</p>
      */
-    inline const ClusterStateChangeReasonCode& GetCode() const{ return m_code; }
+    inline ClusterStateChangeReasonCode GetCode() const { return m_code; }
     inline bool CodeHasBeenSet() const { return m_codeHasBeenSet; }
-    inline void SetCode(const ClusterStateChangeReasonCode& value) { m_codeHasBeenSet = true; m_code = value; }
-    inline void SetCode(ClusterStateChangeReasonCode&& value) { m_codeHasBeenSet = true; m_code = std::move(value); }
-    inline ClusterStateChangeReason& WithCode(const ClusterStateChangeReasonCode& value) { SetCode(value); return *this;}
-    inline ClusterStateChangeReason& WithCode(ClusterStateChangeReasonCode&& value) { SetCode(std::move(value)); return *this;}
+    inline void SetCode(ClusterStateChangeReasonCode value) { m_codeHasBeenSet = true; m_code = value; }
+    inline ClusterStateChangeReason& WithCode(ClusterStateChangeReasonCode value) { SetCode(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The descriptive message for the state change reason.</p>
      */
-    inline const Aws::String& GetMessage() const{ return m_message; }
+    inline const Aws::String& GetMessage() const { return m_message; }
     inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }
-    inline void SetMessage(const Aws::String& value) { m_messageHasBeenSet = true; m_message = value; }
-    inline void SetMessage(Aws::String&& value) { m_messageHasBeenSet = true; m_message = std::move(value); }
-    inline void SetMessage(const char* value) { m_messageHasBeenSet = true; m_message.assign(value); }
-    inline ClusterStateChangeReason& WithMessage(const Aws::String& value) { SetMessage(value); return *this;}
-    inline ClusterStateChangeReason& WithMessage(Aws::String&& value) { SetMessage(std::move(value)); return *this;}
-    inline ClusterStateChangeReason& WithMessage(const char* value) { SetMessage(value); return *this;}
+    template<typename MessageT = Aws::String>
+    void SetMessage(MessageT&& value) { m_messageHasBeenSet = true; m_message = std::forward<MessageT>(value); }
+    template<typename MessageT = Aws::String>
+    ClusterStateChangeReason& WithMessage(MessageT&& value) { SetMessage(std::forward<MessageT>(value)); return *this;}
     ///@}
   private:
 
-    ClusterStateChangeReasonCode m_code;
+    ClusterStateChangeReasonCode m_code{ClusterStateChangeReasonCode::NOT_SET};
     bool m_codeHasBeenSet = false;
 
     Aws::String m_message;
