@@ -22,7 +22,7 @@ namespace Model
   class GetStudioSessionMappingRequest : public EMRRequest
   {
   public:
-    AWS_EMR_API GetStudioSessionMappingRequest();
+    AWS_EMR_API GetStudioSessionMappingRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -39,14 +39,12 @@ namespace Model
     /**
      * <p>The ID of the Amazon EMR Studio.</p>
      */
-    inline const Aws::String& GetStudioId() const{ return m_studioId; }
+    inline const Aws::String& GetStudioId() const { return m_studioId; }
     inline bool StudioIdHasBeenSet() const { return m_studioIdHasBeenSet; }
-    inline void SetStudioId(const Aws::String& value) { m_studioIdHasBeenSet = true; m_studioId = value; }
-    inline void SetStudioId(Aws::String&& value) { m_studioIdHasBeenSet = true; m_studioId = std::move(value); }
-    inline void SetStudioId(const char* value) { m_studioIdHasBeenSet = true; m_studioId.assign(value); }
-    inline GetStudioSessionMappingRequest& WithStudioId(const Aws::String& value) { SetStudioId(value); return *this;}
-    inline GetStudioSessionMappingRequest& WithStudioId(Aws::String&& value) { SetStudioId(std::move(value)); return *this;}
-    inline GetStudioSessionMappingRequest& WithStudioId(const char* value) { SetStudioId(value); return *this;}
+    template<typename StudioIdT = Aws::String>
+    void SetStudioId(StudioIdT&& value) { m_studioIdHasBeenSet = true; m_studioId = std::forward<StudioIdT>(value); }
+    template<typename StudioIdT = Aws::String>
+    GetStudioSessionMappingRequest& WithStudioId(StudioIdT&& value) { SetStudioId(std::forward<StudioIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -59,14 +57,12 @@ namespace Model
      * in the <i>IAM Identity Center Identity Store API Reference</i>. Either
      * <code>IdentityName</code> or <code>IdentityId</code> must be specified.</p>
      */
-    inline const Aws::String& GetIdentityId() const{ return m_identityId; }
+    inline const Aws::String& GetIdentityId() const { return m_identityId; }
     inline bool IdentityIdHasBeenSet() const { return m_identityIdHasBeenSet; }
-    inline void SetIdentityId(const Aws::String& value) { m_identityIdHasBeenSet = true; m_identityId = value; }
-    inline void SetIdentityId(Aws::String&& value) { m_identityIdHasBeenSet = true; m_identityId = std::move(value); }
-    inline void SetIdentityId(const char* value) { m_identityIdHasBeenSet = true; m_identityId.assign(value); }
-    inline GetStudioSessionMappingRequest& WithIdentityId(const Aws::String& value) { SetIdentityId(value); return *this;}
-    inline GetStudioSessionMappingRequest& WithIdentityId(Aws::String&& value) { SetIdentityId(std::move(value)); return *this;}
-    inline GetStudioSessionMappingRequest& WithIdentityId(const char* value) { SetIdentityId(value); return *this;}
+    template<typename IdentityIdT = Aws::String>
+    void SetIdentityId(IdentityIdT&& value) { m_identityIdHasBeenSet = true; m_identityId = std::forward<IdentityIdT>(value); }
+    template<typename IdentityIdT = Aws::String>
+    GetStudioSessionMappingRequest& WithIdentityId(IdentityIdT&& value) { SetIdentityId(std::forward<IdentityIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -78,26 +74,22 @@ namespace Model
      * in the <i>IAM Identity Center Identity Store API Reference</i>. Either
      * <code>IdentityName</code> or <code>IdentityId</code> must be specified.</p>
      */
-    inline const Aws::String& GetIdentityName() const{ return m_identityName; }
+    inline const Aws::String& GetIdentityName() const { return m_identityName; }
     inline bool IdentityNameHasBeenSet() const { return m_identityNameHasBeenSet; }
-    inline void SetIdentityName(const Aws::String& value) { m_identityNameHasBeenSet = true; m_identityName = value; }
-    inline void SetIdentityName(Aws::String&& value) { m_identityNameHasBeenSet = true; m_identityName = std::move(value); }
-    inline void SetIdentityName(const char* value) { m_identityNameHasBeenSet = true; m_identityName.assign(value); }
-    inline GetStudioSessionMappingRequest& WithIdentityName(const Aws::String& value) { SetIdentityName(value); return *this;}
-    inline GetStudioSessionMappingRequest& WithIdentityName(Aws::String&& value) { SetIdentityName(std::move(value)); return *this;}
-    inline GetStudioSessionMappingRequest& WithIdentityName(const char* value) { SetIdentityName(value); return *this;}
+    template<typename IdentityNameT = Aws::String>
+    void SetIdentityName(IdentityNameT&& value) { m_identityNameHasBeenSet = true; m_identityName = std::forward<IdentityNameT>(value); }
+    template<typename IdentityNameT = Aws::String>
+    GetStudioSessionMappingRequest& WithIdentityName(IdentityNameT&& value) { SetIdentityName(std::forward<IdentityNameT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Specifies whether the identity to fetch is a user or a group.</p>
      */
-    inline const IdentityType& GetIdentityType() const{ return m_identityType; }
+    inline IdentityType GetIdentityType() const { return m_identityType; }
     inline bool IdentityTypeHasBeenSet() const { return m_identityTypeHasBeenSet; }
-    inline void SetIdentityType(const IdentityType& value) { m_identityTypeHasBeenSet = true; m_identityType = value; }
-    inline void SetIdentityType(IdentityType&& value) { m_identityTypeHasBeenSet = true; m_identityType = std::move(value); }
-    inline GetStudioSessionMappingRequest& WithIdentityType(const IdentityType& value) { SetIdentityType(value); return *this;}
-    inline GetStudioSessionMappingRequest& WithIdentityType(IdentityType&& value) { SetIdentityType(std::move(value)); return *this;}
+    inline void SetIdentityType(IdentityType value) { m_identityTypeHasBeenSet = true; m_identityType = value; }
+    inline GetStudioSessionMappingRequest& WithIdentityType(IdentityType value) { SetIdentityType(value); return *this;}
     ///@}
   private:
 
@@ -110,7 +102,7 @@ namespace Model
     Aws::String m_identityName;
     bool m_identityNameHasBeenSet = false;
 
-    IdentityType m_identityType;
+    IdentityType m_identityType{IdentityType::NOT_SET};
     bool m_identityTypeHasBeenSet = false;
   };
 
