@@ -33,7 +33,7 @@ namespace Model
   class InstanceStatus
   {
   public:
-    AWS_EMR_API InstanceStatus();
+    AWS_EMR_API InstanceStatus() = default;
     AWS_EMR_API InstanceStatus(Aws::Utils::Json::JsonView jsonValue);
     AWS_EMR_API InstanceStatus& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_EMR_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,40 +43,38 @@ namespace Model
     /**
      * <p>The current state of the instance.</p>
      */
-    inline const InstanceState& GetState() const{ return m_state; }
+    inline InstanceState GetState() const { return m_state; }
     inline bool StateHasBeenSet() const { return m_stateHasBeenSet; }
-    inline void SetState(const InstanceState& value) { m_stateHasBeenSet = true; m_state = value; }
-    inline void SetState(InstanceState&& value) { m_stateHasBeenSet = true; m_state = std::move(value); }
-    inline InstanceStatus& WithState(const InstanceState& value) { SetState(value); return *this;}
-    inline InstanceStatus& WithState(InstanceState&& value) { SetState(std::move(value)); return *this;}
+    inline void SetState(InstanceState value) { m_stateHasBeenSet = true; m_state = value; }
+    inline InstanceStatus& WithState(InstanceState value) { SetState(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The details of the status change reason for the instance.</p>
      */
-    inline const InstanceStateChangeReason& GetStateChangeReason() const{ return m_stateChangeReason; }
+    inline const InstanceStateChangeReason& GetStateChangeReason() const { return m_stateChangeReason; }
     inline bool StateChangeReasonHasBeenSet() const { return m_stateChangeReasonHasBeenSet; }
-    inline void SetStateChangeReason(const InstanceStateChangeReason& value) { m_stateChangeReasonHasBeenSet = true; m_stateChangeReason = value; }
-    inline void SetStateChangeReason(InstanceStateChangeReason&& value) { m_stateChangeReasonHasBeenSet = true; m_stateChangeReason = std::move(value); }
-    inline InstanceStatus& WithStateChangeReason(const InstanceStateChangeReason& value) { SetStateChangeReason(value); return *this;}
-    inline InstanceStatus& WithStateChangeReason(InstanceStateChangeReason&& value) { SetStateChangeReason(std::move(value)); return *this;}
+    template<typename StateChangeReasonT = InstanceStateChangeReason>
+    void SetStateChangeReason(StateChangeReasonT&& value) { m_stateChangeReasonHasBeenSet = true; m_stateChangeReason = std::forward<StateChangeReasonT>(value); }
+    template<typename StateChangeReasonT = InstanceStateChangeReason>
+    InstanceStatus& WithStateChangeReason(StateChangeReasonT&& value) { SetStateChangeReason(std::forward<StateChangeReasonT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The timeline of the instance status over time.</p>
      */
-    inline const InstanceTimeline& GetTimeline() const{ return m_timeline; }
+    inline const InstanceTimeline& GetTimeline() const { return m_timeline; }
     inline bool TimelineHasBeenSet() const { return m_timelineHasBeenSet; }
-    inline void SetTimeline(const InstanceTimeline& value) { m_timelineHasBeenSet = true; m_timeline = value; }
-    inline void SetTimeline(InstanceTimeline&& value) { m_timelineHasBeenSet = true; m_timeline = std::move(value); }
-    inline InstanceStatus& WithTimeline(const InstanceTimeline& value) { SetTimeline(value); return *this;}
-    inline InstanceStatus& WithTimeline(InstanceTimeline&& value) { SetTimeline(std::move(value)); return *this;}
+    template<typename TimelineT = InstanceTimeline>
+    void SetTimeline(TimelineT&& value) { m_timelineHasBeenSet = true; m_timeline = std::forward<TimelineT>(value); }
+    template<typename TimelineT = InstanceTimeline>
+    InstanceStatus& WithTimeline(TimelineT&& value) { SetTimeline(std::forward<TimelineT>(value)); return *this;}
     ///@}
   private:
 
-    InstanceState m_state;
+    InstanceState m_state{InstanceState::NOT_SET};
     bool m_stateHasBeenSet = false;
 
     InstanceStateChangeReason m_stateChangeReason;
