@@ -32,7 +32,7 @@ namespace Model
   class SimplifiedApplication
   {
   public:
-    AWS_EMR_API SimplifiedApplication();
+    AWS_EMR_API SimplifiedApplication() = default;
     AWS_EMR_API SimplifiedApplication(Aws::Utils::Json::JsonView jsonValue);
     AWS_EMR_API SimplifiedApplication& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_EMR_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,14 +43,12 @@ namespace Model
      * <p>The returned release label application name. For example,
      * <code>hadoop</code>.</p>
      */
-    inline const Aws::String& GetName() const{ return m_name; }
+    inline const Aws::String& GetName() const { return m_name; }
     inline bool NameHasBeenSet() const { return m_nameHasBeenSet; }
-    inline void SetName(const Aws::String& value) { m_nameHasBeenSet = true; m_name = value; }
-    inline void SetName(Aws::String&& value) { m_nameHasBeenSet = true; m_name = std::move(value); }
-    inline void SetName(const char* value) { m_nameHasBeenSet = true; m_name.assign(value); }
-    inline SimplifiedApplication& WithName(const Aws::String& value) { SetName(value); return *this;}
-    inline SimplifiedApplication& WithName(Aws::String&& value) { SetName(std::move(value)); return *this;}
-    inline SimplifiedApplication& WithName(const char* value) { SetName(value); return *this;}
+    template<typename NameT = Aws::String>
+    void SetName(NameT&& value) { m_nameHasBeenSet = true; m_name = std::forward<NameT>(value); }
+    template<typename NameT = Aws::String>
+    SimplifiedApplication& WithName(NameT&& value) { SetName(std::forward<NameT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -58,14 +56,12 @@ namespace Model
      * <p>The returned release label application version. For example,
      * <code>3.2.1</code>.</p>
      */
-    inline const Aws::String& GetVersion() const{ return m_version; }
+    inline const Aws::String& GetVersion() const { return m_version; }
     inline bool VersionHasBeenSet() const { return m_versionHasBeenSet; }
-    inline void SetVersion(const Aws::String& value) { m_versionHasBeenSet = true; m_version = value; }
-    inline void SetVersion(Aws::String&& value) { m_versionHasBeenSet = true; m_version = std::move(value); }
-    inline void SetVersion(const char* value) { m_versionHasBeenSet = true; m_version.assign(value); }
-    inline SimplifiedApplication& WithVersion(const Aws::String& value) { SetVersion(value); return *this;}
-    inline SimplifiedApplication& WithVersion(Aws::String&& value) { SetVersion(std::move(value)); return *this;}
-    inline SimplifiedApplication& WithVersion(const char* value) { SetVersion(value); return *this;}
+    template<typename VersionT = Aws::String>
+    void SetVersion(VersionT&& value) { m_versionHasBeenSet = true; m_version = std::forward<VersionT>(value); }
+    template<typename VersionT = Aws::String>
+    SimplifiedApplication& WithVersion(VersionT&& value) { SetVersion(std::forward<VersionT>(value)); return *this;}
     ///@}
   private:
 
