@@ -16,10 +16,10 @@ namespace Model
 
   /**
    */
-  class AWS_SES_API GetAccountSendingEnabledRequest : public SESRequest
+  class GetAccountSendingEnabledRequest : public SESRequest
   {
   public:
-    GetAccountSendingEnabledRequest();
+    AWS_SES_API GetAccountSendingEnabledRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -27,10 +27,10 @@ namespace Model
     // so we can not get operation's name from response.
     inline virtual const char* GetServiceRequestName() const override { return "GetAccountSendingEnabled"; }
 
-    Aws::String SerializePayload() const override;
+    AWS_SES_API Aws::String SerializePayload() const override;
 
   protected:
-    void DumpBodyToUrl(Aws::Http::URI& uri ) const override;
+    AWS_SES_API void DumpBodyToUrl(Aws::Http::URI& uri ) const override;
 
   public:
   };
