@@ -21,7 +21,7 @@ namespace Model
   class TestEventPatternRequest : public EventBridgeRequest
   {
   public:
-    AWS_EVENTBRIDGE_API TestEventPatternRequest();
+    AWS_EVENTBRIDGE_API TestEventPatternRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -40,14 +40,12 @@ namespace Model
      * href="https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-and-event-patterns.html">Events
      * and Event Patterns</a> in the <i> <i>Amazon EventBridge User Guide</i> </i>.</p>
      */
-    inline const Aws::String& GetEventPattern() const{ return m_eventPattern; }
+    inline const Aws::String& GetEventPattern() const { return m_eventPattern; }
     inline bool EventPatternHasBeenSet() const { return m_eventPatternHasBeenSet; }
-    inline void SetEventPattern(const Aws::String& value) { m_eventPatternHasBeenSet = true; m_eventPattern = value; }
-    inline void SetEventPattern(Aws::String&& value) { m_eventPatternHasBeenSet = true; m_eventPattern = std::move(value); }
-    inline void SetEventPattern(const char* value) { m_eventPatternHasBeenSet = true; m_eventPattern.assign(value); }
-    inline TestEventPatternRequest& WithEventPattern(const Aws::String& value) { SetEventPattern(value); return *this;}
-    inline TestEventPatternRequest& WithEventPattern(Aws::String&& value) { SetEventPattern(std::move(value)); return *this;}
-    inline TestEventPatternRequest& WithEventPattern(const char* value) { SetEventPattern(value); return *this;}
+    template<typename EventPatternT = Aws::String>
+    void SetEventPattern(EventPatternT&& value) { m_eventPatternHasBeenSet = true; m_eventPattern = std::forward<EventPatternT>(value); }
+    template<typename EventPatternT = Aws::String>
+    TestEventPatternRequest& WithEventPattern(EventPatternT&& value) { SetEventPattern(std::forward<EventPatternT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -61,14 +59,12 @@ namespace Model
      * <code>region</code> </p> </li> <li> <p> <code>resources</code> </p> </li> <li>
      * <p> <code>detail-type</code> </p> </li> </ul>
      */
-    inline const Aws::String& GetEvent() const{ return m_event; }
+    inline const Aws::String& GetEvent() const { return m_event; }
     inline bool EventHasBeenSet() const { return m_eventHasBeenSet; }
-    inline void SetEvent(const Aws::String& value) { m_eventHasBeenSet = true; m_event = value; }
-    inline void SetEvent(Aws::String&& value) { m_eventHasBeenSet = true; m_event = std::move(value); }
-    inline void SetEvent(const char* value) { m_eventHasBeenSet = true; m_event.assign(value); }
-    inline TestEventPatternRequest& WithEvent(const Aws::String& value) { SetEvent(value); return *this;}
-    inline TestEventPatternRequest& WithEvent(Aws::String&& value) { SetEvent(std::move(value)); return *this;}
-    inline TestEventPatternRequest& WithEvent(const char* value) { SetEvent(value); return *this;}
+    template<typename EventT = Aws::String>
+    void SetEvent(EventT&& value) { m_eventHasBeenSet = true; m_event = std::forward<EventT>(value); }
+    template<typename EventT = Aws::String>
+    TestEventPatternRequest& WithEvent(EventT&& value) { SetEvent(std::forward<EventT>(value)); return *this;}
     ///@}
   private:
 
