@@ -34,7 +34,7 @@ namespace Model
   class SegmentOverride
   {
   public:
-    AWS_CLOUDWATCHEVIDENTLY_API SegmentOverride();
+    AWS_CLOUDWATCHEVIDENTLY_API SegmentOverride() = default;
     AWS_CLOUDWATCHEVIDENTLY_API SegmentOverride(Aws::Utils::Json::JsonView jsonValue);
     AWS_CLOUDWATCHEVIDENTLY_API SegmentOverride& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_CLOUDWATCHEVIDENTLY_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -45,7 +45,7 @@ namespace Model
      * <p>A number indicating the order to use to evaluate segment overrides, if there
      * are more than one. Segment overrides with lower numbers are evaluated first.</p>
      */
-    inline long long GetEvaluationOrder() const{ return m_evaluationOrder; }
+    inline long long GetEvaluationOrder() const { return m_evaluationOrder; }
     inline bool EvaluationOrderHasBeenSet() const { return m_evaluationOrderHasBeenSet; }
     inline void SetEvaluationOrder(long long value) { m_evaluationOrderHasBeenSet = true; m_evaluationOrder = value; }
     inline SegmentOverride& WithEvaluationOrder(long long value) { SetEvaluationOrder(value); return *this;}
@@ -55,14 +55,12 @@ namespace Model
     /**
      * <p>The ARN of the segment to use.</p>
      */
-    inline const Aws::String& GetSegment() const{ return m_segment; }
+    inline const Aws::String& GetSegment() const { return m_segment; }
     inline bool SegmentHasBeenSet() const { return m_segmentHasBeenSet; }
-    inline void SetSegment(const Aws::String& value) { m_segmentHasBeenSet = true; m_segment = value; }
-    inline void SetSegment(Aws::String&& value) { m_segmentHasBeenSet = true; m_segment = std::move(value); }
-    inline void SetSegment(const char* value) { m_segmentHasBeenSet = true; m_segment.assign(value); }
-    inline SegmentOverride& WithSegment(const Aws::String& value) { SetSegment(value); return *this;}
-    inline SegmentOverride& WithSegment(Aws::String&& value) { SetSegment(std::move(value)); return *this;}
-    inline SegmentOverride& WithSegment(const char* value) { SetSegment(value); return *this;}
+    template<typename SegmentT = Aws::String>
+    void SetSegment(SegmentT&& value) { m_segmentHasBeenSet = true; m_segment = std::forward<SegmentT>(value); }
+    template<typename SegmentT = Aws::String>
+    SegmentOverride& WithSegment(SegmentT&& value) { SetSegment(std::forward<SegmentT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -73,19 +71,19 @@ namespace Model
      * this segment. This is expressed in thousandths of a percent, so a weight of
      * 50000 represents 50% of traffic.</p>
      */
-    inline const Aws::Map<Aws::String, long long>& GetWeights() const{ return m_weights; }
+    inline const Aws::Map<Aws::String, long long>& GetWeights() const { return m_weights; }
     inline bool WeightsHasBeenSet() const { return m_weightsHasBeenSet; }
-    inline void SetWeights(const Aws::Map<Aws::String, long long>& value) { m_weightsHasBeenSet = true; m_weights = value; }
-    inline void SetWeights(Aws::Map<Aws::String, long long>&& value) { m_weightsHasBeenSet = true; m_weights = std::move(value); }
-    inline SegmentOverride& WithWeights(const Aws::Map<Aws::String, long long>& value) { SetWeights(value); return *this;}
-    inline SegmentOverride& WithWeights(Aws::Map<Aws::String, long long>&& value) { SetWeights(std::move(value)); return *this;}
-    inline SegmentOverride& AddWeights(const Aws::String& key, long long value) { m_weightsHasBeenSet = true; m_weights.emplace(key, value); return *this; }
-    inline SegmentOverride& AddWeights(Aws::String&& key, long long value) { m_weightsHasBeenSet = true; m_weights.emplace(std::move(key), value); return *this; }
-    inline SegmentOverride& AddWeights(const char* key, long long value) { m_weightsHasBeenSet = true; m_weights.emplace(key, value); return *this; }
+    template<typename WeightsT = Aws::Map<Aws::String, long long>>
+    void SetWeights(WeightsT&& value) { m_weightsHasBeenSet = true; m_weights = std::forward<WeightsT>(value); }
+    template<typename WeightsT = Aws::Map<Aws::String, long long>>
+    SegmentOverride& WithWeights(WeightsT&& value) { SetWeights(std::forward<WeightsT>(value)); return *this;}
+    inline SegmentOverride& AddWeights(Aws::String key, long long value) {
+      m_weightsHasBeenSet = true; m_weights.emplace(key, value); return *this;
+    }
     ///@}
   private:
 
-    long long m_evaluationOrder;
+    long long m_evaluationOrder{0};
     bool m_evaluationOrderHasBeenSet = false;
 
     Aws::String m_segment;
