@@ -32,7 +32,7 @@ namespace Model
   class ExperimentTemplateCloudWatchLogsLogConfiguration
   {
   public:
-    AWS_FIS_API ExperimentTemplateCloudWatchLogsLogConfiguration();
+    AWS_FIS_API ExperimentTemplateCloudWatchLogsLogConfiguration() = default;
     AWS_FIS_API ExperimentTemplateCloudWatchLogsLogConfiguration(Aws::Utils::Json::JsonView jsonValue);
     AWS_FIS_API ExperimentTemplateCloudWatchLogsLogConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_FIS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,14 +43,12 @@ namespace Model
      * <p>The Amazon Resource Name (ARN) of the destination Amazon CloudWatch Logs log
      * group.</p>
      */
-    inline const Aws::String& GetLogGroupArn() const{ return m_logGroupArn; }
+    inline const Aws::String& GetLogGroupArn() const { return m_logGroupArn; }
     inline bool LogGroupArnHasBeenSet() const { return m_logGroupArnHasBeenSet; }
-    inline void SetLogGroupArn(const Aws::String& value) { m_logGroupArnHasBeenSet = true; m_logGroupArn = value; }
-    inline void SetLogGroupArn(Aws::String&& value) { m_logGroupArnHasBeenSet = true; m_logGroupArn = std::move(value); }
-    inline void SetLogGroupArn(const char* value) { m_logGroupArnHasBeenSet = true; m_logGroupArn.assign(value); }
-    inline ExperimentTemplateCloudWatchLogsLogConfiguration& WithLogGroupArn(const Aws::String& value) { SetLogGroupArn(value); return *this;}
-    inline ExperimentTemplateCloudWatchLogsLogConfiguration& WithLogGroupArn(Aws::String&& value) { SetLogGroupArn(std::move(value)); return *this;}
-    inline ExperimentTemplateCloudWatchLogsLogConfiguration& WithLogGroupArn(const char* value) { SetLogGroupArn(value); return *this;}
+    template<typename LogGroupArnT = Aws::String>
+    void SetLogGroupArn(LogGroupArnT&& value) { m_logGroupArnHasBeenSet = true; m_logGroupArn = std::forward<LogGroupArnT>(value); }
+    template<typename LogGroupArnT = Aws::String>
+    ExperimentTemplateCloudWatchLogsLogConfiguration& WithLogGroupArn(LogGroupArnT&& value) { SetLogGroupArn(std::forward<LogGroupArnT>(value)); return *this;}
     ///@}
   private:
 
