@@ -29,7 +29,7 @@ namespace Model
   class MetricDataPoint
   {
   public:
-    AWS_FRAUDDETECTOR_API MetricDataPoint();
+    AWS_FRAUDDETECTOR_API MetricDataPoint() = default;
     AWS_FRAUDDETECTOR_API MetricDataPoint(Aws::Utils::Json::JsonView jsonValue);
     AWS_FRAUDDETECTOR_API MetricDataPoint& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_FRAUDDETECTOR_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -40,7 +40,7 @@ namespace Model
      * <p>The false positive rate. This is the percentage of total legitimate events
      * that are incorrectly predicted as fraud.</p>
      */
-    inline double GetFpr() const{ return m_fpr; }
+    inline double GetFpr() const { return m_fpr; }
     inline bool FprHasBeenSet() const { return m_fprHasBeenSet; }
     inline void SetFpr(double value) { m_fprHasBeenSet = true; m_fpr = value; }
     inline MetricDataPoint& WithFpr(double value) { SetFpr(value); return *this;}
@@ -51,7 +51,7 @@ namespace Model
      * <p>The percentage of fraud events correctly predicted as fraudulent as compared
      * to all events predicted as fraudulent.</p>
      */
-    inline double GetPrecision() const{ return m_precision; }
+    inline double GetPrecision() const { return m_precision; }
     inline bool PrecisionHasBeenSet() const { return m_precisionHasBeenSet; }
     inline void SetPrecision(double value) { m_precisionHasBeenSet = true; m_precision = value; }
     inline MetricDataPoint& WithPrecision(double value) { SetPrecision(value); return *this;}
@@ -62,7 +62,7 @@ namespace Model
      * <p>The true positive rate. This is the percentage of total fraud the model
      * detects. Also known as capture rate.</p>
      */
-    inline double GetTpr() const{ return m_tpr; }
+    inline double GetTpr() const { return m_tpr; }
     inline bool TprHasBeenSet() const { return m_tprHasBeenSet; }
     inline void SetTpr(double value) { m_tprHasBeenSet = true; m_tpr = value; }
     inline MetricDataPoint& WithTpr(double value) { SetTpr(value); return *this;}
@@ -74,23 +74,23 @@ namespace Model
      * example, a threshold of 500 means any model score 500 or above is labeled as
      * fraud.</p>
      */
-    inline double GetThreshold() const{ return m_threshold; }
+    inline double GetThreshold() const { return m_threshold; }
     inline bool ThresholdHasBeenSet() const { return m_thresholdHasBeenSet; }
     inline void SetThreshold(double value) { m_thresholdHasBeenSet = true; m_threshold = value; }
     inline MetricDataPoint& WithThreshold(double value) { SetThreshold(value); return *this;}
     ///@}
   private:
 
-    double m_fpr;
+    double m_fpr{0.0};
     bool m_fprHasBeenSet = false;
 
-    double m_precision;
+    double m_precision{0.0};
     bool m_precisionHasBeenSet = false;
 
-    double m_tpr;
+    double m_tpr{0.0};
     bool m_tprHasBeenSet = false;
 
-    double m_threshold;
+    double m_threshold{0.0};
     bool m_thresholdHasBeenSet = false;
   };
 
