@@ -33,7 +33,7 @@ namespace Model
   class IncompatibleParameterError
   {
   public:
-    AWS_FSX_API IncompatibleParameterError();
+    AWS_FSX_API IncompatibleParameterError() = default;
     AWS_FSX_API IncompatibleParameterError(Aws::Utils::Json::JsonView jsonValue);
     AWS_FSX_API IncompatibleParameterError& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_FSX_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,26 +43,22 @@ namespace Model
     /**
      * <p>A parameter that is incompatible with the earlier request.</p>
      */
-    inline const Aws::String& GetParameter() const{ return m_parameter; }
+    inline const Aws::String& GetParameter() const { return m_parameter; }
     inline bool ParameterHasBeenSet() const { return m_parameterHasBeenSet; }
-    inline void SetParameter(const Aws::String& value) { m_parameterHasBeenSet = true; m_parameter = value; }
-    inline void SetParameter(Aws::String&& value) { m_parameterHasBeenSet = true; m_parameter = std::move(value); }
-    inline void SetParameter(const char* value) { m_parameterHasBeenSet = true; m_parameter.assign(value); }
-    inline IncompatibleParameterError& WithParameter(const Aws::String& value) { SetParameter(value); return *this;}
-    inline IncompatibleParameterError& WithParameter(Aws::String&& value) { SetParameter(std::move(value)); return *this;}
-    inline IncompatibleParameterError& WithParameter(const char* value) { SetParameter(value); return *this;}
+    template<typename ParameterT = Aws::String>
+    void SetParameter(ParameterT&& value) { m_parameterHasBeenSet = true; m_parameter = std::forward<ParameterT>(value); }
+    template<typename ParameterT = Aws::String>
+    IncompatibleParameterError& WithParameter(ParameterT&& value) { SetParameter(std::forward<ParameterT>(value)); return *this;}
     ///@}
 
     ///@{
     
-    inline const Aws::String& GetMessage() const{ return m_message; }
+    inline const Aws::String& GetMessage() const { return m_message; }
     inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }
-    inline void SetMessage(const Aws::String& value) { m_messageHasBeenSet = true; m_message = value; }
-    inline void SetMessage(Aws::String&& value) { m_messageHasBeenSet = true; m_message = std::move(value); }
-    inline void SetMessage(const char* value) { m_messageHasBeenSet = true; m_message.assign(value); }
-    inline IncompatibleParameterError& WithMessage(const Aws::String& value) { SetMessage(value); return *this;}
-    inline IncompatibleParameterError& WithMessage(Aws::String&& value) { SetMessage(std::move(value)); return *this;}
-    inline IncompatibleParameterError& WithMessage(const char* value) { SetMessage(value); return *this;}
+    template<typename MessageT = Aws::String>
+    void SetMessage(MessageT&& value) { m_messageHasBeenSet = true; m_message = std::forward<MessageT>(value); }
+    template<typename MessageT = Aws::String>
+    IncompatibleParameterError& WithMessage(MessageT&& value) { SetMessage(std::forward<MessageT>(value)); return *this;}
     ///@}
   private:
 
