@@ -32,7 +32,7 @@ namespace Model
   class LifecycleTransitionReason
   {
   public:
-    AWS_FSX_API LifecycleTransitionReason();
+    AWS_FSX_API LifecycleTransitionReason() = default;
     AWS_FSX_API LifecycleTransitionReason(Aws::Utils::Json::JsonView jsonValue);
     AWS_FSX_API LifecycleTransitionReason& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_FSX_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -40,14 +40,12 @@ namespace Model
 
     ///@{
     
-    inline const Aws::String& GetMessage() const{ return m_message; }
+    inline const Aws::String& GetMessage() const { return m_message; }
     inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }
-    inline void SetMessage(const Aws::String& value) { m_messageHasBeenSet = true; m_message = value; }
-    inline void SetMessage(Aws::String&& value) { m_messageHasBeenSet = true; m_message = std::move(value); }
-    inline void SetMessage(const char* value) { m_messageHasBeenSet = true; m_message.assign(value); }
-    inline LifecycleTransitionReason& WithMessage(const Aws::String& value) { SetMessage(value); return *this;}
-    inline LifecycleTransitionReason& WithMessage(Aws::String&& value) { SetMessage(std::move(value)); return *this;}
-    inline LifecycleTransitionReason& WithMessage(const char* value) { SetMessage(value); return *this;}
+    template<typename MessageT = Aws::String>
+    void SetMessage(MessageT&& value) { m_messageHasBeenSet = true; m_message = std::forward<MessageT>(value); }
+    template<typename MessageT = Aws::String>
+    LifecycleTransitionReason& WithMessage(MessageT&& value) { SetMessage(std::forward<MessageT>(value)); return *this;}
     ///@}
   private:
 
