@@ -31,7 +31,7 @@ namespace Model
   class WaypointOptimizationOriginOptions
   {
   public:
-    AWS_GEOROUTES_API WaypointOptimizationOriginOptions();
+    AWS_GEOROUTES_API WaypointOptimizationOriginOptions() = default;
     AWS_GEOROUTES_API WaypointOptimizationOriginOptions(Aws::Utils::Json::JsonView jsonValue);
     AWS_GEOROUTES_API WaypointOptimizationOriginOptions& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_GEOROUTES_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -41,14 +41,12 @@ namespace Model
     /**
      * <p>The Origin Id.</p>
      */
-    inline const Aws::String& GetId() const{ return m_id; }
+    inline const Aws::String& GetId() const { return m_id; }
     inline bool IdHasBeenSet() const { return m_idHasBeenSet; }
-    inline void SetId(const Aws::String& value) { m_idHasBeenSet = true; m_id = value; }
-    inline void SetId(Aws::String&& value) { m_idHasBeenSet = true; m_id = std::move(value); }
-    inline void SetId(const char* value) { m_idHasBeenSet = true; m_id.assign(value); }
-    inline WaypointOptimizationOriginOptions& WithId(const Aws::String& value) { SetId(value); return *this;}
-    inline WaypointOptimizationOriginOptions& WithId(Aws::String&& value) { SetId(std::move(value)); return *this;}
-    inline WaypointOptimizationOriginOptions& WithId(const char* value) { SetId(value); return *this;}
+    template<typename IdT = Aws::String>
+    void SetId(IdT&& value) { m_idHasBeenSet = true; m_id = std::forward<IdT>(value); }
+    template<typename IdT = Aws::String>
+    WaypointOptimizationOriginOptions& WithId(IdT&& value) { SetId(std::forward<IdT>(value)); return *this;}
     ///@}
   private:
 
