@@ -21,7 +21,7 @@ namespace Model
   class GetRegistryRequest : public GlueRequest
   {
   public:
-    AWS_GLUE_API GetRegistryRequest();
+    AWS_GLUE_API GetRegistryRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -39,12 +39,12 @@ namespace Model
      * <p>This is a wrapper structure that may contain the registry name and Amazon
      * Resource Name (ARN).</p>
      */
-    inline const RegistryId& GetRegistryId() const{ return m_registryId; }
+    inline const RegistryId& GetRegistryId() const { return m_registryId; }
     inline bool RegistryIdHasBeenSet() const { return m_registryIdHasBeenSet; }
-    inline void SetRegistryId(const RegistryId& value) { m_registryIdHasBeenSet = true; m_registryId = value; }
-    inline void SetRegistryId(RegistryId&& value) { m_registryIdHasBeenSet = true; m_registryId = std::move(value); }
-    inline GetRegistryRequest& WithRegistryId(const RegistryId& value) { SetRegistryId(value); return *this;}
-    inline GetRegistryRequest& WithRegistryId(RegistryId&& value) { SetRegistryId(std::move(value)); return *this;}
+    template<typename RegistryIdT = RegistryId>
+    void SetRegistryId(RegistryIdT&& value) { m_registryIdHasBeenSet = true; m_registryId = std::forward<RegistryIdT>(value); }
+    template<typename RegistryIdT = RegistryId>
+    GetRegistryRequest& WithRegistryId(RegistryIdT&& value) { SetRegistryId(std::forward<RegistryIdT>(value)); return *this;}
     ///@}
   private:
 
