@@ -43,7 +43,7 @@ namespace Model
   class JobUpdate
   {
   public:
-    AWS_GLUE_API JobUpdate();
+    AWS_GLUE_API JobUpdate() = default;
     AWS_GLUE_API JobUpdate(Aws::Utils::Json::JsonView jsonValue);
     AWS_GLUE_API JobUpdate& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_GLUE_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -59,12 +59,10 @@ namespace Model
      * <code>JobMode</code> field is missing or null, <code>SCRIPT</code> is assigned
      * as the default value.</p>
      */
-    inline const JobMode& GetJobMode() const{ return m_jobMode; }
+    inline JobMode GetJobMode() const { return m_jobMode; }
     inline bool JobModeHasBeenSet() const { return m_jobModeHasBeenSet; }
-    inline void SetJobMode(const JobMode& value) { m_jobModeHasBeenSet = true; m_jobMode = value; }
-    inline void SetJobMode(JobMode&& value) { m_jobModeHasBeenSet = true; m_jobMode = std::move(value); }
-    inline JobUpdate& WithJobMode(const JobMode& value) { SetJobMode(value); return *this;}
-    inline JobUpdate& WithJobMode(JobMode&& value) { SetJobMode(std::move(value)); return *this;}
+    inline void SetJobMode(JobMode value) { m_jobModeHasBeenSet = true; m_jobMode = value; }
+    inline JobUpdate& WithJobMode(JobMode value) { SetJobMode(value); return *this;}
     ///@}
 
     ///@{
@@ -75,7 +73,7 @@ namespace Model
      * <p>If this field does not match the value set in the job run, then the value
      * from the job run field will be used.</p>
      */
-    inline bool GetJobRunQueuingEnabled() const{ return m_jobRunQueuingEnabled; }
+    inline bool GetJobRunQueuingEnabled() const { return m_jobRunQueuingEnabled; }
     inline bool JobRunQueuingEnabledHasBeenSet() const { return m_jobRunQueuingEnabledHasBeenSet; }
     inline void SetJobRunQueuingEnabled(bool value) { m_jobRunQueuingEnabledHasBeenSet = true; m_jobRunQueuingEnabled = value; }
     inline JobUpdate& WithJobRunQueuingEnabled(bool value) { SetJobRunQueuingEnabled(value); return *this;}
@@ -85,28 +83,24 @@ namespace Model
     /**
      * <p>Description of the job being defined.</p>
      */
-    inline const Aws::String& GetDescription() const{ return m_description; }
+    inline const Aws::String& GetDescription() const { return m_description; }
     inline bool DescriptionHasBeenSet() const { return m_descriptionHasBeenSet; }
-    inline void SetDescription(const Aws::String& value) { m_descriptionHasBeenSet = true; m_description = value; }
-    inline void SetDescription(Aws::String&& value) { m_descriptionHasBeenSet = true; m_description = std::move(value); }
-    inline void SetDescription(const char* value) { m_descriptionHasBeenSet = true; m_description.assign(value); }
-    inline JobUpdate& WithDescription(const Aws::String& value) { SetDescription(value); return *this;}
-    inline JobUpdate& WithDescription(Aws::String&& value) { SetDescription(std::move(value)); return *this;}
-    inline JobUpdate& WithDescription(const char* value) { SetDescription(value); return *this;}
+    template<typename DescriptionT = Aws::String>
+    void SetDescription(DescriptionT&& value) { m_descriptionHasBeenSet = true; m_description = std::forward<DescriptionT>(value); }
+    template<typename DescriptionT = Aws::String>
+    JobUpdate& WithDescription(DescriptionT&& value) { SetDescription(std::forward<DescriptionT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>This field is reserved for future use.</p>
      */
-    inline const Aws::String& GetLogUri() const{ return m_logUri; }
+    inline const Aws::String& GetLogUri() const { return m_logUri; }
     inline bool LogUriHasBeenSet() const { return m_logUriHasBeenSet; }
-    inline void SetLogUri(const Aws::String& value) { m_logUriHasBeenSet = true; m_logUri = value; }
-    inline void SetLogUri(Aws::String&& value) { m_logUriHasBeenSet = true; m_logUri = std::move(value); }
-    inline void SetLogUri(const char* value) { m_logUriHasBeenSet = true; m_logUri.assign(value); }
-    inline JobUpdate& WithLogUri(const Aws::String& value) { SetLogUri(value); return *this;}
-    inline JobUpdate& WithLogUri(Aws::String&& value) { SetLogUri(std::move(value)); return *this;}
-    inline JobUpdate& WithLogUri(const char* value) { SetLogUri(value); return *this;}
+    template<typename LogUriT = Aws::String>
+    void SetLogUri(LogUriT&& value) { m_logUriHasBeenSet = true; m_logUri = std::forward<LogUriT>(value); }
+    template<typename LogUriT = Aws::String>
+    JobUpdate& WithLogUri(LogUriT&& value) { SetLogUri(std::forward<LogUriT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -114,14 +108,12 @@ namespace Model
      * <p>The name or Amazon Resource Name (ARN) of the IAM role associated with this
      * job (required).</p>
      */
-    inline const Aws::String& GetRole() const{ return m_role; }
+    inline const Aws::String& GetRole() const { return m_role; }
     inline bool RoleHasBeenSet() const { return m_roleHasBeenSet; }
-    inline void SetRole(const Aws::String& value) { m_roleHasBeenSet = true; m_role = value; }
-    inline void SetRole(Aws::String&& value) { m_roleHasBeenSet = true; m_role = std::move(value); }
-    inline void SetRole(const char* value) { m_roleHasBeenSet = true; m_role.assign(value); }
-    inline JobUpdate& WithRole(const Aws::String& value) { SetRole(value); return *this;}
-    inline JobUpdate& WithRole(Aws::String&& value) { SetRole(std::move(value)); return *this;}
-    inline JobUpdate& WithRole(const char* value) { SetRole(value); return *this;}
+    template<typename RoleT = Aws::String>
+    void SetRole(RoleT&& value) { m_roleHasBeenSet = true; m_role = std::forward<RoleT>(value); }
+    template<typename RoleT = Aws::String>
+    JobUpdate& WithRole(RoleT&& value) { SetRole(std::forward<RoleT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -129,24 +121,24 @@ namespace Model
      * <p>An <code>ExecutionProperty</code> specifying the maximum number of concurrent
      * runs allowed for this job.</p>
      */
-    inline const ExecutionProperty& GetExecutionProperty() const{ return m_executionProperty; }
+    inline const ExecutionProperty& GetExecutionProperty() const { return m_executionProperty; }
     inline bool ExecutionPropertyHasBeenSet() const { return m_executionPropertyHasBeenSet; }
-    inline void SetExecutionProperty(const ExecutionProperty& value) { m_executionPropertyHasBeenSet = true; m_executionProperty = value; }
-    inline void SetExecutionProperty(ExecutionProperty&& value) { m_executionPropertyHasBeenSet = true; m_executionProperty = std::move(value); }
-    inline JobUpdate& WithExecutionProperty(const ExecutionProperty& value) { SetExecutionProperty(value); return *this;}
-    inline JobUpdate& WithExecutionProperty(ExecutionProperty&& value) { SetExecutionProperty(std::move(value)); return *this;}
+    template<typename ExecutionPropertyT = ExecutionProperty>
+    void SetExecutionProperty(ExecutionPropertyT&& value) { m_executionPropertyHasBeenSet = true; m_executionProperty = std::forward<ExecutionPropertyT>(value); }
+    template<typename ExecutionPropertyT = ExecutionProperty>
+    JobUpdate& WithExecutionProperty(ExecutionPropertyT&& value) { SetExecutionProperty(std::forward<ExecutionPropertyT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The <code>JobCommand</code> that runs this job (required).</p>
      */
-    inline const JobCommand& GetCommand() const{ return m_command; }
+    inline const JobCommand& GetCommand() const { return m_command; }
     inline bool CommandHasBeenSet() const { return m_commandHasBeenSet; }
-    inline void SetCommand(const JobCommand& value) { m_commandHasBeenSet = true; m_command = value; }
-    inline void SetCommand(JobCommand&& value) { m_commandHasBeenSet = true; m_command = std::move(value); }
-    inline JobUpdate& WithCommand(const JobCommand& value) { SetCommand(value); return *this;}
-    inline JobUpdate& WithCommand(JobCommand&& value) { SetCommand(std::move(value)); return *this;}
+    template<typename CommandT = JobCommand>
+    void SetCommand(CommandT&& value) { m_commandHasBeenSet = true; m_command = std::forward<CommandT>(value); }
+    template<typename CommandT = JobCommand>
+    JobUpdate& WithCommand(CommandT&& value) { SetCommand(std::forward<CommandT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -169,19 +161,16 @@ namespace Model
      * href="https://docs.aws.amazon.com/glue/latest/dg/author-job-ray-job-parameters.html">Using
      * job parameters in Ray jobs</a> in the developer guide.</p>
      */
-    inline const Aws::Map<Aws::String, Aws::String>& GetDefaultArguments() const{ return m_defaultArguments; }
+    inline const Aws::Map<Aws::String, Aws::String>& GetDefaultArguments() const { return m_defaultArguments; }
     inline bool DefaultArgumentsHasBeenSet() const { return m_defaultArgumentsHasBeenSet; }
-    inline void SetDefaultArguments(const Aws::Map<Aws::String, Aws::String>& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments = value; }
-    inline void SetDefaultArguments(Aws::Map<Aws::String, Aws::String>&& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments = std::move(value); }
-    inline JobUpdate& WithDefaultArguments(const Aws::Map<Aws::String, Aws::String>& value) { SetDefaultArguments(value); return *this;}
-    inline JobUpdate& WithDefaultArguments(Aws::Map<Aws::String, Aws::String>&& value) { SetDefaultArguments(std::move(value)); return *this;}
-    inline JobUpdate& AddDefaultArguments(const Aws::String& key, const Aws::String& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(key, value); return *this; }
-    inline JobUpdate& AddDefaultArguments(Aws::String&& key, const Aws::String& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(std::move(key), value); return *this; }
-    inline JobUpdate& AddDefaultArguments(const Aws::String& key, Aws::String&& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(key, std::move(value)); return *this; }
-    inline JobUpdate& AddDefaultArguments(Aws::String&& key, Aws::String&& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(std::move(key), std::move(value)); return *this; }
-    inline JobUpdate& AddDefaultArguments(const char* key, Aws::String&& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(key, std::move(value)); return *this; }
-    inline JobUpdate& AddDefaultArguments(Aws::String&& key, const char* value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(std::move(key), value); return *this; }
-    inline JobUpdate& AddDefaultArguments(const char* key, const char* value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(key, value); return *this; }
+    template<typename DefaultArgumentsT = Aws::Map<Aws::String, Aws::String>>
+    void SetDefaultArguments(DefaultArgumentsT&& value) { m_defaultArgumentsHasBeenSet = true; m_defaultArguments = std::forward<DefaultArgumentsT>(value); }
+    template<typename DefaultArgumentsT = Aws::Map<Aws::String, Aws::String>>
+    JobUpdate& WithDefaultArguments(DefaultArgumentsT&& value) { SetDefaultArguments(std::forward<DefaultArgumentsT>(value)); return *this;}
+    template<typename DefaultArgumentsKeyT = Aws::String, typename DefaultArgumentsValueT = Aws::String>
+    JobUpdate& AddDefaultArguments(DefaultArgumentsKeyT&& key, DefaultArgumentsValueT&& value) {
+      m_defaultArgumentsHasBeenSet = true; m_defaultArguments.emplace(std::forward<DefaultArgumentsKeyT>(key), std::forward<DefaultArgumentsValueT>(value)); return *this;
+    }
     ///@}
 
     ///@{
@@ -189,38 +178,35 @@ namespace Model
      * <p>Arguments for this job that are not overridden when providing job arguments
      * in a job run, specified as name-value pairs.</p>
      */
-    inline const Aws::Map<Aws::String, Aws::String>& GetNonOverridableArguments() const{ return m_nonOverridableArguments; }
+    inline const Aws::Map<Aws::String, Aws::String>& GetNonOverridableArguments() const { return m_nonOverridableArguments; }
     inline bool NonOverridableArgumentsHasBeenSet() const { return m_nonOverridableArgumentsHasBeenSet; }
-    inline void SetNonOverridableArguments(const Aws::Map<Aws::String, Aws::String>& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments = value; }
-    inline void SetNonOverridableArguments(Aws::Map<Aws::String, Aws::String>&& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments = std::move(value); }
-    inline JobUpdate& WithNonOverridableArguments(const Aws::Map<Aws::String, Aws::String>& value) { SetNonOverridableArguments(value); return *this;}
-    inline JobUpdate& WithNonOverridableArguments(Aws::Map<Aws::String, Aws::String>&& value) { SetNonOverridableArguments(std::move(value)); return *this;}
-    inline JobUpdate& AddNonOverridableArguments(const Aws::String& key, const Aws::String& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(key, value); return *this; }
-    inline JobUpdate& AddNonOverridableArguments(Aws::String&& key, const Aws::String& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(std::move(key), value); return *this; }
-    inline JobUpdate& AddNonOverridableArguments(const Aws::String& key, Aws::String&& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(key, std::move(value)); return *this; }
-    inline JobUpdate& AddNonOverridableArguments(Aws::String&& key, Aws::String&& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(std::move(key), std::move(value)); return *this; }
-    inline JobUpdate& AddNonOverridableArguments(const char* key, Aws::String&& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(key, std::move(value)); return *this; }
-    inline JobUpdate& AddNonOverridableArguments(Aws::String&& key, const char* value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(std::move(key), value); return *this; }
-    inline JobUpdate& AddNonOverridableArguments(const char* key, const char* value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(key, value); return *this; }
+    template<typename NonOverridableArgumentsT = Aws::Map<Aws::String, Aws::String>>
+    void SetNonOverridableArguments(NonOverridableArgumentsT&& value) { m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments = std::forward<NonOverridableArgumentsT>(value); }
+    template<typename NonOverridableArgumentsT = Aws::Map<Aws::String, Aws::String>>
+    JobUpdate& WithNonOverridableArguments(NonOverridableArgumentsT&& value) { SetNonOverridableArguments(std::forward<NonOverridableArgumentsT>(value)); return *this;}
+    template<typename NonOverridableArgumentsKeyT = Aws::String, typename NonOverridableArgumentsValueT = Aws::String>
+    JobUpdate& AddNonOverridableArguments(NonOverridableArgumentsKeyT&& key, NonOverridableArgumentsValueT&& value) {
+      m_nonOverridableArgumentsHasBeenSet = true; m_nonOverridableArguments.emplace(std::forward<NonOverridableArgumentsKeyT>(key), std::forward<NonOverridableArgumentsValueT>(value)); return *this;
+    }
     ///@}
 
     ///@{
     /**
      * <p>The connections used for this job.</p>
      */
-    inline const ConnectionsList& GetConnections() const{ return m_connections; }
+    inline const ConnectionsList& GetConnections() const { return m_connections; }
     inline bool ConnectionsHasBeenSet() const { return m_connectionsHasBeenSet; }
-    inline void SetConnections(const ConnectionsList& value) { m_connectionsHasBeenSet = true; m_connections = value; }
-    inline void SetConnections(ConnectionsList&& value) { m_connectionsHasBeenSet = true; m_connections = std::move(value); }
-    inline JobUpdate& WithConnections(const ConnectionsList& value) { SetConnections(value); return *this;}
-    inline JobUpdate& WithConnections(ConnectionsList&& value) { SetConnections(std::move(value)); return *this;}
+    template<typename ConnectionsT = ConnectionsList>
+    void SetConnections(ConnectionsT&& value) { m_connectionsHasBeenSet = true; m_connections = std::forward<ConnectionsT>(value); }
+    template<typename ConnectionsT = ConnectionsList>
+    JobUpdate& WithConnections(ConnectionsT&& value) { SetConnections(std::forward<ConnectionsT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The maximum number of times to retry this job if it fails.</p>
      */
-    inline int GetMaxRetries() const{ return m_maxRetries; }
+    inline int GetMaxRetries() const { return m_maxRetries; }
     inline bool MaxRetriesHasBeenSet() const { return m_maxRetriesHasBeenSet; }
     inline void SetMaxRetries(int value) { m_maxRetriesHasBeenSet = true; m_maxRetries = value; }
     inline JobUpdate& WithMaxRetries(int value) { SetMaxRetries(value); return *this;}
@@ -239,7 +225,7 @@ namespace Model
      * maintenance window, it will be restarted during the maintenance window after 7
      * days.</p>
      */
-    inline int GetTimeout() const{ return m_timeout; }
+    inline int GetTimeout() const { return m_timeout; }
     inline bool TimeoutHasBeenSet() const { return m_timeoutHasBeenSet; }
     inline void SetTimeout(int value) { m_timeoutHasBeenSet = true; m_timeout = value; }
     inline JobUpdate& WithTimeout(int value) { SetTimeout(value); return *this;}
@@ -266,7 +252,7 @@ namespace Model
      * to 100 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU
      * allocation.</p> </li> </ul>
      */
-    inline double GetMaxCapacity() const{ return m_maxCapacity; }
+    inline double GetMaxCapacity() const { return m_maxCapacity; }
     inline bool MaxCapacityHasBeenSet() const { return m_maxCapacityHasBeenSet; }
     inline void SetMaxCapacity(double value) { m_maxCapacityHasBeenSet = true; m_maxCapacity = value; }
     inline JobUpdate& WithMaxCapacity(double value) { SetMaxCapacity(value); return *this;}
@@ -306,12 +292,10 @@ namespace Model
      * type, each worker maps to 2 M-DPU (8vCPUs, 64 GB of memory) with 128 GB disk,
      * and provides up to 8 Ray workers based on the autoscaler.</p> </li> </ul>
      */
-    inline const WorkerType& GetWorkerType() const{ return m_workerType; }
+    inline WorkerType GetWorkerType() const { return m_workerType; }
     inline bool WorkerTypeHasBeenSet() const { return m_workerTypeHasBeenSet; }
-    inline void SetWorkerType(const WorkerType& value) { m_workerTypeHasBeenSet = true; m_workerType = value; }
-    inline void SetWorkerType(WorkerType&& value) { m_workerTypeHasBeenSet = true; m_workerType = std::move(value); }
-    inline JobUpdate& WithWorkerType(const WorkerType& value) { SetWorkerType(value); return *this;}
-    inline JobUpdate& WithWorkerType(WorkerType&& value) { SetWorkerType(std::move(value)); return *this;}
+    inline void SetWorkerType(WorkerType value) { m_workerTypeHasBeenSet = true; m_workerType = value; }
+    inline JobUpdate& WithWorkerType(WorkerType value) { SetWorkerType(value); return *this;}
     ///@}
 
     ///@{
@@ -319,7 +303,7 @@ namespace Model
      * <p>The number of workers of a defined <code>workerType</code> that are allocated
      * when a job runs.</p>
      */
-    inline int GetNumberOfWorkers() const{ return m_numberOfWorkers; }
+    inline int GetNumberOfWorkers() const { return m_numberOfWorkers; }
     inline bool NumberOfWorkersHasBeenSet() const { return m_numberOfWorkersHasBeenSet; }
     inline void SetNumberOfWorkers(int value) { m_numberOfWorkersHasBeenSet = true; m_numberOfWorkers = value; }
     inline JobUpdate& WithNumberOfWorkers(int value) { SetNumberOfWorkers(value); return *this;}
@@ -330,26 +314,24 @@ namespace Model
      * <p>The name of the <code>SecurityConfiguration</code> structure to be used with
      * this job.</p>
      */
-    inline const Aws::String& GetSecurityConfiguration() const{ return m_securityConfiguration; }
+    inline const Aws::String& GetSecurityConfiguration() const { return m_securityConfiguration; }
     inline bool SecurityConfigurationHasBeenSet() const { return m_securityConfigurationHasBeenSet; }
-    inline void SetSecurityConfiguration(const Aws::String& value) { m_securityConfigurationHasBeenSet = true; m_securityConfiguration = value; }
-    inline void SetSecurityConfiguration(Aws::String&& value) { m_securityConfigurationHasBeenSet = true; m_securityConfiguration = std::move(value); }
-    inline void SetSecurityConfiguration(const char* value) { m_securityConfigurationHasBeenSet = true; m_securityConfiguration.assign(value); }
-    inline JobUpdate& WithSecurityConfiguration(const Aws::String& value) { SetSecurityConfiguration(value); return *this;}
-    inline JobUpdate& WithSecurityConfiguration(Aws::String&& value) { SetSecurityConfiguration(std::move(value)); return *this;}
-    inline JobUpdate& WithSecurityConfiguration(const char* value) { SetSecurityConfiguration(value); return *this;}
+    template<typename SecurityConfigurationT = Aws::String>
+    void SetSecurityConfiguration(SecurityConfigurationT&& value) { m_securityConfigurationHasBeenSet = true; m_securityConfiguration = std::forward<SecurityConfigurationT>(value); }
+    template<typename SecurityConfigurationT = Aws::String>
+    JobUpdate& WithSecurityConfiguration(SecurityConfigurationT&& value) { SetSecurityConfiguration(std::forward<SecurityConfigurationT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Specifies the configuration properties of a job notification.</p>
      */
-    inline const NotificationProperty& GetNotificationProperty() const{ return m_notificationProperty; }
+    inline const NotificationProperty& GetNotificationProperty() const { return m_notificationProperty; }
     inline bool NotificationPropertyHasBeenSet() const { return m_notificationPropertyHasBeenSet; }
-    inline void SetNotificationProperty(const NotificationProperty& value) { m_notificationPropertyHasBeenSet = true; m_notificationProperty = value; }
-    inline void SetNotificationProperty(NotificationProperty&& value) { m_notificationPropertyHasBeenSet = true; m_notificationProperty = std::move(value); }
-    inline JobUpdate& WithNotificationProperty(const NotificationProperty& value) { SetNotificationProperty(value); return *this;}
-    inline JobUpdate& WithNotificationProperty(NotificationProperty&& value) { SetNotificationProperty(std::move(value)); return *this;}
+    template<typename NotificationPropertyT = NotificationProperty>
+    void SetNotificationProperty(NotificationPropertyT&& value) { m_notificationPropertyHasBeenSet = true; m_notificationProperty = std::forward<NotificationPropertyT>(value); }
+    template<typename NotificationPropertyT = NotificationProperty>
+    JobUpdate& WithNotificationProperty(NotificationPropertyT&& value) { SetNotificationProperty(std::forward<NotificationPropertyT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -366,14 +348,12 @@ namespace Model
      * in the developer guide.</p> <p>Jobs that are created without specifying a Glue
      * version default to Glue 0.9.</p>
      */
-    inline const Aws::String& GetGlueVersion() const{ return m_glueVersion; }
+    inline const Aws::String& GetGlueVersion() const { return m_glueVersion; }
     inline bool GlueVersionHasBeenSet() const { return m_glueVersionHasBeenSet; }
-    inline void SetGlueVersion(const Aws::String& value) { m_glueVersionHasBeenSet = true; m_glueVersion = value; }
-    inline void SetGlueVersion(Aws::String&& value) { m_glueVersionHasBeenSet = true; m_glueVersion = std::move(value); }
-    inline void SetGlueVersion(const char* value) { m_glueVersionHasBeenSet = true; m_glueVersion.assign(value); }
-    inline JobUpdate& WithGlueVersion(const Aws::String& value) { SetGlueVersion(value); return *this;}
-    inline JobUpdate& WithGlueVersion(Aws::String&& value) { SetGlueVersion(std::move(value)); return *this;}
-    inline JobUpdate& WithGlueVersion(const char* value) { SetGlueVersion(value); return *this;}
+    template<typename GlueVersionT = Aws::String>
+    void SetGlueVersion(GlueVersionT&& value) { m_glueVersionHasBeenSet = true; m_glueVersion = std::forward<GlueVersionT>(value); }
+    template<typename GlueVersionT = Aws::String>
+    JobUpdate& WithGlueVersion(GlueVersionT&& value) { SetGlueVersion(std::forward<GlueVersionT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -381,18 +361,16 @@ namespace Model
      * <p>The representation of a directed acyclic graph on which both the Glue Studio
      * visual component and Glue Studio code generation is based.</p>
      */
-    inline const Aws::Map<Aws::String, CodeGenConfigurationNode>& GetCodeGenConfigurationNodes() const{ return m_codeGenConfigurationNodes; }
+    inline const Aws::Map<Aws::String, CodeGenConfigurationNode>& GetCodeGenConfigurationNodes() const { return m_codeGenConfigurationNodes; }
     inline bool CodeGenConfigurationNodesHasBeenSet() const { return m_codeGenConfigurationNodesHasBeenSet; }
-    inline void SetCodeGenConfigurationNodes(const Aws::Map<Aws::String, CodeGenConfigurationNode>& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes = value; }
-    inline void SetCodeGenConfigurationNodes(Aws::Map<Aws::String, CodeGenConfigurationNode>&& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes = std::move(value); }
-    inline JobUpdate& WithCodeGenConfigurationNodes(const Aws::Map<Aws::String, CodeGenConfigurationNode>& value) { SetCodeGenConfigurationNodes(value); return *this;}
-    inline JobUpdate& WithCodeGenConfigurationNodes(Aws::Map<Aws::String, CodeGenConfigurationNode>&& value) { SetCodeGenConfigurationNodes(std::move(value)); return *this;}
-    inline JobUpdate& AddCodeGenConfigurationNodes(const Aws::String& key, const CodeGenConfigurationNode& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes.emplace(key, value); return *this; }
-    inline JobUpdate& AddCodeGenConfigurationNodes(Aws::String&& key, const CodeGenConfigurationNode& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes.emplace(std::move(key), value); return *this; }
-    inline JobUpdate& AddCodeGenConfigurationNodes(const Aws::String& key, CodeGenConfigurationNode&& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes.emplace(key, std::move(value)); return *this; }
-    inline JobUpdate& AddCodeGenConfigurationNodes(Aws::String&& key, CodeGenConfigurationNode&& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes.emplace(std::move(key), std::move(value)); return *this; }
-    inline JobUpdate& AddCodeGenConfigurationNodes(const char* key, CodeGenConfigurationNode&& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes.emplace(key, std::move(value)); return *this; }
-    inline JobUpdate& AddCodeGenConfigurationNodes(const char* key, const CodeGenConfigurationNode& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes.emplace(key, value); return *this; }
+    template<typename CodeGenConfigurationNodesT = Aws::Map<Aws::String, CodeGenConfigurationNode>>
+    void SetCodeGenConfigurationNodes(CodeGenConfigurationNodesT&& value) { m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes = std::forward<CodeGenConfigurationNodesT>(value); }
+    template<typename CodeGenConfigurationNodesT = Aws::Map<Aws::String, CodeGenConfigurationNode>>
+    JobUpdate& WithCodeGenConfigurationNodes(CodeGenConfigurationNodesT&& value) { SetCodeGenConfigurationNodes(std::forward<CodeGenConfigurationNodesT>(value)); return *this;}
+    template<typename CodeGenConfigurationNodesKeyT = Aws::String, typename CodeGenConfigurationNodesValueT = CodeGenConfigurationNode>
+    JobUpdate& AddCodeGenConfigurationNodes(CodeGenConfigurationNodesKeyT&& key, CodeGenConfigurationNodesValueT&& value) {
+      m_codeGenConfigurationNodesHasBeenSet = true; m_codeGenConfigurationNodes.emplace(std::forward<CodeGenConfigurationNodesKeyT>(key), std::forward<CodeGenConfigurationNodesValueT>(value)); return *this;
+    }
     ///@}
 
     ///@{
@@ -405,12 +383,10 @@ namespace Model
      * <code>glueetl</code> will be allowed to set <code>ExecutionClass</code> to
      * <code>FLEX</code>. The flexible execution class is available for Spark jobs.</p>
      */
-    inline const ExecutionClass& GetExecutionClass() const{ return m_executionClass; }
+    inline ExecutionClass GetExecutionClass() const { return m_executionClass; }
     inline bool ExecutionClassHasBeenSet() const { return m_executionClassHasBeenSet; }
-    inline void SetExecutionClass(const ExecutionClass& value) { m_executionClassHasBeenSet = true; m_executionClass = value; }
-    inline void SetExecutionClass(ExecutionClass&& value) { m_executionClassHasBeenSet = true; m_executionClass = std::move(value); }
-    inline JobUpdate& WithExecutionClass(const ExecutionClass& value) { SetExecutionClass(value); return *this;}
-    inline JobUpdate& WithExecutionClass(ExecutionClass&& value) { SetExecutionClass(std::move(value)); return *this;}
+    inline void SetExecutionClass(ExecutionClass value) { m_executionClassHasBeenSet = true; m_executionClass = value; }
+    inline JobUpdate& WithExecutionClass(ExecutionClass value) { SetExecutionClass(value); return *this;}
     ///@}
 
     ///@{
@@ -418,12 +394,12 @@ namespace Model
      * <p>The details for a source control configuration for a job, allowing
      * synchronization of job artifacts to or from a remote repository.</p>
      */
-    inline const SourceControlDetails& GetSourceControlDetails() const{ return m_sourceControlDetails; }
+    inline const SourceControlDetails& GetSourceControlDetails() const { return m_sourceControlDetails; }
     inline bool SourceControlDetailsHasBeenSet() const { return m_sourceControlDetailsHasBeenSet; }
-    inline void SetSourceControlDetails(const SourceControlDetails& value) { m_sourceControlDetailsHasBeenSet = true; m_sourceControlDetails = value; }
-    inline void SetSourceControlDetails(SourceControlDetails&& value) { m_sourceControlDetailsHasBeenSet = true; m_sourceControlDetails = std::move(value); }
-    inline JobUpdate& WithSourceControlDetails(const SourceControlDetails& value) { SetSourceControlDetails(value); return *this;}
-    inline JobUpdate& WithSourceControlDetails(SourceControlDetails&& value) { SetSourceControlDetails(std::move(value)); return *this;}
+    template<typename SourceControlDetailsT = SourceControlDetails>
+    void SetSourceControlDetails(SourceControlDetailsT&& value) { m_sourceControlDetailsHasBeenSet = true; m_sourceControlDetails = std::forward<SourceControlDetailsT>(value); }
+    template<typename SourceControlDetailsT = SourceControlDetails>
+    JobUpdate& WithSourceControlDetails(SourceControlDetailsT&& value) { SetSourceControlDetails(std::forward<SourceControlDetailsT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -435,21 +411,19 @@ namespace Model
      * instance, if you set up the maintenance window for Monday at 10:00AM GMT, your
      * jobs will be restarted between 10:00AM GMT to 1:00PM GMT.</p>
      */
-    inline const Aws::String& GetMaintenanceWindow() const{ return m_maintenanceWindow; }
+    inline const Aws::String& GetMaintenanceWindow() const { return m_maintenanceWindow; }
     inline bool MaintenanceWindowHasBeenSet() const { return m_maintenanceWindowHasBeenSet; }
-    inline void SetMaintenanceWindow(const Aws::String& value) { m_maintenanceWindowHasBeenSet = true; m_maintenanceWindow = value; }
-    inline void SetMaintenanceWindow(Aws::String&& value) { m_maintenanceWindowHasBeenSet = true; m_maintenanceWindow = std::move(value); }
-    inline void SetMaintenanceWindow(const char* value) { m_maintenanceWindowHasBeenSet = true; m_maintenanceWindow.assign(value); }
-    inline JobUpdate& WithMaintenanceWindow(const Aws::String& value) { SetMaintenanceWindow(value); return *this;}
-    inline JobUpdate& WithMaintenanceWindow(Aws::String&& value) { SetMaintenanceWindow(std::move(value)); return *this;}
-    inline JobUpdate& WithMaintenanceWindow(const char* value) { SetMaintenanceWindow(value); return *this;}
+    template<typename MaintenanceWindowT = Aws::String>
+    void SetMaintenanceWindow(MaintenanceWindowT&& value) { m_maintenanceWindowHasBeenSet = true; m_maintenanceWindow = std::forward<MaintenanceWindowT>(value); }
+    template<typename MaintenanceWindowT = Aws::String>
+    JobUpdate& WithMaintenanceWindow(MaintenanceWindowT&& value) { SetMaintenanceWindow(std::forward<MaintenanceWindowT>(value)); return *this;}
     ///@}
   private:
 
-    JobMode m_jobMode;
+    JobMode m_jobMode{JobMode::NOT_SET};
     bool m_jobModeHasBeenSet = false;
 
-    bool m_jobRunQueuingEnabled;
+    bool m_jobRunQueuingEnabled{false};
     bool m_jobRunQueuingEnabledHasBeenSet = false;
 
     Aws::String m_description;
@@ -476,19 +450,19 @@ namespace Model
     ConnectionsList m_connections;
     bool m_connectionsHasBeenSet = false;
 
-    int m_maxRetries;
+    int m_maxRetries{0};
     bool m_maxRetriesHasBeenSet = false;
 
-    int m_timeout;
+    int m_timeout{0};
     bool m_timeoutHasBeenSet = false;
 
-    double m_maxCapacity;
+    double m_maxCapacity{0.0};
     bool m_maxCapacityHasBeenSet = false;
 
-    WorkerType m_workerType;
+    WorkerType m_workerType{WorkerType::NOT_SET};
     bool m_workerTypeHasBeenSet = false;
 
-    int m_numberOfWorkers;
+    int m_numberOfWorkers{0};
     bool m_numberOfWorkersHasBeenSet = false;
 
     Aws::String m_securityConfiguration;
@@ -503,7 +477,7 @@ namespace Model
     Aws::Map<Aws::String, CodeGenConfigurationNode> m_codeGenConfigurationNodes;
     bool m_codeGenConfigurationNodesHasBeenSet = false;
 
-    ExecutionClass m_executionClass;
+    ExecutionClass m_executionClass{ExecutionClass::NOT_SET};
     bool m_executionClassHasBeenSet = false;
 
     SourceControlDetails m_sourceControlDetails;
