@@ -107,6 +107,19 @@ namespace Model
     S3DirectTarget& WithCompression(CompressionT&& value) { SetCompression(std::forward<CompressionT>(value)); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>Specifies the number of target partitions when writing data directly to
+     * Amazon S3.</p>
+     */
+    inline const Aws::String& GetNumberTargetPartitions() const { return m_numberTargetPartitions; }
+    inline bool NumberTargetPartitionsHasBeenSet() const { return m_numberTargetPartitionsHasBeenSet; }
+    template<typename NumberTargetPartitionsT = Aws::String>
+    void SetNumberTargetPartitions(NumberTargetPartitionsT&& value) { m_numberTargetPartitionsHasBeenSet = true; m_numberTargetPartitions = std::forward<NumberTargetPartitionsT>(value); }
+    template<typename NumberTargetPartitionsT = Aws::String>
+    S3DirectTarget& WithNumberTargetPartitions(NumberTargetPartitionsT&& value) { SetNumberTargetPartitions(std::forward<NumberTargetPartitionsT>(value)); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>Specifies the data output format for the target.</p>
@@ -145,6 +158,9 @@ namespace Model
     Aws::String m_compression;
     bool m_compressionHasBeenSet = false;
 
+    Aws::String m_numberTargetPartitions;
+    bool m_numberTargetPartitionsHasBeenSet = false;
+
     TargetFormat m_format{TargetFormat::NOT_SET};
     bool m_formatHasBeenSet = false;
 
