@@ -32,7 +32,7 @@ namespace Model
   class StartingEventBatchCondition
   {
   public:
-    AWS_GLUE_API StartingEventBatchCondition();
+    AWS_GLUE_API StartingEventBatchCondition() = default;
     AWS_GLUE_API StartingEventBatchCondition(Aws::Utils::Json::JsonView jsonValue);
     AWS_GLUE_API StartingEventBatchCondition& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_GLUE_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,7 +42,7 @@ namespace Model
     /**
      * <p>Number of events in the batch.</p>
      */
-    inline int GetBatchSize() const{ return m_batchSize; }
+    inline int GetBatchSize() const { return m_batchSize; }
     inline bool BatchSizeHasBeenSet() const { return m_batchSizeHasBeenSet; }
     inline void SetBatchSize(int value) { m_batchSizeHasBeenSet = true; m_batchSize = value; }
     inline StartingEventBatchCondition& WithBatchSize(int value) { SetBatchSize(value); return *this;}
@@ -52,17 +52,17 @@ namespace Model
     /**
      * <p>Duration of the batch window in seconds.</p>
      */
-    inline int GetBatchWindow() const{ return m_batchWindow; }
+    inline int GetBatchWindow() const { return m_batchWindow; }
     inline bool BatchWindowHasBeenSet() const { return m_batchWindowHasBeenSet; }
     inline void SetBatchWindow(int value) { m_batchWindowHasBeenSet = true; m_batchWindow = value; }
     inline StartingEventBatchCondition& WithBatchWindow(int value) { SetBatchWindow(value); return *this;}
     ///@}
   private:
 
-    int m_batchSize;
+    int m_batchSize{0};
     bool m_batchSizeHasBeenSet = false;
 
-    int m_batchWindow;
+    int m_batchWindow{0};
     bool m_batchWindowHasBeenSet = false;
   };
 
