@@ -33,7 +33,7 @@ namespace Model
   class FunctionDefaultConfig
   {
   public:
-    AWS_GREENGRASS_API FunctionDefaultConfig();
+    AWS_GREENGRASS_API FunctionDefaultConfig() = default;
     AWS_GREENGRASS_API FunctionDefaultConfig(Aws::Utils::Json::JsonView jsonValue);
     AWS_GREENGRASS_API FunctionDefaultConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_GREENGRASS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -41,12 +41,12 @@ namespace Model
 
     ///@{
     
-    inline const FunctionDefaultExecutionConfig& GetExecution() const{ return m_execution; }
+    inline const FunctionDefaultExecutionConfig& GetExecution() const { return m_execution; }
     inline bool ExecutionHasBeenSet() const { return m_executionHasBeenSet; }
-    inline void SetExecution(const FunctionDefaultExecutionConfig& value) { m_executionHasBeenSet = true; m_execution = value; }
-    inline void SetExecution(FunctionDefaultExecutionConfig&& value) { m_executionHasBeenSet = true; m_execution = std::move(value); }
-    inline FunctionDefaultConfig& WithExecution(const FunctionDefaultExecutionConfig& value) { SetExecution(value); return *this;}
-    inline FunctionDefaultConfig& WithExecution(FunctionDefaultExecutionConfig&& value) { SetExecution(std::move(value)); return *this;}
+    template<typename ExecutionT = FunctionDefaultExecutionConfig>
+    void SetExecution(ExecutionT&& value) { m_executionHasBeenSet = true; m_execution = std::forward<ExecutionT>(value); }
+    template<typename ExecutionT = FunctionDefaultExecutionConfig>
+    FunctionDefaultConfig& WithExecution(ExecutionT&& value) { SetExecution(std::forward<ExecutionT>(value)); return *this;}
     ///@}
   private:
 
