@@ -32,7 +32,7 @@ namespace Model
   class BlockPublicAccess
   {
   public:
-    AWS_GUARDDUTY_API BlockPublicAccess();
+    AWS_GUARDDUTY_API BlockPublicAccess() = default;
     AWS_GUARDDUTY_API BlockPublicAccess(Aws::Utils::Json::JsonView jsonValue);
     AWS_GUARDDUTY_API BlockPublicAccess& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_GUARDDUTY_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,7 +43,7 @@ namespace Model
      * <p>Indicates if S3 Block Public Access is set to
      * <code>IgnorePublicAcls</code>.</p>
      */
-    inline bool GetIgnorePublicAcls() const{ return m_ignorePublicAcls; }
+    inline bool GetIgnorePublicAcls() const { return m_ignorePublicAcls; }
     inline bool IgnorePublicAclsHasBeenSet() const { return m_ignorePublicAclsHasBeenSet; }
     inline void SetIgnorePublicAcls(bool value) { m_ignorePublicAclsHasBeenSet = true; m_ignorePublicAcls = value; }
     inline BlockPublicAccess& WithIgnorePublicAcls(bool value) { SetIgnorePublicAcls(value); return *this;}
@@ -54,7 +54,7 @@ namespace Model
      * <p>Indicates if S3 Block Public Access is set to
      * <code>RestrictPublicBuckets</code>.</p>
      */
-    inline bool GetRestrictPublicBuckets() const{ return m_restrictPublicBuckets; }
+    inline bool GetRestrictPublicBuckets() const { return m_restrictPublicBuckets; }
     inline bool RestrictPublicBucketsHasBeenSet() const { return m_restrictPublicBucketsHasBeenSet; }
     inline void SetRestrictPublicBuckets(bool value) { m_restrictPublicBucketsHasBeenSet = true; m_restrictPublicBuckets = value; }
     inline BlockPublicAccess& WithRestrictPublicBuckets(bool value) { SetRestrictPublicBuckets(value); return *this;}
@@ -65,7 +65,7 @@ namespace Model
      * <p>Indicates if S3 Block Public Access is set to
      * <code>BlockPublicAcls</code>.</p>
      */
-    inline bool GetBlockPublicAcls() const{ return m_blockPublicAcls; }
+    inline bool GetBlockPublicAcls() const { return m_blockPublicAcls; }
     inline bool BlockPublicAclsHasBeenSet() const { return m_blockPublicAclsHasBeenSet; }
     inline void SetBlockPublicAcls(bool value) { m_blockPublicAclsHasBeenSet = true; m_blockPublicAcls = value; }
     inline BlockPublicAccess& WithBlockPublicAcls(bool value) { SetBlockPublicAcls(value); return *this;}
@@ -76,23 +76,23 @@ namespace Model
      * <p>Indicates if S3 Block Public Access is set to
      * <code>BlockPublicPolicy</code>.</p>
      */
-    inline bool GetBlockPublicPolicy() const{ return m_blockPublicPolicy; }
+    inline bool GetBlockPublicPolicy() const { return m_blockPublicPolicy; }
     inline bool BlockPublicPolicyHasBeenSet() const { return m_blockPublicPolicyHasBeenSet; }
     inline void SetBlockPublicPolicy(bool value) { m_blockPublicPolicyHasBeenSet = true; m_blockPublicPolicy = value; }
     inline BlockPublicAccess& WithBlockPublicPolicy(bool value) { SetBlockPublicPolicy(value); return *this;}
     ///@}
   private:
 
-    bool m_ignorePublicAcls;
+    bool m_ignorePublicAcls{false};
     bool m_ignorePublicAclsHasBeenSet = false;
 
-    bool m_restrictPublicBuckets;
+    bool m_restrictPublicBuckets{false};
     bool m_restrictPublicBucketsHasBeenSet = false;
 
-    bool m_blockPublicAcls;
+    bool m_blockPublicAcls{false};
     bool m_blockPublicAclsHasBeenSet = false;
 
-    bool m_blockPublicPolicy;
+    bool m_blockPublicPolicy{false};
     bool m_blockPublicPolicyHasBeenSet = false;
   };
 
