@@ -31,7 +31,7 @@ namespace Model
   class FilterCondition
   {
   public:
-    AWS_GUARDDUTY_API FilterCondition();
+    AWS_GUARDDUTY_API FilterCondition() = default;
     AWS_GUARDDUTY_API FilterCondition(Aws::Utils::Json::JsonView jsonValue);
     AWS_GUARDDUTY_API FilterCondition& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_GUARDDUTY_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,14 +42,12 @@ namespace Model
      * <p>Represents an <i>equal</i> <b/> condition to be applied to a single field
      * when querying for scan entries.</p>
      */
-    inline const Aws::String& GetEqualsValue() const{ return m_equalsValue; }
+    inline const Aws::String& GetEqualsValue() const { return m_equalsValue; }
     inline bool EqualsValueHasBeenSet() const { return m_equalsValueHasBeenSet; }
-    inline void SetEqualsValue(const Aws::String& value) { m_equalsValueHasBeenSet = true; m_equalsValue = value; }
-    inline void SetEqualsValue(Aws::String&& value) { m_equalsValueHasBeenSet = true; m_equalsValue = std::move(value); }
-    inline void SetEqualsValue(const char* value) { m_equalsValueHasBeenSet = true; m_equalsValue.assign(value); }
-    inline FilterCondition& WithEqualsValue(const Aws::String& value) { SetEqualsValue(value); return *this;}
-    inline FilterCondition& WithEqualsValue(Aws::String&& value) { SetEqualsValue(std::move(value)); return *this;}
-    inline FilterCondition& WithEqualsValue(const char* value) { SetEqualsValue(value); return *this;}
+    template<typename EqualsValueT = Aws::String>
+    void SetEqualsValue(EqualsValueT&& value) { m_equalsValueHasBeenSet = true; m_equalsValue = std::forward<EqualsValueT>(value); }
+    template<typename EqualsValueT = Aws::String>
+    FilterCondition& WithEqualsValue(EqualsValueT&& value) { SetEqualsValue(std::forward<EqualsValueT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -57,7 +55,7 @@ namespace Model
      * <p>Represents a <i>greater than</i> condition to be applied to a single field
      * when querying for scan entries.</p>
      */
-    inline long long GetGreaterThan() const{ return m_greaterThan; }
+    inline long long GetGreaterThan() const { return m_greaterThan; }
     inline bool GreaterThanHasBeenSet() const { return m_greaterThanHasBeenSet; }
     inline void SetGreaterThan(long long value) { m_greaterThanHasBeenSet = true; m_greaterThan = value; }
     inline FilterCondition& WithGreaterThan(long long value) { SetGreaterThan(value); return *this;}
@@ -68,7 +66,7 @@ namespace Model
      * <p>Represents a <i>less than</i> condition to be applied to a single field when
      * querying for scan entries.</p>
      */
-    inline long long GetLessThan() const{ return m_lessThan; }
+    inline long long GetLessThan() const { return m_lessThan; }
     inline bool LessThanHasBeenSet() const { return m_lessThanHasBeenSet; }
     inline void SetLessThan(long long value) { m_lessThanHasBeenSet = true; m_lessThan = value; }
     inline FilterCondition& WithLessThan(long long value) { SetLessThan(value); return *this;}
@@ -78,10 +76,10 @@ namespace Model
     Aws::String m_equalsValue;
     bool m_equalsValueHasBeenSet = false;
 
-    long long m_greaterThan;
+    long long m_greaterThan{0};
     bool m_greaterThanHasBeenSet = false;
 
-    long long m_lessThan;
+    long long m_lessThan{0};
     bool m_lessThanHasBeenSet = false;
   };
 
