@@ -22,7 +22,7 @@ namespace Model
   class DescribeEventDetailsRequest : public HealthRequest
   {
   public:
-    AWS_HEALTH_API DescribeEventDetailsRequest();
+    AWS_HEALTH_API DescribeEventDetailsRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -42,15 +42,14 @@ namespace Model
      * "arn:aws:health:us-west-1::event/EBS/AWS_EBS_LOST_VOLUME/AWS_EBS_LOST_VOLUME_CHI789_JKL101"</code>
      * </p>
      */
-    inline const Aws::Vector<Aws::String>& GetEventArns() const{ return m_eventArns; }
+    inline const Aws::Vector<Aws::String>& GetEventArns() const { return m_eventArns; }
     inline bool EventArnsHasBeenSet() const { return m_eventArnsHasBeenSet; }
-    inline void SetEventArns(const Aws::Vector<Aws::String>& value) { m_eventArnsHasBeenSet = true; m_eventArns = value; }
-    inline void SetEventArns(Aws::Vector<Aws::String>&& value) { m_eventArnsHasBeenSet = true; m_eventArns = std::move(value); }
-    inline DescribeEventDetailsRequest& WithEventArns(const Aws::Vector<Aws::String>& value) { SetEventArns(value); return *this;}
-    inline DescribeEventDetailsRequest& WithEventArns(Aws::Vector<Aws::String>&& value) { SetEventArns(std::move(value)); return *this;}
-    inline DescribeEventDetailsRequest& AddEventArns(const Aws::String& value) { m_eventArnsHasBeenSet = true; m_eventArns.push_back(value); return *this; }
-    inline DescribeEventDetailsRequest& AddEventArns(Aws::String&& value) { m_eventArnsHasBeenSet = true; m_eventArns.push_back(std::move(value)); return *this; }
-    inline DescribeEventDetailsRequest& AddEventArns(const char* value) { m_eventArnsHasBeenSet = true; m_eventArns.push_back(value); return *this; }
+    template<typename EventArnsT = Aws::Vector<Aws::String>>
+    void SetEventArns(EventArnsT&& value) { m_eventArnsHasBeenSet = true; m_eventArns = std::forward<EventArnsT>(value); }
+    template<typename EventArnsT = Aws::Vector<Aws::String>>
+    DescribeEventDetailsRequest& WithEventArns(EventArnsT&& value) { SetEventArns(std::forward<EventArnsT>(value)); return *this;}
+    template<typename EventArnsT = Aws::String>
+    DescribeEventDetailsRequest& AddEventArns(EventArnsT&& value) { m_eventArnsHasBeenSet = true; m_eventArns.emplace_back(std::forward<EventArnsT>(value)); return *this; }
     ///@}
 
     ///@{
@@ -58,14 +57,12 @@ namespace Model
      * <p>The locale (language) to return information in. English (en) is the default
      * and the only supported value at this time.</p>
      */
-    inline const Aws::String& GetLocale() const{ return m_locale; }
+    inline const Aws::String& GetLocale() const { return m_locale; }
     inline bool LocaleHasBeenSet() const { return m_localeHasBeenSet; }
-    inline void SetLocale(const Aws::String& value) { m_localeHasBeenSet = true; m_locale = value; }
-    inline void SetLocale(Aws::String&& value) { m_localeHasBeenSet = true; m_locale = std::move(value); }
-    inline void SetLocale(const char* value) { m_localeHasBeenSet = true; m_locale.assign(value); }
-    inline DescribeEventDetailsRequest& WithLocale(const Aws::String& value) { SetLocale(value); return *this;}
-    inline DescribeEventDetailsRequest& WithLocale(Aws::String&& value) { SetLocale(std::move(value)); return *this;}
-    inline DescribeEventDetailsRequest& WithLocale(const char* value) { SetLocale(value); return *this;}
+    template<typename LocaleT = Aws::String>
+    void SetLocale(LocaleT&& value) { m_localeHasBeenSet = true; m_locale = std::forward<LocaleT>(value); }
+    template<typename LocaleT = Aws::String>
+    DescribeEventDetailsRequest& WithLocale(LocaleT&& value) { SetLocale(std::forward<LocaleT>(value)); return *this;}
     ///@}
   private:
 
