@@ -147,8 +147,8 @@ namespace Model
     Aws::Utils::DateTime m_updateAt{};
     bool m_updateAtHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
   };
 
 } // namespace Model
