@@ -158,8 +158,8 @@ namespace Model
     LifecyclePolicyResourceSelection m_resourceSelection;
     bool m_resourceSelectionHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
   };
 
 } // namespace Model
