@@ -34,7 +34,7 @@ namespace Model
   class LimitExceededException
   {
   public:
-    AWS_INSPECTOR_API LimitExceededException();
+    AWS_INSPECTOR_API LimitExceededException() = default;
     AWS_INSPECTOR_API LimitExceededException(Aws::Utils::Json::JsonView jsonValue);
     AWS_INSPECTOR_API LimitExceededException& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_INSPECTOR_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,33 +44,29 @@ namespace Model
     /**
      * <p>Details of the exception error.</p>
      */
-    inline const Aws::String& GetMessage() const{ return m_message; }
+    inline const Aws::String& GetMessage() const { return m_message; }
     inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }
-    inline void SetMessage(const Aws::String& value) { m_messageHasBeenSet = true; m_message = value; }
-    inline void SetMessage(Aws::String&& value) { m_messageHasBeenSet = true; m_message = std::move(value); }
-    inline void SetMessage(const char* value) { m_messageHasBeenSet = true; m_message.assign(value); }
-    inline LimitExceededException& WithMessage(const Aws::String& value) { SetMessage(value); return *this;}
-    inline LimitExceededException& WithMessage(Aws::String&& value) { SetMessage(std::move(value)); return *this;}
-    inline LimitExceededException& WithMessage(const char* value) { SetMessage(value); return *this;}
+    template<typename MessageT = Aws::String>
+    void SetMessage(MessageT&& value) { m_messageHasBeenSet = true; m_message = std::forward<MessageT>(value); }
+    template<typename MessageT = Aws::String>
+    LimitExceededException& WithMessage(MessageT&& value) { SetMessage(std::forward<MessageT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Code that indicates the type of error that is generated.</p>
      */
-    inline const LimitExceededErrorCode& GetErrorCode() const{ return m_errorCode; }
+    inline LimitExceededErrorCode GetErrorCode() const { return m_errorCode; }
     inline bool ErrorCodeHasBeenSet() const { return m_errorCodeHasBeenSet; }
-    inline void SetErrorCode(const LimitExceededErrorCode& value) { m_errorCodeHasBeenSet = true; m_errorCode = value; }
-    inline void SetErrorCode(LimitExceededErrorCode&& value) { m_errorCodeHasBeenSet = true; m_errorCode = std::move(value); }
-    inline LimitExceededException& WithErrorCode(const LimitExceededErrorCode& value) { SetErrorCode(value); return *this;}
-    inline LimitExceededException& WithErrorCode(LimitExceededErrorCode&& value) { SetErrorCode(std::move(value)); return *this;}
+    inline void SetErrorCode(LimitExceededErrorCode value) { m_errorCodeHasBeenSet = true; m_errorCode = value; }
+    inline LimitExceededException& WithErrorCode(LimitExceededErrorCode value) { SetErrorCode(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>You can immediately retry your request.</p>
      */
-    inline bool GetCanRetry() const{ return m_canRetry; }
+    inline bool GetCanRetry() const { return m_canRetry; }
     inline bool CanRetryHasBeenSet() const { return m_canRetryHasBeenSet; }
     inline void SetCanRetry(bool value) { m_canRetryHasBeenSet = true; m_canRetry = value; }
     inline LimitExceededException& WithCanRetry(bool value) { SetCanRetry(value); return *this;}
@@ -80,10 +76,10 @@ namespace Model
     Aws::String m_message;
     bool m_messageHasBeenSet = false;
 
-    LimitExceededErrorCode m_errorCode;
+    LimitExceededErrorCode m_errorCode{LimitExceededErrorCode::NOT_SET};
     bool m_errorCodeHasBeenSet = false;
 
-    bool m_canRetry;
+    bool m_canRetry{false};
     bool m_canRetryHasBeenSet = false;
   };
 
