@@ -36,6 +36,17 @@ namespace Model
     AWS_INSPECTOR2_API Aws::Utils::Json::JsonValue Jsonize() const;
 
 
+    ///@{
+    /**
+     * <p>Represents whether code repository scans are automatically enabled for new
+     * members of your Amazon Inspector organization.</p>
+     */
+    inline bool GetCodeRepository() const { return m_codeRepository; }
+    inline bool CodeRepositoryHasBeenSet() const { return m_codeRepositoryHasBeenSet; }
+    inline void SetCodeRepository(bool value) { m_codeRepositoryHasBeenSet = true; m_codeRepository = value; }
+    inline AutoEnable& WithCodeRepository(bool value) { SetCodeRepository(value); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>Represents whether Amazon EC2 scans are automatically enabled for new members
@@ -73,8 +84,7 @@ namespace Model
     ///@{
     /**
      * <p>Represents whether Lambda code scans are automatically enabled for new
-     * members of your Amazon Inspector organization. <pre><code> &lt;/p&gt;
-     * </code></pre>
+     * members of your Amazon Inspector organization. </p>
      */
     inline bool GetLambdaCode() const { return m_lambdaCode; }
     inline bool LambdaCodeHasBeenSet() const { return m_lambdaCodeHasBeenSet; }
@@ -83,6 +93,9 @@ namespace Model
     ///@}
   private:
 
+    bool m_codeRepository{false};
+    bool m_codeRepositoryHasBeenSet = false;
+
     bool m_ec2{false};
     bool m_ec2HasBeenSet = false;
 
