@@ -23,7 +23,7 @@ namespace Model
   class CreateFindingsReportRequest : public Inspector2Request
   {
   public:
-    AWS_INSPECTOR2_API CreateFindingsReportRequest();
+    AWS_INSPECTOR2_API CreateFindingsReportRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -38,43 +38,41 @@ namespace Model
     /**
      * <p>The filter criteria to apply to the results of the finding report.</p>
      */
-    inline const FilterCriteria& GetFilterCriteria() const{ return m_filterCriteria; }
+    inline const FilterCriteria& GetFilterCriteria() const { return m_filterCriteria; }
     inline bool FilterCriteriaHasBeenSet() const { return m_filterCriteriaHasBeenSet; }
-    inline void SetFilterCriteria(const FilterCriteria& value) { m_filterCriteriaHasBeenSet = true; m_filterCriteria = value; }
-    inline void SetFilterCriteria(FilterCriteria&& value) { m_filterCriteriaHasBeenSet = true; m_filterCriteria = std::move(value); }
-    inline CreateFindingsReportRequest& WithFilterCriteria(const FilterCriteria& value) { SetFilterCriteria(value); return *this;}
-    inline CreateFindingsReportRequest& WithFilterCriteria(FilterCriteria&& value) { SetFilterCriteria(std::move(value)); return *this;}
+    template<typename FilterCriteriaT = FilterCriteria>
+    void SetFilterCriteria(FilterCriteriaT&& value) { m_filterCriteriaHasBeenSet = true; m_filterCriteria = std::forward<FilterCriteriaT>(value); }
+    template<typename FilterCriteriaT = FilterCriteria>
+    CreateFindingsReportRequest& WithFilterCriteria(FilterCriteriaT&& value) { SetFilterCriteria(std::forward<FilterCriteriaT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The format to generate the report in.</p>
      */
-    inline const ReportFormat& GetReportFormat() const{ return m_reportFormat; }
+    inline ReportFormat GetReportFormat() const { return m_reportFormat; }
     inline bool ReportFormatHasBeenSet() const { return m_reportFormatHasBeenSet; }
-    inline void SetReportFormat(const ReportFormat& value) { m_reportFormatHasBeenSet = true; m_reportFormat = value; }
-    inline void SetReportFormat(ReportFormat&& value) { m_reportFormatHasBeenSet = true; m_reportFormat = std::move(value); }
-    inline CreateFindingsReportRequest& WithReportFormat(const ReportFormat& value) { SetReportFormat(value); return *this;}
-    inline CreateFindingsReportRequest& WithReportFormat(ReportFormat&& value) { SetReportFormat(std::move(value)); return *this;}
+    inline void SetReportFormat(ReportFormat value) { m_reportFormatHasBeenSet = true; m_reportFormat = value; }
+    inline CreateFindingsReportRequest& WithReportFormat(ReportFormat value) { SetReportFormat(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The Amazon S3 export destination for the report.</p>
      */
-    inline const Destination& GetS3Destination() const{ return m_s3Destination; }
+    inline const Destination& GetS3Destination() const { return m_s3Destination; }
     inline bool S3DestinationHasBeenSet() const { return m_s3DestinationHasBeenSet; }
-    inline void SetS3Destination(const Destination& value) { m_s3DestinationHasBeenSet = true; m_s3Destination = value; }
-    inline void SetS3Destination(Destination&& value) { m_s3DestinationHasBeenSet = true; m_s3Destination = std::move(value); }
-    inline CreateFindingsReportRequest& WithS3Destination(const Destination& value) { SetS3Destination(value); return *this;}
-    inline CreateFindingsReportRequest& WithS3Destination(Destination&& value) { SetS3Destination(std::move(value)); return *this;}
+    template<typename S3DestinationT = Destination>
+    void SetS3Destination(S3DestinationT&& value) { m_s3DestinationHasBeenSet = true; m_s3Destination = std::forward<S3DestinationT>(value); }
+    template<typename S3DestinationT = Destination>
+    CreateFindingsReportRequest& WithS3Destination(S3DestinationT&& value) { SetS3Destination(std::forward<S3DestinationT>(value)); return *this;}
     ///@}
   private:
 
     FilterCriteria m_filterCriteria;
     bool m_filterCriteriaHasBeenSet = false;
 
-    ReportFormat m_reportFormat;
+    ReportFormat m_reportFormat{ReportFormat::NOT_SET};
     bool m_reportFormatHasBeenSet = false;
 
     Destination m_s3Destination;
