@@ -42,7 +42,12 @@ namespace Model
     DEEP_INSPECTION_NO_INVENTORY,
     AGENTLESS_INSTANCE_STORAGE_LIMIT_EXCEEDED,
     AGENTLESS_INSTANCE_COLLECTION_TIME_LIMIT_EXCEEDED,
-    PENDING_REVIVAL_SCAN
+    PENDING_REVIVAL_SCAN,
+    INTEGRATION_CONNECTION_LOST,
+    ACCESS_DENIED_TO_ENCRYPTION_KEY,
+    UNSUPPORTED_LANGUAGE,
+    NO_SCAN_CONFIGURATION_ASSOCIATED,
+    SCAN_IN_PROGRESS
   };
 
 namespace ScanStatusReasonMapper
