@@ -123,8 +123,8 @@ namespace Model
     long long m_executionTimeoutSeconds{0};
     bool m_executionTimeoutSecondsHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
   };
 
 } // namespace Model
