@@ -19,7 +19,7 @@ namespace Model
   class GetCustomEndpointRequest : public IoTManagedIntegrationsRequest
   {
   public:
-    AWS_IOTMANAGEDINTEGRATIONS_API GetCustomEndpointRequest();
+    AWS_IOTMANAGEDINTEGRATIONS_API GetCustomEndpointRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
