@@ -116,15 +116,15 @@ namespace Model
 
     ///@{
     /**
-     * <p>The id of the connector policy.</p>  <p>This parameter is used for
-     * cloud-to-cloud devices only.</p> 
+     * <p>The identifier of the connector destination associated with this managed
+     * thing, if applicable.</p>
      */
-    inline const Aws::String& GetConnectorPolicyId() const { return m_connectorPolicyId; }
-    inline bool ConnectorPolicyIdHasBeenSet() const { return m_connectorPolicyIdHasBeenSet; }
-    template<typename ConnectorPolicyIdT = Aws::String>
-    void SetConnectorPolicyId(ConnectorPolicyIdT&& value) { m_connectorPolicyIdHasBeenSet = true; m_connectorPolicyId = std::forward<ConnectorPolicyIdT>(value); }
-    template<typename ConnectorPolicyIdT = Aws::String>
-    ManagedThingSummary& WithConnectorPolicyId(ConnectorPolicyIdT&& value) { SetConnectorPolicyId(std::forward<ConnectorPolicyIdT>(value)); return *this;}
+    inline const Aws::String& GetConnectorDestinationId() const { return m_connectorDestinationId; }
+    inline bool ConnectorDestinationIdHasBeenSet() const { return m_connectorDestinationIdHasBeenSet; }
+    template<typename ConnectorDestinationIdT = Aws::String>
+    void SetConnectorDestinationId(ConnectorDestinationIdT&& value) { m_connectorDestinationIdHasBeenSet = true; m_connectorDestinationId = std::forward<ConnectorDestinationIdT>(value); }
+    template<typename ConnectorDestinationIdT = Aws::String>
+    ManagedThingSummary& WithConnectorDestinationId(ConnectorDestinationIdT&& value) { SetConnectorDestinationId(std::forward<ConnectorDestinationIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -277,8 +277,8 @@ namespace Model
     Aws::String m_connectorDeviceId;
     bool m_connectorDeviceIdHasBeenSet = false;
 
-    Aws::String m_connectorPolicyId;
-    bool m_connectorPolicyIdHasBeenSet = false;
+    Aws::String m_connectorDestinationId;
+    bool m_connectorDestinationIdHasBeenSet = false;
 
     Aws::String m_model;
     bool m_modelHasBeenSet = false;
