@@ -24,7 +24,7 @@ namespace Model
   class DeprecateThingTypeRequest : public IoTRequest
   {
   public:
-    AWS_IOT_API DeprecateThingTypeRequest();
+    AWS_IOT_API DeprecateThingTypeRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -39,14 +39,12 @@ namespace Model
     /**
      * <p>The name of the thing type to deprecate.</p>
      */
-    inline const Aws::String& GetThingTypeName() const{ return m_thingTypeName; }
+    inline const Aws::String& GetThingTypeName() const { return m_thingTypeName; }
     inline bool ThingTypeNameHasBeenSet() const { return m_thingTypeNameHasBeenSet; }
-    inline void SetThingTypeName(const Aws::String& value) { m_thingTypeNameHasBeenSet = true; m_thingTypeName = value; }
-    inline void SetThingTypeName(Aws::String&& value) { m_thingTypeNameHasBeenSet = true; m_thingTypeName = std::move(value); }
-    inline void SetThingTypeName(const char* value) { m_thingTypeNameHasBeenSet = true; m_thingTypeName.assign(value); }
-    inline DeprecateThingTypeRequest& WithThingTypeName(const Aws::String& value) { SetThingTypeName(value); return *this;}
-    inline DeprecateThingTypeRequest& WithThingTypeName(Aws::String&& value) { SetThingTypeName(std::move(value)); return *this;}
-    inline DeprecateThingTypeRequest& WithThingTypeName(const char* value) { SetThingTypeName(value); return *this;}
+    template<typename ThingTypeNameT = Aws::String>
+    void SetThingTypeName(ThingTypeNameT&& value) { m_thingTypeNameHasBeenSet = true; m_thingTypeName = std::forward<ThingTypeNameT>(value); }
+    template<typename ThingTypeNameT = Aws::String>
+    DeprecateThingTypeRequest& WithThingTypeName(ThingTypeNameT&& value) { SetThingTypeName(std::forward<ThingTypeNameT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -54,7 +52,7 @@ namespace Model
      * <p>Whether to undeprecate a deprecated thing type. If <b>true</b>, the thing
      * type will not be deprecated anymore and you can associate it with things.</p>
      */
-    inline bool GetUndoDeprecate() const{ return m_undoDeprecate; }
+    inline bool GetUndoDeprecate() const { return m_undoDeprecate; }
     inline bool UndoDeprecateHasBeenSet() const { return m_undoDeprecateHasBeenSet; }
     inline void SetUndoDeprecate(bool value) { m_undoDeprecateHasBeenSet = true; m_undoDeprecate = value; }
     inline DeprecateThingTypeRequest& WithUndoDeprecate(bool value) { SetUndoDeprecate(value); return *this;}
@@ -64,7 +62,7 @@ namespace Model
     Aws::String m_thingTypeName;
     bool m_thingTypeNameHasBeenSet = false;
 
-    bool m_undoDeprecate;
+    bool m_undoDeprecate{false};
     bool m_undoDeprecateHasBeenSet = false;
   };
 
