@@ -33,7 +33,7 @@ namespace Model
   class JobExecutionsRetryConfig
   {
   public:
-    AWS_IOT_API JobExecutionsRetryConfig();
+    AWS_IOT_API JobExecutionsRetryConfig() = default;
     AWS_IOT_API JobExecutionsRetryConfig(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOT_API JobExecutionsRetryConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOT_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,14 +44,14 @@ namespace Model
      * <p>The list of criteria that determines how many retries are allowed for each
      * failure type for a job.</p>
      */
-    inline const Aws::Vector<RetryCriteria>& GetCriteriaList() const{ return m_criteriaList; }
+    inline const Aws::Vector<RetryCriteria>& GetCriteriaList() const { return m_criteriaList; }
     inline bool CriteriaListHasBeenSet() const { return m_criteriaListHasBeenSet; }
-    inline void SetCriteriaList(const Aws::Vector<RetryCriteria>& value) { m_criteriaListHasBeenSet = true; m_criteriaList = value; }
-    inline void SetCriteriaList(Aws::Vector<RetryCriteria>&& value) { m_criteriaListHasBeenSet = true; m_criteriaList = std::move(value); }
-    inline JobExecutionsRetryConfig& WithCriteriaList(const Aws::Vector<RetryCriteria>& value) { SetCriteriaList(value); return *this;}
-    inline JobExecutionsRetryConfig& WithCriteriaList(Aws::Vector<RetryCriteria>&& value) { SetCriteriaList(std::move(value)); return *this;}
-    inline JobExecutionsRetryConfig& AddCriteriaList(const RetryCriteria& value) { m_criteriaListHasBeenSet = true; m_criteriaList.push_back(value); return *this; }
-    inline JobExecutionsRetryConfig& AddCriteriaList(RetryCriteria&& value) { m_criteriaListHasBeenSet = true; m_criteriaList.push_back(std::move(value)); return *this; }
+    template<typename CriteriaListT = Aws::Vector<RetryCriteria>>
+    void SetCriteriaList(CriteriaListT&& value) { m_criteriaListHasBeenSet = true; m_criteriaList = std::forward<CriteriaListT>(value); }
+    template<typename CriteriaListT = Aws::Vector<RetryCriteria>>
+    JobExecutionsRetryConfig& WithCriteriaList(CriteriaListT&& value) { SetCriteriaList(std::forward<CriteriaListT>(value)); return *this;}
+    template<typename CriteriaListT = RetryCriteria>
+    JobExecutionsRetryConfig& AddCriteriaList(CriteriaListT&& value) { m_criteriaListHasBeenSet = true; m_criteriaList.emplace_back(std::forward<CriteriaListT>(value)); return *this; }
     ///@}
   private:
 
