@@ -34,7 +34,7 @@ namespace Model
   class ThingTypeMetadata
   {
   public:
-    AWS_IOT_API ThingTypeMetadata();
+    AWS_IOT_API ThingTypeMetadata() = default;
     AWS_IOT_API ThingTypeMetadata(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOT_API ThingTypeMetadata& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOT_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -45,7 +45,7 @@ namespace Model
      * <p>Whether the thing type is deprecated. If <b>true</b>, no new things could be
      * associated with this type.</p>
      */
-    inline bool GetDeprecated() const{ return m_deprecated; }
+    inline bool GetDeprecated() const { return m_deprecated; }
     inline bool DeprecatedHasBeenSet() const { return m_deprecatedHasBeenSet; }
     inline void SetDeprecated(bool value) { m_deprecatedHasBeenSet = true; m_deprecated = value; }
     inline ThingTypeMetadata& WithDeprecated(bool value) { SetDeprecated(value); return *this;}
@@ -55,34 +55,34 @@ namespace Model
     /**
      * <p>The date and time when the thing type was deprecated.</p>
      */
-    inline const Aws::Utils::DateTime& GetDeprecationDate() const{ return m_deprecationDate; }
+    inline const Aws::Utils::DateTime& GetDeprecationDate() const { return m_deprecationDate; }
     inline bool DeprecationDateHasBeenSet() const { return m_deprecationDateHasBeenSet; }
-    inline void SetDeprecationDate(const Aws::Utils::DateTime& value) { m_deprecationDateHasBeenSet = true; m_deprecationDate = value; }
-    inline void SetDeprecationDate(Aws::Utils::DateTime&& value) { m_deprecationDateHasBeenSet = true; m_deprecationDate = std::move(value); }
-    inline ThingTypeMetadata& WithDeprecationDate(const Aws::Utils::DateTime& value) { SetDeprecationDate(value); return *this;}
-    inline ThingTypeMetadata& WithDeprecationDate(Aws::Utils::DateTime&& value) { SetDeprecationDate(std::move(value)); return *this;}
+    template<typename DeprecationDateT = Aws::Utils::DateTime>
+    void SetDeprecationDate(DeprecationDateT&& value) { m_deprecationDateHasBeenSet = true; m_deprecationDate = std::forward<DeprecationDateT>(value); }
+    template<typename DeprecationDateT = Aws::Utils::DateTime>
+    ThingTypeMetadata& WithDeprecationDate(DeprecationDateT&& value) { SetDeprecationDate(std::forward<DeprecationDateT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The date and time when the thing type was created.</p>
      */
-    inline const Aws::Utils::DateTime& GetCreationDate() const{ return m_creationDate; }
+    inline const Aws::Utils::DateTime& GetCreationDate() const { return m_creationDate; }
     inline bool CreationDateHasBeenSet() const { return m_creationDateHasBeenSet; }
-    inline void SetCreationDate(const Aws::Utils::DateTime& value) { m_creationDateHasBeenSet = true; m_creationDate = value; }
-    inline void SetCreationDate(Aws::Utils::DateTime&& value) { m_creationDateHasBeenSet = true; m_creationDate = std::move(value); }
-    inline ThingTypeMetadata& WithCreationDate(const Aws::Utils::DateTime& value) { SetCreationDate(value); return *this;}
-    inline ThingTypeMetadata& WithCreationDate(Aws::Utils::DateTime&& value) { SetCreationDate(std::move(value)); return *this;}
+    template<typename CreationDateT = Aws::Utils::DateTime>
+    void SetCreationDate(CreationDateT&& value) { m_creationDateHasBeenSet = true; m_creationDate = std::forward<CreationDateT>(value); }
+    template<typename CreationDateT = Aws::Utils::DateTime>
+    ThingTypeMetadata& WithCreationDate(CreationDateT&& value) { SetCreationDate(std::forward<CreationDateT>(value)); return *this;}
     ///@}
   private:
 
-    bool m_deprecated;
+    bool m_deprecated{false};
     bool m_deprecatedHasBeenSet = false;
 
-    Aws::Utils::DateTime m_deprecationDate;
+    Aws::Utils::DateTime m_deprecationDate{};
     bool m_deprecationDateHasBeenSet = false;
 
-    Aws::Utils::DateTime m_creationDate;
+    Aws::Utils::DateTime m_creationDate{};
     bool m_creationDateHasBeenSet = false;
   };
 
