@@ -22,7 +22,7 @@ namespace Model
   class ListSignalCatalogNodesRequest : public IoTFleetWiseRequest
   {
   public:
-    AWS_IOTFLEETWISE_API ListSignalCatalogNodesRequest();
+    AWS_IOTFLEETWISE_API ListSignalCatalogNodesRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -39,14 +39,12 @@ namespace Model
     /**
      * <p> The name of the signal catalog to list information about. </p>
      */
-    inline const Aws::String& GetName() const{ return m_name; }
+    inline const Aws::String& GetName() const { return m_name; }
     inline bool NameHasBeenSet() const { return m_nameHasBeenSet; }
-    inline void SetName(const Aws::String& value) { m_nameHasBeenSet = true; m_name = value; }
-    inline void SetName(Aws::String&& value) { m_nameHasBeenSet = true; m_name = std::move(value); }
-    inline void SetName(const char* value) { m_nameHasBeenSet = true; m_name.assign(value); }
-    inline ListSignalCatalogNodesRequest& WithName(const Aws::String& value) { SetName(value); return *this;}
-    inline ListSignalCatalogNodesRequest& WithName(Aws::String&& value) { SetName(std::move(value)); return *this;}
-    inline ListSignalCatalogNodesRequest& WithName(const char* value) { SetName(value); return *this;}
+    template<typename NameT = Aws::String>
+    void SetName(NameT&& value) { m_nameHasBeenSet = true; m_name = std::forward<NameT>(value); }
+    template<typename NameT = Aws::String>
+    ListSignalCatalogNodesRequest& WithName(NameT&& value) { SetName(std::forward<NameT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -58,21 +56,19 @@ namespace Model
      * token. When all results have been returned, the response does not contain a
      * pagination token value. </p>
      */
-    inline const Aws::String& GetNextToken() const{ return m_nextToken; }
+    inline const Aws::String& GetNextToken() const { return m_nextToken; }
     inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }
-    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }
-    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }
-    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }
-    inline ListSignalCatalogNodesRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}
-    inline ListSignalCatalogNodesRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}
-    inline ListSignalCatalogNodesRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}
+    template<typename NextTokenT = Aws::String>
+    void SetNextToken(NextTokenT&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::forward<NextTokenT>(value); }
+    template<typename NextTokenT = Aws::String>
+    ListSignalCatalogNodesRequest& WithNextToken(NextTokenT&& value) { SetNextToken(std::forward<NextTokenT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The maximum number of items to return, between 1 and 100, inclusive.</p>
      */
-    inline int GetMaxResults() const{ return m_maxResults; }
+    inline int GetMaxResults() const { return m_maxResults; }
     inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }
     inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }
     inline ListSignalCatalogNodesRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}
@@ -82,12 +78,10 @@ namespace Model
     /**
      * <p>The type of node in the signal catalog.</p>
      */
-    inline const SignalNodeType& GetSignalNodeType() const{ return m_signalNodeType; }
+    inline SignalNodeType GetSignalNodeType() const { return m_signalNodeType; }
     inline bool SignalNodeTypeHasBeenSet() const { return m_signalNodeTypeHasBeenSet; }
-    inline void SetSignalNodeType(const SignalNodeType& value) { m_signalNodeTypeHasBeenSet = true; m_signalNodeType = value; }
-    inline void SetSignalNodeType(SignalNodeType&& value) { m_signalNodeTypeHasBeenSet = true; m_signalNodeType = std::move(value); }
-    inline ListSignalCatalogNodesRequest& WithSignalNodeType(const SignalNodeType& value) { SetSignalNodeType(value); return *this;}
-    inline ListSignalCatalogNodesRequest& WithSignalNodeType(SignalNodeType&& value) { SetSignalNodeType(std::move(value)); return *this;}
+    inline void SetSignalNodeType(SignalNodeType value) { m_signalNodeTypeHasBeenSet = true; m_signalNodeType = value; }
+    inline ListSignalCatalogNodesRequest& WithSignalNodeType(SignalNodeType value) { SetSignalNodeType(value); return *this;}
     ///@}
   private:
 
@@ -97,10 +91,10 @@ namespace Model
     Aws::String m_nextToken;
     bool m_nextTokenHasBeenSet = false;
 
-    int m_maxResults;
+    int m_maxResults{0};
     bool m_maxResultsHasBeenSet = false;
 
-    SignalNodeType m_signalNodeType;
+    SignalNodeType m_signalNodeType{SignalNodeType::NOT_SET};
     bool m_signalNodeTypeHasBeenSet = false;
   };
 
