@@ -243,8 +243,8 @@ namespace Model
     Aws::String m_assetModelCompositeModelType;
     bool m_assetModelCompositeModelTypeHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
 
     Aws::String m_composedAssetModelId;
     bool m_composedAssetModelIdHasBeenSet = false;
