@@ -32,7 +32,7 @@ namespace Model
   class MultiLayerStorage
   {
   public:
-    AWS_IOTSITEWISE_API MultiLayerStorage();
+    AWS_IOTSITEWISE_API MultiLayerStorage() = default;
     AWS_IOTSITEWISE_API MultiLayerStorage(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOTSITEWISE_API MultiLayerStorage& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOTSITEWISE_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,12 +42,12 @@ namespace Model
     /**
      * <p>Contains information about a customer managed Amazon S3 bucket.</p>
      */
-    inline const CustomerManagedS3Storage& GetCustomerManagedS3Storage() const{ return m_customerManagedS3Storage; }
+    inline const CustomerManagedS3Storage& GetCustomerManagedS3Storage() const { return m_customerManagedS3Storage; }
     inline bool CustomerManagedS3StorageHasBeenSet() const { return m_customerManagedS3StorageHasBeenSet; }
-    inline void SetCustomerManagedS3Storage(const CustomerManagedS3Storage& value) { m_customerManagedS3StorageHasBeenSet = true; m_customerManagedS3Storage = value; }
-    inline void SetCustomerManagedS3Storage(CustomerManagedS3Storage&& value) { m_customerManagedS3StorageHasBeenSet = true; m_customerManagedS3Storage = std::move(value); }
-    inline MultiLayerStorage& WithCustomerManagedS3Storage(const CustomerManagedS3Storage& value) { SetCustomerManagedS3Storage(value); return *this;}
-    inline MultiLayerStorage& WithCustomerManagedS3Storage(CustomerManagedS3Storage&& value) { SetCustomerManagedS3Storage(std::move(value)); return *this;}
+    template<typename CustomerManagedS3StorageT = CustomerManagedS3Storage>
+    void SetCustomerManagedS3Storage(CustomerManagedS3StorageT&& value) { m_customerManagedS3StorageHasBeenSet = true; m_customerManagedS3Storage = std::forward<CustomerManagedS3StorageT>(value); }
+    template<typename CustomerManagedS3StorageT = CustomerManagedS3Storage>
+    MultiLayerStorage& WithCustomerManagedS3Storage(CustomerManagedS3StorageT&& value) { SetCustomerManagedS3Storage(std::forward<CustomerManagedS3StorageT>(value)); return *this;}
     ///@}
   private:
 
