@@ -5,9 +5,11 @@
 
 #pragma once
 #include <aws/iotwireless/IoTWireless_EXPORTS.h>
+#include <aws/core/endpoint/AWSEndpoint.h>
 #include <aws/core/AmazonSerializableWebServiceRequest.h>
 #include <aws/core/utils/UnreferencedParam.h>
 #include <aws/core/http/HttpRequest.h>
+#include <aws/core/AmazonStreamingWebServiceRequest.h>
 
 namespace Aws
 {
@@ -16,6 +18,9 @@ namespace IoTWireless
   class AWS_IOTWIRELESS_API IoTWirelessRequest : public Aws::AmazonSerializableWebServiceRequest
   {
   public:
+    using EndpointParameter = Aws::Endpoint::EndpointParameter;
+    using EndpointParameters = Aws::Endpoint::EndpointParameters;
+
     virtual ~IoTWirelessRequest () {}
 
     void AddParametersToRequest(Aws::Http::HttpRequest& httpRequest) const { AWS_UNREFERENCED_PARAM(httpRequest); }
@@ -37,6 +42,7 @@ namespace IoTWireless
 
   };
 
+  typedef Aws::AmazonStreamingWebServiceRequest StreamingIoTWirelessRequest;
 
 } // namespace IoTWireless
 } // namespace Aws
