@@ -33,7 +33,7 @@ namespace Model
   class ConnectionStatusEventConfiguration
   {
   public:
-    AWS_IOTWIRELESS_API ConnectionStatusEventConfiguration();
+    AWS_IOTWIRELESS_API ConnectionStatusEventConfiguration() = default;
     AWS_IOTWIRELESS_API ConnectionStatusEventConfiguration(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOTWIRELESS_API ConnectionStatusEventConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_IOTWIRELESS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,12 +44,12 @@ namespace Model
      * <p>Connection status event configuration object for enabling or disabling
      * LoRaWAN related event topics.</p>
      */
-    inline const LoRaWANConnectionStatusEventNotificationConfigurations& GetLoRaWAN() const{ return m_loRaWAN; }
+    inline const LoRaWANConnectionStatusEventNotificationConfigurations& GetLoRaWAN() const { return m_loRaWAN; }
     inline bool LoRaWANHasBeenSet() const { return m_loRaWANHasBeenSet; }
-    inline void SetLoRaWAN(const LoRaWANConnectionStatusEventNotificationConfigurations& value) { m_loRaWANHasBeenSet = true; m_loRaWAN = value; }
-    inline void SetLoRaWAN(LoRaWANConnectionStatusEventNotificationConfigurations&& value) { m_loRaWANHasBeenSet = true; m_loRaWAN = std::move(value); }
-    inline ConnectionStatusEventConfiguration& WithLoRaWAN(const LoRaWANConnectionStatusEventNotificationConfigurations& value) { SetLoRaWAN(value); return *this;}
-    inline ConnectionStatusEventConfiguration& WithLoRaWAN(LoRaWANConnectionStatusEventNotificationConfigurations&& value) { SetLoRaWAN(std::move(value)); return *this;}
+    template<typename LoRaWANT = LoRaWANConnectionStatusEventNotificationConfigurations>
+    void SetLoRaWAN(LoRaWANT&& value) { m_loRaWANHasBeenSet = true; m_loRaWAN = std::forward<LoRaWANT>(value); }
+    template<typename LoRaWANT = LoRaWANConnectionStatusEventNotificationConfigurations>
+    ConnectionStatusEventConfiguration& WithLoRaWAN(LoRaWANT&& value) { SetLoRaWAN(std::forward<LoRaWANT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -57,19 +57,17 @@ namespace Model
      * <p>Denotes whether the wireless gateway ID connection status event topic is
      * enabled or disabled.</p>
      */
-    inline const EventNotificationTopicStatus& GetWirelessGatewayIdEventTopic() const{ return m_wirelessGatewayIdEventTopic; }
+    inline EventNotificationTopicStatus GetWirelessGatewayIdEventTopic() const { return m_wirelessGatewayIdEventTopic; }
     inline bool WirelessGatewayIdEventTopicHasBeenSet() const { return m_wirelessGatewayIdEventTopicHasBeenSet; }
-    inline void SetWirelessGatewayIdEventTopic(const EventNotificationTopicStatus& value) { m_wirelessGatewayIdEventTopicHasBeenSet = true; m_wirelessGatewayIdEventTopic = value; }
-    inline void SetWirelessGatewayIdEventTopic(EventNotificationTopicStatus&& value) { m_wirelessGatewayIdEventTopicHasBeenSet = true; m_wirelessGatewayIdEventTopic = std::move(value); }
-    inline ConnectionStatusEventConfiguration& WithWirelessGatewayIdEventTopic(const EventNotificationTopicStatus& value) { SetWirelessGatewayIdEventTopic(value); return *this;}
-    inline ConnectionStatusEventConfiguration& WithWirelessGatewayIdEventTopic(EventNotificationTopicStatus&& value) { SetWirelessGatewayIdEventTopic(std::move(value)); return *this;}
+    inline void SetWirelessGatewayIdEventTopic(EventNotificationTopicStatus value) { m_wirelessGatewayIdEventTopicHasBeenSet = true; m_wirelessGatewayIdEventTopic = value; }
+    inline ConnectionStatusEventConfiguration& WithWirelessGatewayIdEventTopic(EventNotificationTopicStatus value) { SetWirelessGatewayIdEventTopic(value); return *this;}
     ///@}
   private:
 
     LoRaWANConnectionStatusEventNotificationConfigurations m_loRaWAN;
     bool m_loRaWANHasBeenSet = false;
 
-    EventNotificationTopicStatus m_wirelessGatewayIdEventTopic;
+    EventNotificationTopicStatus m_wirelessGatewayIdEventTopic{EventNotificationTopicStatus::NOT_SET};
     bool m_wirelessGatewayIdEventTopicHasBeenSet = false;
   };
 
