@@ -34,7 +34,7 @@ namespace Model
   class StreamSummary
   {
   public:
-    AWS_IVS_API StreamSummary();
+    AWS_IVS_API StreamSummary() = default;
     AWS_IVS_API StreamSummary(Aws::Utils::Json::JsonView jsonValue);
     AWS_IVS_API StreamSummary& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_IVS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,26 +44,22 @@ namespace Model
     /**
      * <p>Channel ARN for the stream.</p>
      */
-    inline const Aws::String& GetChannelArn() const{ return m_channelArn; }
+    inline const Aws::String& GetChannelArn() const { return m_channelArn; }
     inline bool ChannelArnHasBeenSet() const { return m_channelArnHasBeenSet; }
-    inline void SetChannelArn(const Aws::String& value) { m_channelArnHasBeenSet = true; m_channelArn = value; }
-    inline void SetChannelArn(Aws::String&& value) { m_channelArnHasBeenSet = true; m_channelArn = std::move(value); }
-    inline void SetChannelArn(const char* value) { m_channelArnHasBeenSet = true; m_channelArn.assign(value); }
-    inline StreamSummary& WithChannelArn(const Aws::String& value) { SetChannelArn(value); return *this;}
-    inline StreamSummary& WithChannelArn(Aws::String&& value) { SetChannelArn(std::move(value)); return *this;}
-    inline StreamSummary& WithChannelArn(const char* value) { SetChannelArn(value); return *this;}
+    template<typename ChannelArnT = Aws::String>
+    void SetChannelArn(ChannelArnT&& value) { m_channelArnHasBeenSet = true; m_channelArn = std::forward<ChannelArnT>(value); }
+    template<typename ChannelArnT = Aws::String>
+    StreamSummary& WithChannelArn(ChannelArnT&& value) { SetChannelArn(std::forward<ChannelArnT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The stream’s health.</p>
      */
-    inline const StreamHealth& GetHealth() const{ return m_health; }
+    inline StreamHealth GetHealth() const { return m_health; }
     inline bool HealthHasBeenSet() const { return m_healthHasBeenSet; }
-    inline void SetHealth(const StreamHealth& value) { m_healthHasBeenSet = true; m_health = value; }
-    inline void SetHealth(StreamHealth&& value) { m_healthHasBeenSet = true; m_health = std::move(value); }
-    inline StreamSummary& WithHealth(const StreamHealth& value) { SetHealth(value); return *this;}
-    inline StreamSummary& WithHealth(StreamHealth&& value) { SetHealth(std::move(value)); return *this;}
+    inline void SetHealth(StreamHealth value) { m_healthHasBeenSet = true; m_health = value; }
+    inline StreamSummary& WithHealth(StreamHealth value) { SetHealth(value); return *this;}
     ///@}
 
     ///@{
@@ -71,12 +67,12 @@ namespace Model
      * <p>Time of the stream’s start. This is an ISO 8601 timestamp; <i>note that this
      * is returned as a string</i>. </p>
      */
-    inline const Aws::Utils::DateTime& GetStartTime() const{ return m_startTime; }
+    inline const Aws::Utils::DateTime& GetStartTime() const { return m_startTime; }
     inline bool StartTimeHasBeenSet() const { return m_startTimeHasBeenSet; }
-    inline void SetStartTime(const Aws::Utils::DateTime& value) { m_startTimeHasBeenSet = true; m_startTime = value; }
-    inline void SetStartTime(Aws::Utils::DateTime&& value) { m_startTimeHasBeenSet = true; m_startTime = std::move(value); }
-    inline StreamSummary& WithStartTime(const Aws::Utils::DateTime& value) { SetStartTime(value); return *this;}
-    inline StreamSummary& WithStartTime(Aws::Utils::DateTime&& value) { SetStartTime(std::move(value)); return *this;}
+    template<typename StartTimeT = Aws::Utils::DateTime>
+    void SetStartTime(StartTimeT&& value) { m_startTimeHasBeenSet = true; m_startTime = std::forward<StartTimeT>(value); }
+    template<typename StartTimeT = Aws::Utils::DateTime>
+    StreamSummary& WithStartTime(StartTimeT&& value) { SetStartTime(std::forward<StartTimeT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -85,12 +81,10 @@ namespace Model
      * may not return it; instead, a "NotBroadcasting" error will indicate that the
      * stream is not live.</p>
      */
-    inline const StreamState& GetState() const{ return m_state; }
+    inline StreamState GetState() const { return m_state; }
     inline bool StateHasBeenSet() const { return m_stateHasBeenSet; }
-    inline void SetState(const StreamState& value) { m_stateHasBeenSet = true; m_state = value; }
-    inline void SetState(StreamState&& value) { m_stateHasBeenSet = true; m_state = std::move(value); }
-    inline StreamSummary& WithState(const StreamState& value) { SetState(value); return *this;}
-    inline StreamSummary& WithState(StreamState&& value) { SetState(std::move(value)); return *this;}
+    inline void SetState(StreamState value) { m_stateHasBeenSet = true; m_state = value; }
+    inline StreamSummary& WithState(StreamState value) { SetState(value); return *this;}
     ///@}
 
     ///@{
@@ -98,14 +92,12 @@ namespace Model
      * <p>Unique identifier for a live or previously live stream in the specified
      * channel.</p>
      */
-    inline const Aws::String& GetStreamId() const{ return m_streamId; }
+    inline const Aws::String& GetStreamId() const { return m_streamId; }
     inline bool StreamIdHasBeenSet() const { return m_streamIdHasBeenSet; }
-    inline void SetStreamId(const Aws::String& value) { m_streamIdHasBeenSet = true; m_streamId = value; }
-    inline void SetStreamId(Aws::String&& value) { m_streamIdHasBeenSet = true; m_streamId = std::move(value); }
-    inline void SetStreamId(const char* value) { m_streamIdHasBeenSet = true; m_streamId.assign(value); }
-    inline StreamSummary& WithStreamId(const Aws::String& value) { SetStreamId(value); return *this;}
-    inline StreamSummary& WithStreamId(Aws::String&& value) { SetStreamId(std::move(value)); return *this;}
-    inline StreamSummary& WithStreamId(const char* value) { SetStreamId(value); return *this;}
+    template<typename StreamIdT = Aws::String>
+    void SetStreamId(StreamIdT&& value) { m_streamIdHasBeenSet = true; m_streamId = std::forward<StreamIdT>(value); }
+    template<typename StreamIdT = Aws::String>
+    StreamSummary& WithStreamId(StreamIdT&& value) { SetStreamId(std::forward<StreamIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -116,7 +108,7 @@ namespace Model
      * playback ends. A value of -1 indicates that the request timed out; in this case,
      * retry.</p>
      */
-    inline long long GetViewerCount() const{ return m_viewerCount; }
+    inline long long GetViewerCount() const { return m_viewerCount; }
     inline bool ViewerCountHasBeenSet() const { return m_viewerCountHasBeenSet; }
     inline void SetViewerCount(long long value) { m_viewerCountHasBeenSet = true; m_viewerCount = value; }
     inline StreamSummary& WithViewerCount(long long value) { SetViewerCount(value); return *this;}
@@ -126,19 +118,19 @@ namespace Model
     Aws::String m_channelArn;
     bool m_channelArnHasBeenSet = false;
 
-    StreamHealth m_health;
+    StreamHealth m_health{StreamHealth::NOT_SET};
     bool m_healthHasBeenSet = false;
 
-    Aws::Utils::DateTime m_startTime;
+    Aws::Utils::DateTime m_startTime{};
     bool m_startTimeHasBeenSet = false;
 
-    StreamState m_state;
+    StreamState m_state{StreamState::NOT_SET};
     bool m_stateHasBeenSet = false;
 
     Aws::String m_streamId;
     bool m_streamIdHasBeenSet = false;
 
-    long long m_viewerCount;
+    long long m_viewerCount{0};
     bool m_viewerCountHasBeenSet = false;
   };
 
