@@ -34,7 +34,7 @@ namespace Model
   class ClusterOperationStepInfo
   {
   public:
-    AWS_KAFKA_API ClusterOperationStepInfo();
+    AWS_KAFKA_API ClusterOperationStepInfo() = default;
     AWS_KAFKA_API ClusterOperationStepInfo(Aws::Utils::Json::JsonView jsonValue);
     AWS_KAFKA_API ClusterOperationStepInfo& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_KAFKA_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -46,14 +46,12 @@ namespace Model
             <p>The steps current status.</p>
          
      */
-    inline const Aws::String& GetStepStatus() const{ return m_stepStatus; }
+    inline const Aws::String& GetStepStatus() const { return m_stepStatus; }
     inline bool StepStatusHasBeenSet() const { return m_stepStatusHasBeenSet; }
-    inline void SetStepStatus(const Aws::String& value) { m_stepStatusHasBeenSet = true; m_stepStatus = value; }
-    inline void SetStepStatus(Aws::String&& value) { m_stepStatusHasBeenSet = true; m_stepStatus = std::move(value); }
-    inline void SetStepStatus(const char* value) { m_stepStatusHasBeenSet = true; m_stepStatus.assign(value); }
-    inline ClusterOperationStepInfo& WithStepStatus(const Aws::String& value) { SetStepStatus(value); return *this;}
-    inline ClusterOperationStepInfo& WithStepStatus(Aws::String&& value) { SetStepStatus(std::move(value)); return *this;}
-    inline ClusterOperationStepInfo& WithStepStatus(const char* value) { SetStepStatus(value); return *this;}
+    template<typename StepStatusT = Aws::String>
+    void SetStepStatus(StepStatusT&& value) { m_stepStatusHasBeenSet = true; m_stepStatus = std::forward<StepStatusT>(value); }
+    template<typename StepStatusT = Aws::String>
+    ClusterOperationStepInfo& WithStepStatus(StepStatusT&& value) { SetStepStatus(std::forward<StepStatusT>(value)); return *this;}
     ///@}
   private:
 
