@@ -26,7 +26,7 @@ namespace Model
   class GetBuiltinIntentsRequest : public LexModelBuildingServiceRequest
   {
   public:
-    AWS_LEXMODELBUILDINGSERVICE_API GetBuiltinIntentsRequest();
+    AWS_LEXMODELBUILDINGSERVICE_API GetBuiltinIntentsRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -43,12 +43,10 @@ namespace Model
     /**
      * <p>A list of locales that the intent supports.</p>
      */
-    inline const Locale& GetLocale() const{ return m_locale; }
+    inline Locale GetLocale() const { return m_locale; }
     inline bool LocaleHasBeenSet() const { return m_localeHasBeenSet; }
-    inline void SetLocale(const Locale& value) { m_localeHasBeenSet = true; m_locale = value; }
-    inline void SetLocale(Locale&& value) { m_localeHasBeenSet = true; m_locale = std::move(value); }
-    inline GetBuiltinIntentsRequest& WithLocale(const Locale& value) { SetLocale(value); return *this;}
-    inline GetBuiltinIntentsRequest& WithLocale(Locale&& value) { SetLocale(std::move(value)); return *this;}
+    inline void SetLocale(Locale value) { m_localeHasBeenSet = true; m_locale = value; }
+    inline GetBuiltinIntentsRequest& WithLocale(Locale value) { SetLocale(value); return *this;}
     ///@}
 
     ///@{
@@ -59,14 +57,12 @@ namespace Model
      * href="https://developer.amazon.com/public/solutions/alexa/alexa-skills-kit/docs/built-in-intent-ref/standard-intents">Standard
      * Built-in Intents</a> in the <i>Alexa Skills Kit</i>.</p>
      */
-    inline const Aws::String& GetSignatureContains() const{ return m_signatureContains; }
+    inline const Aws::String& GetSignatureContains() const { return m_signatureContains; }
     inline bool SignatureContainsHasBeenSet() const { return m_signatureContainsHasBeenSet; }
-    inline void SetSignatureContains(const Aws::String& value) { m_signatureContainsHasBeenSet = true; m_signatureContains = value; }
-    inline void SetSignatureContains(Aws::String&& value) { m_signatureContainsHasBeenSet = true; m_signatureContains = std::move(value); }
-    inline void SetSignatureContains(const char* value) { m_signatureContainsHasBeenSet = true; m_signatureContains.assign(value); }
-    inline GetBuiltinIntentsRequest& WithSignatureContains(const Aws::String& value) { SetSignatureContains(value); return *this;}
-    inline GetBuiltinIntentsRequest& WithSignatureContains(Aws::String&& value) { SetSignatureContains(std::move(value)); return *this;}
-    inline GetBuiltinIntentsRequest& WithSignatureContains(const char* value) { SetSignatureContains(value); return *this;}
+    template<typename SignatureContainsT = Aws::String>
+    void SetSignatureContains(SignatureContainsT&& value) { m_signatureContainsHasBeenSet = true; m_signatureContains = std::forward<SignatureContainsT>(value); }
+    template<typename SignatureContainsT = Aws::String>
+    GetBuiltinIntentsRequest& WithSignatureContains(SignatureContainsT&& value) { SetSignatureContains(std::forward<SignatureContainsT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -75,14 +71,12 @@ namespace Model
      * truncated, Amazon Lex returns a pagination token in the response. To fetch the
      * next page of intents, use the pagination token in the next request.</p>
      */
-    inline const Aws::String& GetNextToken() const{ return m_nextToken; }
+    inline const Aws::String& GetNextToken() const { return m_nextToken; }
     inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }
-    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }
-    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }
-    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }
-    inline GetBuiltinIntentsRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}
-    inline GetBuiltinIntentsRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}
-    inline GetBuiltinIntentsRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}
+    template<typename NextTokenT = Aws::String>
+    void SetNextToken(NextTokenT&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::forward<NextTokenT>(value); }
+    template<typename NextTokenT = Aws::String>
+    GetBuiltinIntentsRequest& WithNextToken(NextTokenT&& value) { SetNextToken(std::forward<NextTokenT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -90,14 +84,14 @@ namespace Model
      * <p>The maximum number of intents to return in the response. The default is
      * 10.</p>
      */
-    inline int GetMaxResults() const{ return m_maxResults; }
+    inline int GetMaxResults() const { return m_maxResults; }
     inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }
     inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }
     inline GetBuiltinIntentsRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}
     ///@}
   private:
 
-    Locale m_locale;
+    Locale m_locale{Locale::NOT_SET};
     bool m_localeHasBeenSet = false;
 
     Aws::String m_signatureContains;
@@ -106,7 +100,7 @@ namespace Model
     Aws::String m_nextToken;
     bool m_nextTokenHasBeenSet = false;
 
-    int m_maxResults;
+    int m_maxResults{0};
     bool m_maxResultsHasBeenSet = false;
   };
 
