@@ -29,7 +29,7 @@ namespace Model
   class AllowedInputTypes
   {
   public:
-    AWS_LEXMODELSV2_API AllowedInputTypes();
+    AWS_LEXMODELSV2_API AllowedInputTypes() = default;
     AWS_LEXMODELSV2_API AllowedInputTypes(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API AllowedInputTypes& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -39,7 +39,7 @@ namespace Model
     /**
      * <p>Indicates whether audio input is allowed.</p>
      */
-    inline bool GetAllowAudioInput() const{ return m_allowAudioInput; }
+    inline bool GetAllowAudioInput() const { return m_allowAudioInput; }
     inline bool AllowAudioInputHasBeenSet() const { return m_allowAudioInputHasBeenSet; }
     inline void SetAllowAudioInput(bool value) { m_allowAudioInputHasBeenSet = true; m_allowAudioInput = value; }
     inline AllowedInputTypes& WithAllowAudioInput(bool value) { SetAllowAudioInput(value); return *this;}
@@ -49,17 +49,17 @@ namespace Model
     /**
      * <p>Indicates whether DTMF input is allowed.</p>
      */
-    inline bool GetAllowDTMFInput() const{ return m_allowDTMFInput; }
+    inline bool GetAllowDTMFInput() const { return m_allowDTMFInput; }
     inline bool AllowDTMFInputHasBeenSet() const { return m_allowDTMFInputHasBeenSet; }
     inline void SetAllowDTMFInput(bool value) { m_allowDTMFInputHasBeenSet = true; m_allowDTMFInput = value; }
     inline AllowedInputTypes& WithAllowDTMFInput(bool value) { SetAllowDTMFInput(value); return *this;}
     ///@}
   private:
 
-    bool m_allowAudioInput;
+    bool m_allowAudioInput{false};
     bool m_allowAudioInputHasBeenSet = false;
 
-    bool m_allowDTMFInput;
+    bool m_allowDTMFInput{false};
     bool m_allowDTMFInputHasBeenSet = false;
   };
 
