@@ -33,7 +33,7 @@ namespace Model
   class BuiltInSlotTypeSortBy
   {
   public:
-    AWS_LEXMODELSV2_API BuiltInSlotTypeSortBy();
+    AWS_LEXMODELSV2_API BuiltInSlotTypeSortBy() = default;
     AWS_LEXMODELSV2_API BuiltInSlotTypeSortBy(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API BuiltInSlotTypeSortBy& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,31 +43,27 @@ namespace Model
     /**
      * <p>The attribute to use to sort the list of built-in intents.</p>
      */
-    inline const BuiltInSlotTypeSortAttribute& GetAttribute() const{ return m_attribute; }
+    inline BuiltInSlotTypeSortAttribute GetAttribute() const { return m_attribute; }
     inline bool AttributeHasBeenSet() const { return m_attributeHasBeenSet; }
-    inline void SetAttribute(const BuiltInSlotTypeSortAttribute& value) { m_attributeHasBeenSet = true; m_attribute = value; }
-    inline void SetAttribute(BuiltInSlotTypeSortAttribute&& value) { m_attributeHasBeenSet = true; m_attribute = std::move(value); }
-    inline BuiltInSlotTypeSortBy& WithAttribute(const BuiltInSlotTypeSortAttribute& value) { SetAttribute(value); return *this;}
-    inline BuiltInSlotTypeSortBy& WithAttribute(BuiltInSlotTypeSortAttribute&& value) { SetAttribute(std::move(value)); return *this;}
+    inline void SetAttribute(BuiltInSlotTypeSortAttribute value) { m_attributeHasBeenSet = true; m_attribute = value; }
+    inline BuiltInSlotTypeSortBy& WithAttribute(BuiltInSlotTypeSortAttribute value) { SetAttribute(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The order to sort the list. You can choose ascending or descending.</p>
      */
-    inline const SortOrder& GetOrder() const{ return m_order; }
+    inline SortOrder GetOrder() const { return m_order; }
     inline bool OrderHasBeenSet() const { return m_orderHasBeenSet; }
-    inline void SetOrder(const SortOrder& value) { m_orderHasBeenSet = true; m_order = value; }
-    inline void SetOrder(SortOrder&& value) { m_orderHasBeenSet = true; m_order = std::move(value); }
-    inline BuiltInSlotTypeSortBy& WithOrder(const SortOrder& value) { SetOrder(value); return *this;}
-    inline BuiltInSlotTypeSortBy& WithOrder(SortOrder&& value) { SetOrder(std::move(value)); return *this;}
+    inline void SetOrder(SortOrder value) { m_orderHasBeenSet = true; m_order = value; }
+    inline BuiltInSlotTypeSortBy& WithOrder(SortOrder value) { SetOrder(value); return *this;}
     ///@}
   private:
 
-    BuiltInSlotTypeSortAttribute m_attribute;
+    BuiltInSlotTypeSortAttribute m_attribute{BuiltInSlotTypeSortAttribute::NOT_SET};
     bool m_attributeHasBeenSet = false;
 
-    SortOrder m_order;
+    SortOrder m_order{SortOrder::NOT_SET};
     bool m_orderHasBeenSet = false;
   };
 
