@@ -33,7 +33,7 @@ namespace Model
   class DialogAction
   {
   public:
-    AWS_LEXMODELSV2_API DialogAction();
+    AWS_LEXMODELSV2_API DialogAction() = default;
     AWS_LEXMODELSV2_API DialogAction(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API DialogAction& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,12 +43,10 @@ namespace Model
     /**
      * <p>The action that the bot should execute. </p>
      */
-    inline const DialogActionType& GetType() const{ return m_type; }
+    inline DialogActionType GetType() const { return m_type; }
     inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }
-    inline void SetType(const DialogActionType& value) { m_typeHasBeenSet = true; m_type = value; }
-    inline void SetType(DialogActionType&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }
-    inline DialogAction& WithType(const DialogActionType& value) { SetType(value); return *this;}
-    inline DialogAction& WithType(DialogActionType&& value) { SetType(std::move(value)); return *this;}
+    inline void SetType(DialogActionType value) { m_typeHasBeenSet = true; m_type = value; }
+    inline DialogAction& WithType(DialogActionType value) { SetType(value); return *this;}
     ///@}
 
     ///@{
@@ -56,34 +54,32 @@ namespace Model
      * <p>If the dialog action is <code>ElicitSlot</code>, defines the slot to elicit
      * from the user.</p>
      */
-    inline const Aws::String& GetSlotToElicit() const{ return m_slotToElicit; }
+    inline const Aws::String& GetSlotToElicit() const { return m_slotToElicit; }
     inline bool SlotToElicitHasBeenSet() const { return m_slotToElicitHasBeenSet; }
-    inline void SetSlotToElicit(const Aws::String& value) { m_slotToElicitHasBeenSet = true; m_slotToElicit = value; }
-    inline void SetSlotToElicit(Aws::String&& value) { m_slotToElicitHasBeenSet = true; m_slotToElicit = std::move(value); }
-    inline void SetSlotToElicit(const char* value) { m_slotToElicitHasBeenSet = true; m_slotToElicit.assign(value); }
-    inline DialogAction& WithSlotToElicit(const Aws::String& value) { SetSlotToElicit(value); return *this;}
-    inline DialogAction& WithSlotToElicit(Aws::String&& value) { SetSlotToElicit(std::move(value)); return *this;}
-    inline DialogAction& WithSlotToElicit(const char* value) { SetSlotToElicit(value); return *this;}
+    template<typename SlotToElicitT = Aws::String>
+    void SetSlotToElicit(SlotToElicitT&& value) { m_slotToElicitHasBeenSet = true; m_slotToElicit = std::forward<SlotToElicitT>(value); }
+    template<typename SlotToElicitT = Aws::String>
+    DialogAction& WithSlotToElicit(SlotToElicitT&& value) { SetSlotToElicit(std::forward<SlotToElicitT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>When true the next message for the intent is not used.</p>
      */
-    inline bool GetSuppressNextMessage() const{ return m_suppressNextMessage; }
+    inline bool GetSuppressNextMessage() const { return m_suppressNextMessage; }
     inline bool SuppressNextMessageHasBeenSet() const { return m_suppressNextMessageHasBeenSet; }
     inline void SetSuppressNextMessage(bool value) { m_suppressNextMessageHasBeenSet = true; m_suppressNextMessage = value; }
     inline DialogAction& WithSuppressNextMessage(bool value) { SetSuppressNextMessage(value); return *this;}
     ///@}
   private:
 
-    DialogActionType m_type;
+    DialogActionType m_type{DialogActionType::NOT_SET};
     bool m_typeHasBeenSet = false;
 
     Aws::String m_slotToElicit;
     bool m_slotToElicitHasBeenSet = false;
 
-    bool m_suppressNextMessage;
+    bool m_suppressNextMessage{false};
     bool m_suppressNextMessageHasBeenSet = false;
   };
 
