@@ -32,7 +32,7 @@ namespace Model
   class TextInputEvent
   {
   public:
-    AWS_LEXRUNTIMEV2_API TextInputEvent();
+    AWS_LEXRUNTIMEV2_API TextInputEvent() = default;
     AWS_LEXRUNTIMEV2_API TextInputEvent(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXRUNTIMEV2_API TextInputEvent& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXRUNTIMEV2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,14 +43,12 @@ namespace Model
      * <p>The text from the user. Amazon Lex V2 processes this as a complete
      * statement.</p>
      */
-    inline const Aws::String& GetText() const{ return m_text; }
+    inline const Aws::String& GetText() const { return m_text; }
     inline bool TextHasBeenSet() const { return m_textHasBeenSet; }
-    inline void SetText(const Aws::String& value) { m_textHasBeenSet = true; m_text = value; }
-    inline void SetText(Aws::String&& value) { m_textHasBeenSet = true; m_text = std::move(value); }
-    inline void SetText(const char* value) { m_textHasBeenSet = true; m_text.assign(value); }
-    inline TextInputEvent& WithText(const Aws::String& value) { SetText(value); return *this;}
-    inline TextInputEvent& WithText(Aws::String&& value) { SetText(std::move(value)); return *this;}
-    inline TextInputEvent& WithText(const char* value) { SetText(value); return *this;}
+    template<typename TextT = Aws::String>
+    void SetText(TextT&& value) { m_textHasBeenSet = true; m_text = std::forward<TextT>(value); }
+    template<typename TextT = Aws::String>
+    TextInputEvent& WithText(TextT&& value) { SetText(std::forward<TextT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -58,14 +56,12 @@ namespace Model
      * <p>A unique identifier that your application assigns to the event. You can use
      * this to identify events in logs.</p>
      */
-    inline const Aws::String& GetEventId() const{ return m_eventId; }
+    inline const Aws::String& GetEventId() const { return m_eventId; }
     inline bool EventIdHasBeenSet() const { return m_eventIdHasBeenSet; }
-    inline void SetEventId(const Aws::String& value) { m_eventIdHasBeenSet = true; m_eventId = value; }
-    inline void SetEventId(Aws::String&& value) { m_eventIdHasBeenSet = true; m_eventId = std::move(value); }
-    inline void SetEventId(const char* value) { m_eventIdHasBeenSet = true; m_eventId.assign(value); }
-    inline TextInputEvent& WithEventId(const Aws::String& value) { SetEventId(value); return *this;}
-    inline TextInputEvent& WithEventId(Aws::String&& value) { SetEventId(std::move(value)); return *this;}
-    inline TextInputEvent& WithEventId(const char* value) { SetEventId(value); return *this;}
+    template<typename EventIdT = Aws::String>
+    void SetEventId(EventIdT&& value) { m_eventIdHasBeenSet = true; m_eventId = std::forward<EventIdT>(value); }
+    template<typename EventIdT = Aws::String>
+    TextInputEvent& WithEventId(EventIdT&& value) { SetEventId(std::forward<EventIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -73,7 +69,7 @@ namespace Model
      * <p>A timestamp set by the client of the date and time that the event was sent to
      * Amazon Lex V2.</p>
      */
-    inline long long GetClientTimestampMillis() const{ return m_clientTimestampMillis; }
+    inline long long GetClientTimestampMillis() const { return m_clientTimestampMillis; }
     inline bool ClientTimestampMillisHasBeenSet() const { return m_clientTimestampMillisHasBeenSet; }
     inline void SetClientTimestampMillis(long long value) { m_clientTimestampMillisHasBeenSet = true; m_clientTimestampMillis = value; }
     inline TextInputEvent& WithClientTimestampMillis(long long value) { SetClientTimestampMillis(value); return *this;}
@@ -86,7 +82,7 @@ namespace Model
     Aws::String m_eventId;
     bool m_eventIdHasBeenSet = false;
 
-    long long m_clientTimestampMillis;
+    long long m_clientTimestampMillis{0};
     bool m_clientTimestampMillisHasBeenSet = false;
   };
 
