@@ -21,7 +21,7 @@ namespace Model
   class UpdateDistributionBundleRequest : public LightsailRequest
   {
   public:
-    AWS_LIGHTSAIL_API UpdateDistributionBundleRequest();
+    AWS_LIGHTSAIL_API UpdateDistributionBundleRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -40,14 +40,12 @@ namespace Model
      * <code>GetDistributions</code> action to get a list of distribution names that
      * you can specify.</p>
      */
-    inline const Aws::String& GetDistributionName() const{ return m_distributionName; }
+    inline const Aws::String& GetDistributionName() const { return m_distributionName; }
     inline bool DistributionNameHasBeenSet() const { return m_distributionNameHasBeenSet; }
-    inline void SetDistributionName(const Aws::String& value) { m_distributionNameHasBeenSet = true; m_distributionName = value; }
-    inline void SetDistributionName(Aws::String&& value) { m_distributionNameHasBeenSet = true; m_distributionName = std::move(value); }
-    inline void SetDistributionName(const char* value) { m_distributionNameHasBeenSet = true; m_distributionName.assign(value); }
-    inline UpdateDistributionBundleRequest& WithDistributionName(const Aws::String& value) { SetDistributionName(value); return *this;}
-    inline UpdateDistributionBundleRequest& WithDistributionName(Aws::String&& value) { SetDistributionName(std::move(value)); return *this;}
-    inline UpdateDistributionBundleRequest& WithDistributionName(const char* value) { SetDistributionName(value); return *this;}
+    template<typename DistributionNameT = Aws::String>
+    void SetDistributionName(DistributionNameT&& value) { m_distributionNameHasBeenSet = true; m_distributionName = std::forward<DistributionNameT>(value); }
+    template<typename DistributionNameT = Aws::String>
+    UpdateDistributionBundleRequest& WithDistributionName(DistributionNameT&& value) { SetDistributionName(std::forward<DistributionNameT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -56,14 +54,12 @@ namespace Model
      * <code>GetDistributionBundles</code> action to get a list of distribution bundle
      * IDs that you can specify.</p>
      */
-    inline const Aws::String& GetBundleId() const{ return m_bundleId; }
+    inline const Aws::String& GetBundleId() const { return m_bundleId; }
     inline bool BundleIdHasBeenSet() const { return m_bundleIdHasBeenSet; }
-    inline void SetBundleId(const Aws::String& value) { m_bundleIdHasBeenSet = true; m_bundleId = value; }
-    inline void SetBundleId(Aws::String&& value) { m_bundleIdHasBeenSet = true; m_bundleId = std::move(value); }
-    inline void SetBundleId(const char* value) { m_bundleIdHasBeenSet = true; m_bundleId.assign(value); }
-    inline UpdateDistributionBundleRequest& WithBundleId(const Aws::String& value) { SetBundleId(value); return *this;}
-    inline UpdateDistributionBundleRequest& WithBundleId(Aws::String&& value) { SetBundleId(std::move(value)); return *this;}
-    inline UpdateDistributionBundleRequest& WithBundleId(const char* value) { SetBundleId(value); return *this;}
+    template<typename BundleIdT = Aws::String>
+    void SetBundleId(BundleIdT&& value) { m_bundleIdHasBeenSet = true; m_bundleId = std::forward<BundleIdT>(value); }
+    template<typename BundleIdT = Aws::String>
+    UpdateDistributionBundleRequest& WithBundleId(BundleIdT&& value) { SetBundleId(std::forward<BundleIdT>(value)); return *this;}
     ///@}
   private:
 
