@@ -32,7 +32,7 @@ namespace Model
   class CalculateRouteRequest : public LocationServiceRequest
   {
   public:
-    AWS_LOCATIONSERVICE_API CalculateRouteRequest();
+    AWS_LOCATIONSERVICE_API CalculateRouteRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -50,14 +50,12 @@ namespace Model
      * <p>The name of the route calculator resource that you want to use to calculate
      * the route. </p>
      */
-    inline const Aws::String& GetCalculatorName() const{ return m_calculatorName; }
+    inline const Aws::String& GetCalculatorName() const { return m_calculatorName; }
     inline bool CalculatorNameHasBeenSet() const { return m_calculatorNameHasBeenSet; }
-    inline void SetCalculatorName(const Aws::String& value) { m_calculatorNameHasBeenSet = true; m_calculatorName = value; }
-    inline void SetCalculatorName(Aws::String&& value) { m_calculatorNameHasBeenSet = true; m_calculatorName = std::move(value); }
-    inline void SetCalculatorName(const char* value) { m_calculatorNameHasBeenSet = true; m_calculatorName.assign(value); }
-    inline CalculateRouteRequest& WithCalculatorName(const Aws::String& value) { SetCalculatorName(value); return *this;}
-    inline CalculateRouteRequest& WithCalculatorName(Aws::String&& value) { SetCalculatorName(std::move(value)); return *this;}
-    inline CalculateRouteRequest& WithCalculatorName(const char* value) { SetCalculatorName(value); return *this;}
+    template<typename CalculatorNameT = Aws::String>
+    void SetCalculatorName(CalculatorNameT&& value) { m_calculatorNameHasBeenSet = true; m_calculatorName = std::forward<CalculatorNameT>(value); }
+    template<typename CalculatorNameT = Aws::String>
+    CalculateRouteRequest& WithCalculatorName(CalculatorNameT&& value) { SetCalculatorName(std::forward<CalculatorNameT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -74,12 +72,12 @@ namespace Model
      * RoutesValidationException</code> error.</p>  <p>Valid Values: <code>[-180
      * to 180,-90 to 90]</code> </p>
      */
-    inline const Aws::Vector<double>& GetDeparturePosition() const{ return m_departurePosition; }
+    inline const Aws::Vector<double>& GetDeparturePosition() const { return m_departurePosition; }
     inline bool DeparturePositionHasBeenSet() const { return m_departurePositionHasBeenSet; }
-    inline void SetDeparturePosition(const Aws::Vector<double>& value) { m_departurePositionHasBeenSet = true; m_departurePosition = value; }
-    inline void SetDeparturePosition(Aws::Vector<double>&& value) { m_departurePositionHasBeenSet = true; m_departurePosition = std::move(value); }
-    inline CalculateRouteRequest& WithDeparturePosition(const Aws::Vector<double>& value) { SetDeparturePosition(value); return *this;}
-    inline CalculateRouteRequest& WithDeparturePosition(Aws::Vector<double>&& value) { SetDeparturePosition(std::move(value)); return *this;}
+    template<typename DeparturePositionT = Aws::Vector<double>>
+    void SetDeparturePosition(DeparturePositionT&& value) { m_departurePositionHasBeenSet = true; m_departurePosition = std::forward<DeparturePositionT>(value); }
+    template<typename DeparturePositionT = Aws::Vector<double>>
+    CalculateRouteRequest& WithDeparturePosition(DeparturePositionT&& value) { SetDeparturePosition(std::forward<DeparturePositionT>(value)); return *this;}
     inline CalculateRouteRequest& AddDeparturePosition(double value) { m_departurePositionHasBeenSet = true; m_departurePosition.push_back(value); return *this; }
     ///@}
 
@@ -95,12 +93,12 @@ namespace Model
      * the position to the nearest road</a>. </p>  <p>Valid Values: <code>[-180
      * to 180,-90 to 90]</code> </p>
      */
-    inline const Aws::Vector<double>& GetDestinationPosition() const{ return m_destinationPosition; }
+    inline const Aws::Vector<double>& GetDestinationPosition() const { return m_destinationPosition; }
     inline bool DestinationPositionHasBeenSet() const { return m_destinationPositionHasBeenSet; }
-    inline void SetDestinationPosition(const Aws::Vector<double>& value) { m_destinationPositionHasBeenSet = true; m_destinationPosition = value; }
-    inline void SetDestinationPosition(Aws::Vector<double>&& value) { m_destinationPositionHasBeenSet = true; m_destinationPosition = std::move(value); }
-    inline CalculateRouteRequest& WithDestinationPosition(const Aws::Vector<double>& value) { SetDestinationPosition(value); return *this;}
-    inline CalculateRouteRequest& WithDestinationPosition(Aws::Vector<double>&& value) { SetDestinationPosition(std::move(value)); return *this;}
+    template<typename DestinationPositionT = Aws::Vector<double>>
+    void SetDestinationPosition(DestinationPositionT&& value) { m_destinationPositionHasBeenSet = true; m_destinationPosition = std::forward<DestinationPositionT>(value); }
+    template<typename DestinationPositionT = Aws::Vector<double>>
+    CalculateRouteRequest& WithDestinationPosition(DestinationPositionT&& value) { SetDestinationPosition(std::forward<DestinationPositionT>(value)); return *this;}
     inline CalculateRouteRequest& AddDestinationPosition(double value) { m_destinationPositionHasBeenSet = true; m_destinationPosition.push_back(value); return *this; }
     ///@}
 
@@ -120,14 +118,14 @@ namespace Model
      * km returns a <code>400 RoutesValidationException</code> error.</p> 
      * <p>Valid Values: <code>[-180 to 180,-90 to 90]</code> </p>
      */
-    inline const Aws::Vector<Aws::Vector<double>>& GetWaypointPositions() const{ return m_waypointPositions; }
+    inline const Aws::Vector<Aws::Vector<double>>& GetWaypointPositions() const { return m_waypointPositions; }
     inline bool WaypointPositionsHasBeenSet() const { return m_waypointPositionsHasBeenSet; }
-    inline void SetWaypointPositions(const Aws::Vector<Aws::Vector<double>>& value) { m_waypointPositionsHasBeenSet = true; m_waypointPositions = value; }
-    inline void SetWaypointPositions(Aws::Vector<Aws::Vector<double>>&& value) { m_waypointPositionsHasBeenSet = true; m_waypointPositions = std::move(value); }
-    inline CalculateRouteRequest& WithWaypointPositions(const Aws::Vector<Aws::Vector<double>>& value) { SetWaypointPositions(value); return *this;}
-    inline CalculateRouteRequest& WithWaypointPositions(Aws::Vector<Aws::Vector<double>>&& value) { SetWaypointPositions(std::move(value)); return *this;}
-    inline CalculateRouteRequest& AddWaypointPositions(const Aws::Vector<double>& value) { m_waypointPositionsHasBeenSet = true; m_waypointPositions.push_back(value); return *this; }
-    inline CalculateRouteRequest& AddWaypointPositions(Aws::Vector<double>&& value) { m_waypointPositionsHasBeenSet = true; m_waypointPositions.push_back(std::move(value)); return *this; }
+    template<typename WaypointPositionsT = Aws::Vector<Aws::Vector<double>>>
+    void SetWaypointPositions(WaypointPositionsT&& value) { m_waypointPositionsHasBeenSet = true; m_waypointPositions = std::forward<WaypointPositionsT>(value); }
+    template<typename WaypointPositionsT = Aws::Vector<Aws::Vector<double>>>
+    CalculateRouteRequest& WithWaypointPositions(WaypointPositionsT&& value) { SetWaypointPositions(std::forward<WaypointPositionsT>(value)); return *this;}
+    template<typename WaypointPositionsT = Aws::Vector<double>>
+    CalculateRouteRequest& AddWaypointPositions(WaypointPositionsT&& value) { m_waypointPositionsHasBeenSet = true; m_waypointPositions.emplace_back(std::forward<WaypointPositionsT>(value)); return *this; }
     ///@}
 
     ///@{
@@ -148,12 +146,10 @@ namespace Model
      * <code>Truck</code> use the <code>TruckModeOptions</code> parameter.</p> </li>
      * </ul> <p>Default Value: <code>Car</code> </p>
      */
-    inline const TravelMode& GetTravelMode() const{ return m_travelMode; }
+    inline TravelMode GetTravelMode() const { return m_travelMode; }
     inline bool TravelModeHasBeenSet() const { return m_travelModeHasBeenSet; }
-    inline void SetTravelMode(const TravelMode& value) { m_travelModeHasBeenSet = true; m_travelMode = value; }
-    inline void SetTravelMode(TravelMode&& value) { m_travelModeHasBeenSet = true; m_travelMode = std::move(value); }
-    inline CalculateRouteRequest& WithTravelMode(const TravelMode& value) { SetTravelMode(value); return *this;}
-    inline CalculateRouteRequest& WithTravelMode(TravelMode&& value) { SetTravelMode(std::move(value)); return *this;}
+    inline void SetTravelMode(TravelMode value) { m_travelModeHasBeenSet = true; m_travelMode = value; }
+    inline CalculateRouteRequest& WithTravelMode(TravelMode value) { SetTravelMode(value); return *this;}
     ///@}
 
     ///@{
@@ -165,12 +161,12 @@ namespace Model
      * format: <code>YYYY-MM-DDThh:mm:ss.sssZ</code>. For example,
      * <code>2020–07-2T12:15:20.000Z+01:00</code> </p> </li> </ul>
      */
-    inline const Aws::Utils::DateTime& GetDepartureTime() const{ return m_departureTime; }
+    inline const Aws::Utils::DateTime& GetDepartureTime() const { return m_departureTime; }
     inline bool DepartureTimeHasBeenSet() const { return m_departureTimeHasBeenSet; }
-    inline void SetDepartureTime(const Aws::Utils::DateTime& value) { m_departureTimeHasBeenSet = true; m_departureTime = value; }
-    inline void SetDepartureTime(Aws::Utils::DateTime&& value) { m_departureTimeHasBeenSet = true; m_departureTime = std::move(value); }
-    inline CalculateRouteRequest& WithDepartureTime(const Aws::Utils::DateTime& value) { SetDepartureTime(value); return *this;}
-    inline CalculateRouteRequest& WithDepartureTime(Aws::Utils::DateTime&& value) { SetDepartureTime(std::move(value)); return *this;}
+    template<typename DepartureTimeT = Aws::Utils::DateTime>
+    void SetDepartureTime(DepartureTimeT&& value) { m_departureTimeHasBeenSet = true; m_departureTime = std::forward<DepartureTimeT>(value); }
+    template<typename DepartureTimeT = Aws::Utils::DateTime>
+    CalculateRouteRequest& WithDepartureTime(DepartureTimeT&& value) { SetDepartureTime(std::forward<DepartureTimeT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -181,7 +177,7 @@ namespace Model
      * <code>false</code> </p> <p>Valid Values: <code>false</code> | <code>true</code>
      * </p>
      */
-    inline bool GetDepartNow() const{ return m_departNow; }
+    inline bool GetDepartNow() const { return m_departNow; }
     inline bool DepartNowHasBeenSet() const { return m_departNowHasBeenSet; }
     inline void SetDepartNow(bool value) { m_departNowHasBeenSet = true; m_departNow = value; }
     inline CalculateRouteRequest& WithDepartNow(bool value) { SetDepartNow(value); return *this;}
@@ -192,12 +188,10 @@ namespace Model
      * <p>Set the unit system to specify the distance.</p> <p>Default Value:
      * <code>Kilometers</code> </p>
      */
-    inline const DistanceUnit& GetDistanceUnit() const{ return m_distanceUnit; }
+    inline DistanceUnit GetDistanceUnit() const { return m_distanceUnit; }
     inline bool DistanceUnitHasBeenSet() const { return m_distanceUnitHasBeenSet; }
-    inline void SetDistanceUnit(const DistanceUnit& value) { m_distanceUnitHasBeenSet = true; m_distanceUnit = value; }
-    inline void SetDistanceUnit(DistanceUnit&& value) { m_distanceUnitHasBeenSet = true; m_distanceUnit = std::move(value); }
-    inline CalculateRouteRequest& WithDistanceUnit(const DistanceUnit& value) { SetDistanceUnit(value); return *this;}
-    inline CalculateRouteRequest& WithDistanceUnit(DistanceUnit&& value) { SetDistanceUnit(std::move(value)); return *this;}
+    inline void SetDistanceUnit(DistanceUnit value) { m_distanceUnitHasBeenSet = true; m_distanceUnit = value; }
+    inline CalculateRouteRequest& WithDistanceUnit(DistanceUnit value) { SetDistanceUnit(value); return *this;}
     ///@}
 
     ///@{
@@ -206,7 +200,7 @@ namespace Model
      * pair of positions.</p> <p>Default Value: <code>false</code> </p> <p>Valid
      * Values: <code>false</code> | <code>true</code> </p>
      */
-    inline bool GetIncludeLegGeometry() const{ return m_includeLegGeometry; }
+    inline bool GetIncludeLegGeometry() const { return m_includeLegGeometry; }
     inline bool IncludeLegGeometryHasBeenSet() const { return m_includeLegGeometryHasBeenSet; }
     inline void SetIncludeLegGeometry(bool value) { m_includeLegGeometryHasBeenSet = true; m_includeLegGeometry = value; }
     inline CalculateRouteRequest& WithIncludeLegGeometry(bool value) { SetIncludeLegGeometry(value); return *this;}
@@ -218,12 +212,12 @@ namespace Model
      * avoiding routes that use ferries or tolls.</p> <p>Requirements:
      * <code>TravelMode</code> must be specified as <code>Car</code>.</p>
      */
-    inline const CalculateRouteCarModeOptions& GetCarModeOptions() const{ return m_carModeOptions; }
+    inline const CalculateRouteCarModeOptions& GetCarModeOptions() const { return m_carModeOptions; }
     inline bool CarModeOptionsHasBeenSet() const { return m_carModeOptionsHasBeenSet; }
-    inline void SetCarModeOptions(const CalculateRouteCarModeOptions& value) { m_carModeOptionsHasBeenSet = true; m_carModeOptions = value; }
-    inline void SetCarModeOptions(CalculateRouteCarModeOptions&& value) { m_carModeOptionsHasBeenSet = true; m_carModeOptions = std::move(value); }
-    inline CalculateRouteRequest& WithCarModeOptions(const CalculateRouteCarModeOptions& value) { SetCarModeOptions(value); return *this;}
-    inline CalculateRouteRequest& WithCarModeOptions(CalculateRouteCarModeOptions&& value) { SetCarModeOptions(std::move(value)); return *this;}
+    template<typename CarModeOptionsT = CalculateRouteCarModeOptions>
+    void SetCarModeOptions(CarModeOptionsT&& value) { m_carModeOptionsHasBeenSet = true; m_carModeOptions = std::forward<CarModeOptionsT>(value); }
+    template<typename CarModeOptionsT = CalculateRouteCarModeOptions>
+    CalculateRouteRequest& WithCarModeOptions(CarModeOptionsT&& value) { SetCarModeOptions(std::forward<CarModeOptionsT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -233,12 +227,12 @@ namespace Model
      * when choosing an optimal road.</p> <p>Requirements: <code>TravelMode</code> must
      * be specified as <code>Truck</code>.</p>
      */
-    inline const CalculateRouteTruckModeOptions& GetTruckModeOptions() const{ return m_truckModeOptions; }
+    inline const CalculateRouteTruckModeOptions& GetTruckModeOptions() const { return m_truckModeOptions; }
     inline bool TruckModeOptionsHasBeenSet() const { return m_truckModeOptionsHasBeenSet; }
-    inline void SetTruckModeOptions(const CalculateRouteTruckModeOptions& value) { m_truckModeOptionsHasBeenSet = true; m_truckModeOptions = value; }
-    inline void SetTruckModeOptions(CalculateRouteTruckModeOptions&& value) { m_truckModeOptionsHasBeenSet = true; m_truckModeOptions = std::move(value); }
-    inline CalculateRouteRequest& WithTruckModeOptions(const CalculateRouteTruckModeOptions& value) { SetTruckModeOptions(value); return *this;}
-    inline CalculateRouteRequest& WithTruckModeOptions(CalculateRouteTruckModeOptions&& value) { SetTruckModeOptions(std::move(value)); return *this;}
+    template<typename TruckModeOptionsT = CalculateRouteTruckModeOptions>
+    void SetTruckModeOptions(TruckModeOptionsT&& value) { m_truckModeOptionsHasBeenSet = true; m_truckModeOptions = std::forward<TruckModeOptionsT>(value); }
+    template<typename TruckModeOptionsT = CalculateRouteTruckModeOptions>
+    CalculateRouteRequest& WithTruckModeOptions(TruckModeOptionsT&& value) { SetTruckModeOptions(std::forward<TruckModeOptionsT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -248,24 +242,22 @@ namespace Model
      * conditions is used to calculate the route.</p>  <p>ArrivalTime is not
      * supported Esri.</p> 
      */
-    inline const Aws::Utils::DateTime& GetArrivalTime() const{ return m_arrivalTime; }
+    inline const Aws::Utils::DateTime& GetArrivalTime() const { return m_arrivalTime; }
     inline bool ArrivalTimeHasBeenSet() const { return m_arrivalTimeHasBeenSet; }
-    inline void SetArrivalTime(const Aws::Utils::DateTime& value) { m_arrivalTimeHasBeenSet = true; m_arrivalTime = value; }
-    inline void SetArrivalTime(Aws::Utils::DateTime&& value) { m_arrivalTimeHasBeenSet = true; m_arrivalTime = std::move(value); }
-    inline CalculateRouteRequest& WithArrivalTime(const Aws::Utils::DateTime& value) { SetArrivalTime(value); return *this;}
-    inline CalculateRouteRequest& WithArrivalTime(Aws::Utils::DateTime&& value) { SetArrivalTime(std::move(value)); return *this;}
+    template<typename ArrivalTimeT = Aws::Utils::DateTime>
+    void SetArrivalTime(ArrivalTimeT&& value) { m_arrivalTimeHasBeenSet = true; m_arrivalTime = std::forward<ArrivalTimeT>(value); }
+    template<typename ArrivalTimeT = Aws::Utils::DateTime>
+    CalculateRouteRequest& WithArrivalTime(ArrivalTimeT&& value) { SetArrivalTime(std::forward<ArrivalTimeT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Specifies the distance to optimize for when calculating a route.</p>
      */
-    inline const OptimizationMode& GetOptimizeFor() const{ return m_optimizeFor; }
+    inline OptimizationMode GetOptimizeFor() const { return m_optimizeFor; }
     inline bool OptimizeForHasBeenSet() const { return m_optimizeForHasBeenSet; }
-    inline void SetOptimizeFor(const OptimizationMode& value) { m_optimizeForHasBeenSet = true; m_optimizeFor = value; }
-    inline void SetOptimizeFor(OptimizationMode&& value) { m_optimizeForHasBeenSet = true; m_optimizeFor = std::move(value); }
-    inline CalculateRouteRequest& WithOptimizeFor(const OptimizationMode& value) { SetOptimizeFor(value); return *this;}
-    inline CalculateRouteRequest& WithOptimizeFor(OptimizationMode&& value) { SetOptimizeFor(std::move(value)); return *this;}
+    inline void SetOptimizeFor(OptimizationMode value) { m_optimizeForHasBeenSet = true; m_optimizeFor = value; }
+    inline CalculateRouteRequest& WithOptimizeFor(OptimizationMode value) { SetOptimizeFor(value); return *this;}
     ///@}
 
     ///@{
@@ -274,14 +266,12 @@ namespace Model
      * href="https://docs.aws.amazon.com/location/latest/developerguide/using-apikeys.html">API
      * key</a> to authorize the request.</p>
      */
-    inline const Aws::String& GetKey() const{ return m_key; }
+    inline const Aws::String& GetKey() const { return m_key; }
     inline bool KeyHasBeenSet() const { return m_keyHasBeenSet; }
-    inline void SetKey(const Aws::String& value) { m_keyHasBeenSet = true; m_key = value; }
-    inline void SetKey(Aws::String&& value) { m_keyHasBeenSet = true; m_key = std::move(value); }
-    inline void SetKey(const char* value) { m_keyHasBeenSet = true; m_key.assign(value); }
-    inline CalculateRouteRequest& WithKey(const Aws::String& value) { SetKey(value); return *this;}
-    inline CalculateRouteRequest& WithKey(Aws::String&& value) { SetKey(std::move(value)); return *this;}
-    inline CalculateRouteRequest& WithKey(const char* value) { SetKey(value); return *this;}
+    template<typename KeyT = Aws::String>
+    void SetKey(KeyT&& value) { m_keyHasBeenSet = true; m_key = std::forward<KeyT>(value); }
+    template<typename KeyT = Aws::String>
+    CalculateRouteRequest& WithKey(KeyT&& value) { SetKey(std::forward<KeyT>(value)); return *this;}
     ///@}
   private:
 
@@ -297,19 +287,19 @@ namespace Model
     Aws::Vector<Aws::Vector<double>> m_waypointPositions;
     bool m_waypointPositionsHasBeenSet = false;
 
-    TravelMode m_travelMode;
+    TravelMode m_travelMode{TravelMode::NOT_SET};
     bool m_travelModeHasBeenSet = false;
 
-    Aws::Utils::DateTime m_departureTime;
+    Aws::Utils::DateTime m_departureTime{};
     bool m_departureTimeHasBeenSet = false;
 
-    bool m_departNow;
+    bool m_departNow{false};
     bool m_departNowHasBeenSet = false;
 
-    DistanceUnit m_distanceUnit;
+    DistanceUnit m_distanceUnit{DistanceUnit::NOT_SET};
     bool m_distanceUnitHasBeenSet = false;
 
-    bool m_includeLegGeometry;
+    bool m_includeLegGeometry{false};
     bool m_includeLegGeometryHasBeenSet = false;
 
     CalculateRouteCarModeOptions m_carModeOptions;
@@ -318,10 +308,10 @@ namespace Model
     CalculateRouteTruckModeOptions m_truckModeOptions;
     bool m_truckModeOptionsHasBeenSet = false;
 
-    Aws::Utils::DateTime m_arrivalTime;
+    Aws::Utils::DateTime m_arrivalTime{};
     bool m_arrivalTimeHasBeenSet = false;
 
-    OptimizationMode m_optimizeFor;
+    OptimizationMode m_optimizeFor{OptimizationMode::NOT_SET};
     bool m_optimizeForHasBeenSet = false;
 
     Aws::String m_key;
