@@ -30,7 +30,7 @@ namespace Model
   class CountPercent
   {
   public:
-    AWS_LOOKOUTEQUIPMENT_API CountPercent();
+    AWS_LOOKOUTEQUIPMENT_API CountPercent() = default;
     AWS_LOOKOUTEQUIPMENT_API CountPercent(Aws::Utils::Json::JsonView jsonValue);
     AWS_LOOKOUTEQUIPMENT_API CountPercent& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_LOOKOUTEQUIPMENT_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -40,7 +40,7 @@ namespace Model
     /**
      * <p> Indicates the count of occurences of the given statistic. </p>
      */
-    inline int GetCount() const{ return m_count; }
+    inline int GetCount() const { return m_count; }
     inline bool CountHasBeenSet() const { return m_countHasBeenSet; }
     inline void SetCount(int value) { m_countHasBeenSet = true; m_count = value; }
     inline CountPercent& WithCount(int value) { SetCount(value); return *this;}
@@ -50,17 +50,17 @@ namespace Model
     /**
      * <p> Indicates the percentage of occurances of the given statistic. </p>
      */
-    inline double GetPercentage() const{ return m_percentage; }
+    inline double GetPercentage() const { return m_percentage; }
     inline bool PercentageHasBeenSet() const { return m_percentageHasBeenSet; }
     inline void SetPercentage(double value) { m_percentageHasBeenSet = true; m_percentage = value; }
     inline CountPercent& WithPercentage(double value) { SetPercentage(value); return *this;}
     ///@}
   private:
 
-    int m_count;
+    int m_count{0};
     bool m_countHasBeenSet = false;
 
-    double m_percentage;
+    double m_percentage{0.0};
     bool m_percentageHasBeenSet = false;
   };
 
