@@ -21,7 +21,7 @@ namespace Model
   class DeleteLabelRequest : public LookoutEquipmentRequest
   {
   public:
-    AWS_LOOKOUTEQUIPMENT_API DeleteLabelRequest();
+    AWS_LOOKOUTEQUIPMENT_API DeleteLabelRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -40,28 +40,24 @@ namespace Model
      * Data in this field will be retained for service usage. Follow best practices for
      * the security of your data. </p>
      */
-    inline const Aws::String& GetLabelGroupName() const{ return m_labelGroupName; }
+    inline const Aws::String& GetLabelGroupName() const { return m_labelGroupName; }
     inline bool LabelGroupNameHasBeenSet() const { return m_labelGroupNameHasBeenSet; }
-    inline void SetLabelGroupName(const Aws::String& value) { m_labelGroupNameHasBeenSet = true; m_labelGroupName = value; }
-    inline void SetLabelGroupName(Aws::String&& value) { m_labelGroupNameHasBeenSet = true; m_labelGroupName = std::move(value); }
-    inline void SetLabelGroupName(const char* value) { m_labelGroupNameHasBeenSet = true; m_labelGroupName.assign(value); }
-    inline DeleteLabelRequest& WithLabelGroupName(const Aws::String& value) { SetLabelGroupName(value); return *this;}
-    inline DeleteLabelRequest& WithLabelGroupName(Aws::String&& value) { SetLabelGroupName(std::move(value)); return *this;}
-    inline DeleteLabelRequest& WithLabelGroupName(const char* value) { SetLabelGroupName(value); return *this;}
+    template<typename LabelGroupNameT = Aws::String>
+    void SetLabelGroupName(LabelGroupNameT&& value) { m_labelGroupNameHasBeenSet = true; m_labelGroupName = std::forward<LabelGroupNameT>(value); }
+    template<typename LabelGroupNameT = Aws::String>
+    DeleteLabelRequest& WithLabelGroupName(LabelGroupNameT&& value) { SetLabelGroupName(std::forward<LabelGroupNameT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p> The ID of the label that you want to delete. </p>
      */
-    inline const Aws::String& GetLabelId() const{ return m_labelId; }
+    inline const Aws::String& GetLabelId() const { return m_labelId; }
     inline bool LabelIdHasBeenSet() const { return m_labelIdHasBeenSet; }
-    inline void SetLabelId(const Aws::String& value) { m_labelIdHasBeenSet = true; m_labelId = value; }
-    inline void SetLabelId(Aws::String&& value) { m_labelIdHasBeenSet = true; m_labelId = std::move(value); }
-    inline void SetLabelId(const char* value) { m_labelIdHasBeenSet = true; m_labelId.assign(value); }
-    inline DeleteLabelRequest& WithLabelId(const Aws::String& value) { SetLabelId(value); return *this;}
-    inline DeleteLabelRequest& WithLabelId(Aws::String&& value) { SetLabelId(std::move(value)); return *this;}
-    inline DeleteLabelRequest& WithLabelId(const char* value) { SetLabelId(value); return *this;}
+    template<typename LabelIdT = Aws::String>
+    void SetLabelId(LabelIdT&& value) { m_labelIdHasBeenSet = true; m_labelId = std::forward<LabelIdT>(value); }
+    template<typename LabelIdT = Aws::String>
+    DeleteLabelRequest& WithLabelId(LabelIdT&& value) { SetLabelId(std::forward<LabelIdT>(value)); return *this;}
     ///@}
   private:
 
