@@ -33,7 +33,7 @@ namespace Model
   class ApplicationVersionSummary
   {
   public:
-    AWS_MAINFRAMEMODERNIZATION_API ApplicationVersionSummary();
+    AWS_MAINFRAMEMODERNIZATION_API ApplicationVersionSummary() = default;
     AWS_MAINFRAMEMODERNIZATION_API ApplicationVersionSummary(Aws::Utils::Json::JsonView jsonValue);
     AWS_MAINFRAMEMODERNIZATION_API ApplicationVersionSummary& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MAINFRAMEMODERNIZATION_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,7 +43,7 @@ namespace Model
     /**
      * <p>The application version.</p>
      */
-    inline int GetApplicationVersion() const{ return m_applicationVersion; }
+    inline int GetApplicationVersion() const { return m_applicationVersion; }
     inline bool ApplicationVersionHasBeenSet() const { return m_applicationVersionHasBeenSet; }
     inline void SetApplicationVersion(int value) { m_applicationVersionHasBeenSet = true; m_applicationVersion = value; }
     inline ApplicationVersionSummary& WithApplicationVersion(int value) { SetApplicationVersion(value); return *this;}
@@ -53,48 +53,44 @@ namespace Model
     /**
      * <p>The timestamp when the application version was created.</p>
      */
-    inline const Aws::Utils::DateTime& GetCreationTime() const{ return m_creationTime; }
+    inline const Aws::Utils::DateTime& GetCreationTime() const { return m_creationTime; }
     inline bool CreationTimeHasBeenSet() const { return m_creationTimeHasBeenSet; }
-    inline void SetCreationTime(const Aws::Utils::DateTime& value) { m_creationTimeHasBeenSet = true; m_creationTime = value; }
-    inline void SetCreationTime(Aws::Utils::DateTime&& value) { m_creationTimeHasBeenSet = true; m_creationTime = std::move(value); }
-    inline ApplicationVersionSummary& WithCreationTime(const Aws::Utils::DateTime& value) { SetCreationTime(value); return *this;}
-    inline ApplicationVersionSummary& WithCreationTime(Aws::Utils::DateTime&& value) { SetCreationTime(std::move(value)); return *this;}
+    template<typename CreationTimeT = Aws::Utils::DateTime>
+    void SetCreationTime(CreationTimeT&& value) { m_creationTimeHasBeenSet = true; m_creationTime = std::forward<CreationTimeT>(value); }
+    template<typename CreationTimeT = Aws::Utils::DateTime>
+    ApplicationVersionSummary& WithCreationTime(CreationTimeT&& value) { SetCreationTime(std::forward<CreationTimeT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The status of the application.</p>
      */
-    inline const ApplicationVersionLifecycle& GetStatus() const{ return m_status; }
+    inline ApplicationVersionLifecycle GetStatus() const { return m_status; }
     inline bool StatusHasBeenSet() const { return m_statusHasBeenSet; }
-    inline void SetStatus(const ApplicationVersionLifecycle& value) { m_statusHasBeenSet = true; m_status = value; }
-    inline void SetStatus(ApplicationVersionLifecycle&& value) { m_statusHasBeenSet = true; m_status = std::move(value); }
-    inline ApplicationVersionSummary& WithStatus(const ApplicationVersionLifecycle& value) { SetStatus(value); return *this;}
-    inline ApplicationVersionSummary& WithStatus(ApplicationVersionLifecycle&& value) { SetStatus(std::move(value)); return *this;}
+    inline void SetStatus(ApplicationVersionLifecycle value) { m_statusHasBeenSet = true; m_status = value; }
+    inline ApplicationVersionSummary& WithStatus(ApplicationVersionLifecycle value) { SetStatus(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The reason for the reported status.</p>
      */
-    inline const Aws::String& GetStatusReason() const{ return m_statusReason; }
+    inline const Aws::String& GetStatusReason() const { return m_statusReason; }
     inline bool StatusReasonHasBeenSet() const { return m_statusReasonHasBeenSet; }
-    inline void SetStatusReason(const Aws::String& value) { m_statusReasonHasBeenSet = true; m_statusReason = value; }
-    inline void SetStatusReason(Aws::String&& value) { m_statusReasonHasBeenSet = true; m_statusReason = std::move(value); }
-    inline void SetStatusReason(const char* value) { m_statusReasonHasBeenSet = true; m_statusReason.assign(value); }
-    inline ApplicationVersionSummary& WithStatusReason(const Aws::String& value) { SetStatusReason(value); return *this;}
-    inline ApplicationVersionSummary& WithStatusReason(Aws::String&& value) { SetStatusReason(std::move(value)); return *this;}
-    inline ApplicationVersionSummary& WithStatusReason(const char* value) { SetStatusReason(value); return *this;}
+    template<typename StatusReasonT = Aws::String>
+    void SetStatusReason(StatusReasonT&& value) { m_statusReasonHasBeenSet = true; m_statusReason = std::forward<StatusReasonT>(value); }
+    template<typename StatusReasonT = Aws::String>
+    ApplicationVersionSummary& WithStatusReason(StatusReasonT&& value) { SetStatusReason(std::forward<StatusReasonT>(value)); return *this;}
     ///@}
   private:
 
-    int m_applicationVersion;
+    int m_applicationVersion{0};
     bool m_applicationVersionHasBeenSet = false;
 
-    Aws::Utils::DateTime m_creationTime;
+    Aws::Utils::DateTime m_creationTime{};
     bool m_creationTimeHasBeenSet = false;
 
-    ApplicationVersionLifecycle m_status;
+    ApplicationVersionLifecycle m_status{ApplicationVersionLifecycle::NOT_SET};
     bool m_statusHasBeenSet = false;
 
     Aws::String m_statusReason;
