@@ -29,7 +29,7 @@ namespace Model
   class RecordLength
   {
   public:
-    AWS_MAINFRAMEMODERNIZATION_API RecordLength();
+    AWS_MAINFRAMEMODERNIZATION_API RecordLength() = default;
     AWS_MAINFRAMEMODERNIZATION_API RecordLength(Aws::Utils::Json::JsonView jsonValue);
     AWS_MAINFRAMEMODERNIZATION_API RecordLength& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MAINFRAMEMODERNIZATION_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -40,7 +40,7 @@ namespace Model
      * <p>The maximum record length. In case of fixed, both minimum and maximum are the
      * same.</p>
      */
-    inline int GetMax() const{ return m_max; }
+    inline int GetMax() const { return m_max; }
     inline bool MaxHasBeenSet() const { return m_maxHasBeenSet; }
     inline void SetMax(int value) { m_maxHasBeenSet = true; m_max = value; }
     inline RecordLength& WithMax(int value) { SetMax(value); return *this;}
@@ -50,17 +50,17 @@ namespace Model
     /**
      * <p>The minimum record length of a record.</p>
      */
-    inline int GetMin() const{ return m_min; }
+    inline int GetMin() const { return m_min; }
     inline bool MinHasBeenSet() const { return m_minHasBeenSet; }
     inline void SetMin(int value) { m_minHasBeenSet = true; m_min = value; }
     inline RecordLength& WithMin(int value) { SetMin(value); return *this;}
     ///@}
   private:
 
-    int m_max;
+    int m_max{0};
     bool m_maxHasBeenSet = false;
 
-    int m_min;
+    int m_min{0};
     bool m_minHasBeenSet = false;
   };
 
