@@ -32,7 +32,7 @@ namespace Model
   class ServiceLimit
   {
   public:
-    AWS_MACIE2_API ServiceLimit();
+    AWS_MACIE2_API ServiceLimit() = default;
     AWS_MACIE2_API ServiceLimit(Aws::Utils::Json::JsonView jsonValue);
     AWS_MACIE2_API ServiceLimit& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MACIE2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,7 +43,7 @@ namespace Model
      * <p>Specifies whether the account has met the quota that corresponds to the
      * metric specified by the UsageByAccount.type field in the response.</p>
      */
-    inline bool GetIsServiceLimited() const{ return m_isServiceLimited; }
+    inline bool GetIsServiceLimited() const { return m_isServiceLimited; }
     inline bool IsServiceLimitedHasBeenSet() const { return m_isServiceLimitedHasBeenSet; }
     inline void SetIsServiceLimited(bool value) { m_isServiceLimitedHasBeenSet = true; m_isServiceLimited = value; }
     inline ServiceLimit& WithIsServiceLimited(bool value) { SetIsServiceLimited(value); return *this;}
@@ -53,12 +53,10 @@ namespace Model
     /**
      * <p>The unit of measurement for the value specified by the value field.</p>
      */
-    inline const Unit& GetUnit() const{ return m_unit; }
+    inline Unit GetUnit() const { return m_unit; }
     inline bool UnitHasBeenSet() const { return m_unitHasBeenSet; }
-    inline void SetUnit(const Unit& value) { m_unitHasBeenSet = true; m_unit = value; }
-    inline void SetUnit(Unit&& value) { m_unitHasBeenSet = true; m_unit = std::move(value); }
-    inline ServiceLimit& WithUnit(const Unit& value) { SetUnit(value); return *this;}
-    inline ServiceLimit& WithUnit(Unit&& value) { SetUnit(std::move(value)); return *this;}
+    inline void SetUnit(Unit value) { m_unitHasBeenSet = true; m_unit = value; }
+    inline ServiceLimit& WithUnit(Unit value) { SetUnit(value); return *this;}
     ///@}
 
     ///@{
@@ -66,20 +64,20 @@ namespace Model
      * <p>The value for the metric specified by the UsageByAccount.type field in the
      * response.</p>
      */
-    inline long long GetValue() const{ return m_value; }
+    inline long long GetValue() const { return m_value; }
     inline bool ValueHasBeenSet() const { return m_valueHasBeenSet; }
     inline void SetValue(long long value) { m_valueHasBeenSet = true; m_value = value; }
     inline ServiceLimit& WithValue(long long value) { SetValue(value); return *this;}
     ///@}
   private:
 
-    bool m_isServiceLimited;
+    bool m_isServiceLimited{false};
     bool m_isServiceLimitedHasBeenSet = false;
 
-    Unit m_unit;
+    Unit m_unit{Unit::NOT_SET};
     bool m_unitHasBeenSet = false;
 
-    long long m_value;
+    long long m_value{0};
     bool m_valueHasBeenSet = false;
   };
 
