@@ -32,7 +32,7 @@ namespace Model
   class SessionContextAttributes
   {
   public:
-    AWS_MACIE2_API SessionContextAttributes();
+    AWS_MACIE2_API SessionContextAttributes() = default;
     AWS_MACIE2_API SessionContextAttributes(Aws::Utils::Json::JsonView jsonValue);
     AWS_MACIE2_API SessionContextAttributes& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MACIE2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,12 +43,12 @@ namespace Model
      * <p>The date and time, in UTC and ISO 8601 format, when the credentials were
      * issued.</p>
      */
-    inline const Aws::Utils::DateTime& GetCreationDate() const{ return m_creationDate; }
+    inline const Aws::Utils::DateTime& GetCreationDate() const { return m_creationDate; }
     inline bool CreationDateHasBeenSet() const { return m_creationDateHasBeenSet; }
-    inline void SetCreationDate(const Aws::Utils::DateTime& value) { m_creationDateHasBeenSet = true; m_creationDate = value; }
-    inline void SetCreationDate(Aws::Utils::DateTime&& value) { m_creationDateHasBeenSet = true; m_creationDate = std::move(value); }
-    inline SessionContextAttributes& WithCreationDate(const Aws::Utils::DateTime& value) { SetCreationDate(value); return *this;}
-    inline SessionContextAttributes& WithCreationDate(Aws::Utils::DateTime&& value) { SetCreationDate(std::move(value)); return *this;}
+    template<typename CreationDateT = Aws::Utils::DateTime>
+    void SetCreationDate(CreationDateT&& value) { m_creationDateHasBeenSet = true; m_creationDate = std::forward<CreationDateT>(value); }
+    template<typename CreationDateT = Aws::Utils::DateTime>
+    SessionContextAttributes& WithCreationDate(CreationDateT&& value) { SetCreationDate(std::forward<CreationDateT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -56,17 +56,17 @@ namespace Model
      * <p>Specifies whether the credentials were authenticated with a multi-factor
      * authentication (MFA) device.</p>
      */
-    inline bool GetMfaAuthenticated() const{ return m_mfaAuthenticated; }
+    inline bool GetMfaAuthenticated() const { return m_mfaAuthenticated; }
     inline bool MfaAuthenticatedHasBeenSet() const { return m_mfaAuthenticatedHasBeenSet; }
     inline void SetMfaAuthenticated(bool value) { m_mfaAuthenticatedHasBeenSet = true; m_mfaAuthenticated = value; }
     inline SessionContextAttributes& WithMfaAuthenticated(bool value) { SetMfaAuthenticated(value); return *this;}
     ///@}
   private:
 
-    Aws::Utils::DateTime m_creationDate;
+    Aws::Utils::DateTime m_creationDate{};
     bool m_creationDateHasBeenSet = false;
 
-    bool m_mfaAuthenticated;
+    bool m_mfaAuthenticated{false};
     bool m_mfaAuthenticatedHasBeenSet = false;
   };
 
