@@ -25,7 +25,7 @@ namespace Model
   class ConfigureLogsRequest : public MediaPackageVodRequest
   {
   public:
-    AWS_MEDIAPACKAGEVOD_API ConfigureLogsRequest();
+    AWS_MEDIAPACKAGEVOD_API ConfigureLogsRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -38,26 +38,24 @@ namespace Model
 
     ///@{
     
-    inline const EgressAccessLogs& GetEgressAccessLogs() const{ return m_egressAccessLogs; }
+    inline const EgressAccessLogs& GetEgressAccessLogs() const { return m_egressAccessLogs; }
     inline bool EgressAccessLogsHasBeenSet() const { return m_egressAccessLogsHasBeenSet; }
-    inline void SetEgressAccessLogs(const EgressAccessLogs& value) { m_egressAccessLogsHasBeenSet = true; m_egressAccessLogs = value; }
-    inline void SetEgressAccessLogs(EgressAccessLogs&& value) { m_egressAccessLogsHasBeenSet = true; m_egressAccessLogs = std::move(value); }
-    inline ConfigureLogsRequest& WithEgressAccessLogs(const EgressAccessLogs& value) { SetEgressAccessLogs(value); return *this;}
-    inline ConfigureLogsRequest& WithEgressAccessLogs(EgressAccessLogs&& value) { SetEgressAccessLogs(std::move(value)); return *this;}
+    template<typename EgressAccessLogsT = EgressAccessLogs>
+    void SetEgressAccessLogs(EgressAccessLogsT&& value) { m_egressAccessLogsHasBeenSet = true; m_egressAccessLogs = std::forward<EgressAccessLogsT>(value); }
+    template<typename EgressAccessLogsT = EgressAccessLogs>
+    ConfigureLogsRequest& WithEgressAccessLogs(EgressAccessLogsT&& value) { SetEgressAccessLogs(std::forward<EgressAccessLogsT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * The ID of a MediaPackage VOD PackagingGroup resource.
      */
-    inline const Aws::String& GetId() const{ return m_id; }
+    inline const Aws::String& GetId() const { return m_id; }
     inline bool IdHasBeenSet() const { return m_idHasBeenSet; }
-    inline void SetId(const Aws::String& value) { m_idHasBeenSet = true; m_id = value; }
-    inline void SetId(Aws::String&& value) { m_idHasBeenSet = true; m_id = std::move(value); }
-    inline void SetId(const char* value) { m_idHasBeenSet = true; m_id.assign(value); }
-    inline ConfigureLogsRequest& WithId(const Aws::String& value) { SetId(value); return *this;}
-    inline ConfigureLogsRequest& WithId(Aws::String&& value) { SetId(std::move(value)); return *this;}
-    inline ConfigureLogsRequest& WithId(const char* value) { SetId(value); return *this;}
+    template<typename IdT = Aws::String>
+    void SetId(IdT&& value) { m_idHasBeenSet = true; m_id = std::forward<IdT>(value); }
+    template<typename IdT = Aws::String>
+    ConfigureLogsRequest& WithId(IdT&& value) { SetId(std::forward<IdT>(value)); return *this;}
     ///@}
   private:
 
