@@ -13,6 +13,7 @@
 #include <aws/mediapackagev2/model/ListHlsManifestConfiguration.h>
 #include <aws/mediapackagev2/model/ListLowLatencyHlsManifestConfiguration.h>
 #include <aws/mediapackagev2/model/ListDashManifestConfiguration.h>
+#include <aws/mediapackagev2/model/ListMssManifestConfiguration.h>
 #include <utility>
 
 namespace Aws
@@ -189,6 +190,22 @@ namespace Model
     OriginEndpointListConfiguration& AddDashManifests(DashManifestsT&& value) { m_dashManifestsHasBeenSet = true; m_dashManifests.emplace_back(std::forward<DashManifestsT>(value)); return *this; }
     ///@}
 
+    ///@{
+    /**
+     * <p>A list of Microsoft Smooth Streaming (MSS) manifest configurations associated
+     * with the origin endpoint. Each configuration represents a different MSS
+     * streaming option available from this endpoint.</p>
+     */
+    inline const Aws::Vector<ListMssManifestConfiguration>& GetMssManifests() const { return m_mssManifests; }
+    inline bool MssManifestsHasBeenSet() const { return m_mssManifestsHasBeenSet; }
+    template<typename MssManifestsT = Aws::Vector<ListMssManifestConfiguration>>
+    void SetMssManifests(MssManifestsT&& value) { m_mssManifestsHasBeenSet = true; m_mssManifests = std::forward<MssManifestsT>(value); }
+    template<typename MssManifestsT = Aws::Vector<ListMssManifestConfiguration>>
+    OriginEndpointListConfiguration& WithMssManifests(MssManifestsT&& value) { SetMssManifests(std::forward<MssManifestsT>(value)); return *this;}
+    template<typename MssManifestsT = ListMssManifestConfiguration>
+    OriginEndpointListConfiguration& AddMssManifests(MssManifestsT&& value) { m_mssManifestsHasBeenSet = true; m_mssManifests.emplace_back(std::forward<MssManifestsT>(value)); return *this; }
+    ///@}
+
     ///@{
     /**
      * <p>The failover settings for the endpoint.</p>
@@ -235,6 +252,9 @@ namespace Model
     Aws::Vector<ListDashManifestConfiguration> m_dashManifests;
     bool m_dashManifestsHasBeenSet = false;
 
+    Aws::Vector<ListMssManifestConfiguration> m_mssManifests;
+    bool m_mssManifestsHasBeenSet = false;
+
     ForceEndpointErrorConfiguration m_forceEndpointErrorConfiguration;
     bool m_forceEndpointErrorConfigurationHasBeenSet = false;
   };
