@@ -87,7 +87,22 @@ namespace Model
     ISM_CONTAINER_TYPE_WITH_LL_HLS_MANIFEST,
     ISM_CONTAINER_TYPE_WITH_DASH_MANIFEST,
     ISM_CONTAINER_TYPE_WITH_SCTE,
-    ISM_CONTAINER_WITH_KEY_ROTATION
+    ISM_CONTAINER_WITH_KEY_ROTATION,
+    BATCH_GET_SECRET_VALUE_DENIED,
+    GET_SECRET_VALUE_DENIED,
+    DESCRIBE_SECRET_DENIED,
+    INVALID_SECRET_FORMAT,
+    SECRET_IS_NOT_ONE_KEY_VALUE_PAIR,
+    INVALID_SECRET_KEY,
+    INVALID_SECRET_VALUE,
+    SECRET_ARN_RESOURCE_NOT_FOUND,
+    DECRYPT_SECRET_FAILED,
+    TOO_MANY_SECRETS,
+    DUPLICATED_SECRET,
+    MALFORMED_SECRET_ARN,
+    SECRET_FROM_DIFFERENT_ACCOUNT,
+    SECRET_FROM_DIFFERENT_REGION,
+    INVALID_SECRET
   };
 
 namespace ValidationExceptionTypeMapper
