@@ -32,7 +32,7 @@ namespace Model
   class LogConfigurationForChannel
   {
   public:
-    AWS_MEDIATAILOR_API LogConfigurationForChannel();
+    AWS_MEDIATAILOR_API LogConfigurationForChannel() = default;
     AWS_MEDIATAILOR_API LogConfigurationForChannel(Aws::Utils::Json::JsonView jsonValue);
     AWS_MEDIATAILOR_API LogConfigurationForChannel& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MEDIATAILOR_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,14 +42,13 @@ namespace Model
     /**
      * <p>The log types.</p>
      */
-    inline const Aws::Vector<LogType>& GetLogTypes() const{ return m_logTypes; }
+    inline const Aws::Vector<LogType>& GetLogTypes() const { return m_logTypes; }
     inline bool LogTypesHasBeenSet() const { return m_logTypesHasBeenSet; }
-    inline void SetLogTypes(const Aws::Vector<LogType>& value) { m_logTypesHasBeenSet = true; m_logTypes = value; }
-    inline void SetLogTypes(Aws::Vector<LogType>&& value) { m_logTypesHasBeenSet = true; m_logTypes = std::move(value); }
-    inline LogConfigurationForChannel& WithLogTypes(const Aws::Vector<LogType>& value) { SetLogTypes(value); return *this;}
-    inline LogConfigurationForChannel& WithLogTypes(Aws::Vector<LogType>&& value) { SetLogTypes(std::move(value)); return *this;}
-    inline LogConfigurationForChannel& AddLogTypes(const LogType& value) { m_logTypesHasBeenSet = true; m_logTypes.push_back(value); return *this; }
-    inline LogConfigurationForChannel& AddLogTypes(LogType&& value) { m_logTypesHasBeenSet = true; m_logTypes.push_back(std::move(value)); return *this; }
+    template<typename LogTypesT = Aws::Vector<LogType>>
+    void SetLogTypes(LogTypesT&& value) { m_logTypesHasBeenSet = true; m_logTypes = std::forward<LogTypesT>(value); }
+    template<typename LogTypesT = Aws::Vector<LogType>>
+    LogConfigurationForChannel& WithLogTypes(LogTypesT&& value) { SetLogTypes(std::forward<LogTypesT>(value)); return *this;}
+    inline LogConfigurationForChannel& AddLogTypes(LogType value) { m_logTypesHasBeenSet = true; m_logTypes.push_back(value); return *this; }
     ///@}
   private:
 
