@@ -32,7 +32,7 @@ namespace Model
   class Tag
   {
   public:
-    AWS_MARKETPLACEMETERING_API Tag();
+    AWS_MARKETPLACEMETERING_API Tag() = default;
     AWS_MARKETPLACEMETERING_API Tag(Aws::Utils::Json::JsonView jsonValue);
     AWS_MARKETPLACEMETERING_API Tag& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MARKETPLACEMETERING_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,14 +44,12 @@ namespace Model
      * <code>key</code> is a label that acts like a category for the specific tag
      * values.</p>
      */
-    inline const Aws::String& GetKey() const{ return m_key; }
+    inline const Aws::String& GetKey() const { return m_key; }
     inline bool KeyHasBeenSet() const { return m_keyHasBeenSet; }
-    inline void SetKey(const Aws::String& value) { m_keyHasBeenSet = true; m_key = value; }
-    inline void SetKey(Aws::String&& value) { m_keyHasBeenSet = true; m_key = std::move(value); }
-    inline void SetKey(const char* value) { m_keyHasBeenSet = true; m_key.assign(value); }
-    inline Tag& WithKey(const Aws::String& value) { SetKey(value); return *this;}
-    inline Tag& WithKey(Aws::String&& value) { SetKey(std::move(value)); return *this;}
-    inline Tag& WithKey(const char* value) { SetKey(value); return *this;}
+    template<typename KeyT = Aws::String>
+    void SetKey(KeyT&& value) { m_keyHasBeenSet = true; m_key = std::forward<KeyT>(value); }
+    template<typename KeyT = Aws::String>
+    Tag& WithKey(KeyT&& value) { SetKey(std::forward<KeyT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -60,14 +58,12 @@ namespace Model
      * <code>value</code> acts as a descriptor within a tag category (key). The value
      * can be empty or null.</p>
      */
-    inline const Aws::String& GetValue() const{ return m_value; }
+    inline const Aws::String& GetValue() const { return m_value; }
     inline bool ValueHasBeenSet() const { return m_valueHasBeenSet; }
-    inline void SetValue(const Aws::String& value) { m_valueHasBeenSet = true; m_value = value; }
-    inline void SetValue(Aws::String&& value) { m_valueHasBeenSet = true; m_value = std::move(value); }
-    inline void SetValue(const char* value) { m_valueHasBeenSet = true; m_value.assign(value); }
-    inline Tag& WithValue(const Aws::String& value) { SetValue(value); return *this;}
-    inline Tag& WithValue(Aws::String&& value) { SetValue(std::move(value)); return *this;}
-    inline Tag& WithValue(const char* value) { SetValue(value); return *this;}
+    template<typename ValueT = Aws::String>
+    void SetValue(ValueT&& value) { m_valueHasBeenSet = true; m_value = std::forward<ValueT>(value); }
+    template<typename ValueT = Aws::String>
+    Tag& WithValue(ValueT&& value) { SetValue(std::forward<ValueT>(value)); return *this;}
     ///@}
   private:
 
