@@ -21,7 +21,7 @@ namespace Model
   class ApproveAssignmentRequest : public MTurkRequest
   {
   public:
-    AWS_MTURK_API ApproveAssignmentRequest();
+    AWS_MTURK_API ApproveAssignmentRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -39,14 +39,12 @@ namespace Model
      * <p> The ID of the assignment. The assignment must correspond to a HIT created by
      * the Requester. </p>
      */
-    inline const Aws::String& GetAssignmentId() const{ return m_assignmentId; }
+    inline const Aws::String& GetAssignmentId() const { return m_assignmentId; }
     inline bool AssignmentIdHasBeenSet() const { return m_assignmentIdHasBeenSet; }
-    inline void SetAssignmentId(const Aws::String& value) { m_assignmentIdHasBeenSet = true; m_assignmentId = value; }
-    inline void SetAssignmentId(Aws::String&& value) { m_assignmentIdHasBeenSet = true; m_assignmentId = std::move(value); }
-    inline void SetAssignmentId(const char* value) { m_assignmentIdHasBeenSet = true; m_assignmentId.assign(value); }
-    inline ApproveAssignmentRequest& WithAssignmentId(const Aws::String& value) { SetAssignmentId(value); return *this;}
-    inline ApproveAssignmentRequest& WithAssignmentId(Aws::String&& value) { SetAssignmentId(std::move(value)); return *this;}
-    inline ApproveAssignmentRequest& WithAssignmentId(const char* value) { SetAssignmentId(value); return *this;}
+    template<typename AssignmentIdT = Aws::String>
+    void SetAssignmentId(AssignmentIdT&& value) { m_assignmentIdHasBeenSet = true; m_assignmentId = std::forward<AssignmentIdT>(value); }
+    template<typename AssignmentIdT = Aws::String>
+    ApproveAssignmentRequest& WithAssignmentId(AssignmentIdT&& value) { SetAssignmentId(std::forward<AssignmentIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -54,14 +52,12 @@ namespace Model
      * <p> A message for the Worker, which the Worker can see in the Status section of
      * the web site. </p>
      */
-    inline const Aws::String& GetRequesterFeedback() const{ return m_requesterFeedback; }
+    inline const Aws::String& GetRequesterFeedback() const { return m_requesterFeedback; }
     inline bool RequesterFeedbackHasBeenSet() const { return m_requesterFeedbackHasBeenSet; }
-    inline void SetRequesterFeedback(const Aws::String& value) { m_requesterFeedbackHasBeenSet = true; m_requesterFeedback = value; }
-    inline void SetRequesterFeedback(Aws::String&& value) { m_requesterFeedbackHasBeenSet = true; m_requesterFeedback = std::move(value); }
-    inline void SetRequesterFeedback(const char* value) { m_requesterFeedbackHasBeenSet = true; m_requesterFeedback.assign(value); }
-    inline ApproveAssignmentRequest& WithRequesterFeedback(const Aws::String& value) { SetRequesterFeedback(value); return *this;}
-    inline ApproveAssignmentRequest& WithRequesterFeedback(Aws::String&& value) { SetRequesterFeedback(std::move(value)); return *this;}
-    inline ApproveAssignmentRequest& WithRequesterFeedback(const char* value) { SetRequesterFeedback(value); return *this;}
+    template<typename RequesterFeedbackT = Aws::String>
+    void SetRequesterFeedback(RequesterFeedbackT&& value) { m_requesterFeedbackHasBeenSet = true; m_requesterFeedback = std::forward<RequesterFeedbackT>(value); }
+    template<typename RequesterFeedbackT = Aws::String>
+    ApproveAssignmentRequest& WithRequesterFeedback(RequesterFeedbackT&& value) { SetRequesterFeedback(std::forward<RequesterFeedbackT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -69,7 +65,7 @@ namespace Model
      * <p> A flag indicating that an assignment should be approved even if it was
      * previously rejected. Defaults to <code>False</code>. </p>
      */
-    inline bool GetOverrideRejection() const{ return m_overrideRejection; }
+    inline bool GetOverrideRejection() const { return m_overrideRejection; }
     inline bool OverrideRejectionHasBeenSet() const { return m_overrideRejectionHasBeenSet; }
     inline void SetOverrideRejection(bool value) { m_overrideRejectionHasBeenSet = true; m_overrideRejection = value; }
     inline ApproveAssignmentRequest& WithOverrideRejection(bool value) { SetOverrideRejection(value); return *this;}
@@ -82,7 +78,7 @@ namespace Model
     Aws::String m_requesterFeedback;
     bool m_requesterFeedbackHasBeenSet = false;
 
-    bool m_overrideRejection;
+    bool m_overrideRejection{false};
     bool m_overrideRejectionHasBeenSet = false;
   };
 
