@@ -7,10 +7,12 @@
 
 /* Generic header includes */
 #include <aws/opsworks/OpsWorksErrors.h>
+#include <aws/core/client/GenericClientConfiguration.h>
 #include <aws/core/client/AWSError.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/client/AsyncCallerContext.h>
 #include <aws/core/http/HttpTypes.h>
+#include <aws/opsworks/OpsWorksEndpointProvider.h>
 #include <future>
 #include <functional>
 /* End of generic header includes */
@@ -52,6 +54,24 @@
 #include <aws/opsworks/model/RegisterElasticIpResult.h>
 #include <aws/opsworks/model/RegisterInstanceResult.h>
 #include <aws/opsworks/model/RegisterVolumeResult.h>
+#include <aws/opsworks/model/DescribeCommandsRequest.h>
+#include <aws/opsworks/model/DescribeAppsRequest.h>
+#include <aws/opsworks/model/DescribeUserProfilesRequest.h>
+#include <aws/opsworks/model/UpdateMyUserProfileRequest.h>
+#include <aws/opsworks/model/DescribeMyUserProfileRequest.h>
+#include <aws/opsworks/model/DescribeRaidArraysRequest.h>
+#include <aws/opsworks/model/DescribePermissionsRequest.h>
+#include <aws/opsworks/model/DescribeLayersRequest.h>
+#include <aws/opsworks/model/DescribeServiceErrorsRequest.h>
+#include <aws/opsworks/model/DescribeAgentVersionsRequest.h>
+#include <aws/opsworks/model/DescribeStacksRequest.h>
+#include <aws/opsworks/model/DescribeVolumesRequest.h>
+#include <aws/opsworks/model/DescribeElasticIpsRequest.h>
+#include <aws/opsworks/model/DescribeOperatingSystemsRequest.h>
+#include <aws/opsworks/model/DescribeInstancesRequest.h>
+#include <aws/opsworks/model/DescribeDeploymentsRequest.h>
+#include <aws/opsworks/model/DescribeEcsClustersRequest.h>
+#include <aws/opsworks/model/DescribeElasticLoadBalancersRequest.h>
 #include <aws/core/NoResult.h>
 /* End of service model headers required in OpsWorksClient header */
 
@@ -86,6 +106,10 @@ namespace Aws
 
   namespace OpsWorks
   {
+    using OpsWorksClientConfiguration = Aws::Client::GenericClientConfiguration;
+    using OpsWorksEndpointProviderBase = Aws::OpsWorks::Endpoint::OpsWorksEndpointProviderBase;
+    using OpsWorksEndpointProvider = Aws::OpsWorks::Endpoint::OpsWorksEndpointProvider;
+
     namespace Model
     {
       /* Service model forward declarations required in OpsWorksClient header */
@@ -120,6 +144,8 @@ namespace Aws
       class DescribeInstancesRequest;
       class DescribeLayersRequest;
       class DescribeLoadBasedAutoScalingRequest;
+      class DescribeMyUserProfileRequest;
+      class DescribeOperatingSystemsRequest;
       class DescribePermissionsRequest;
       class DescribeRaidArraysRequest;
       class DescribeRdsDbInstancesRequest;
@@ -352,8 +378,8 @@ namespace Aws
     typedef std::function<void(const OpsWorksClient*, const Model::DescribeInstancesRequest&, const Model::DescribeInstancesOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeInstancesResponseReceivedHandler;
     typedef std::function<void(const OpsWorksClient*, const Model::DescribeLayersRequest&, const Model::DescribeLayersOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeLayersResponseReceivedHandler;
     typedef std::function<void(const OpsWorksClient*, const Model::DescribeLoadBasedAutoScalingRequest&, const Model::DescribeLoadBasedAutoScalingOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeLoadBasedAutoScalingResponseReceivedHandler;
-    typedef std::function<void(const OpsWorksClient*, const Model::DescribeMyUserProfileOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeMyUserProfileResponseReceivedHandler;
-    typedef std::function<void(const OpsWorksClient*, const Model::DescribeOperatingSystemsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeOperatingSystemsResponseReceivedHandler;
+    typedef std::function<void(const OpsWorksClient*, const Model::DescribeMyUserProfileRequest&, const Model::DescribeMyUserProfileOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeMyUserProfileResponseReceivedHandler;
+    typedef std::function<void(const OpsWorksClient*, const Model::DescribeOperatingSystemsRequest&, const Model::DescribeOperatingSystemsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeOperatingSystemsResponseReceivedHandler;
     typedef std::function<void(const OpsWorksClient*, const Model::DescribePermissionsRequest&, const Model::DescribePermissionsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribePermissionsResponseReceivedHandler;
     typedef std::function<void(const OpsWorksClient*, const Model::DescribeRaidArraysRequest&, const Model::DescribeRaidArraysOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeRaidArraysResponseReceivedHandler;
     typedef std::function<void(const OpsWorksClient*, const Model::DescribeRdsDbInstancesRequest&, const Model::DescribeRdsDbInstancesOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DescribeRdsDbInstancesResponseReceivedHandler;
