@@ -31,7 +31,7 @@ namespace Model
   class Permission
   {
   public:
-    AWS_OPSWORKS_API Permission();
+    AWS_OPSWORKS_API Permission() = default;
     AWS_OPSWORKS_API Permission(Aws::Utils::Json::JsonView jsonValue);
     AWS_OPSWORKS_API Permission& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_OPSWORKS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -41,14 +41,12 @@ namespace Model
     /**
      * <p>A stack ID.</p>
      */
-    inline const Aws::String& GetStackId() const{ return m_stackId; }
+    inline const Aws::String& GetStackId() const { return m_stackId; }
     inline bool StackIdHasBeenSet() const { return m_stackIdHasBeenSet; }
-    inline void SetStackId(const Aws::String& value) { m_stackIdHasBeenSet = true; m_stackId = value; }
-    inline void SetStackId(Aws::String&& value) { m_stackIdHasBeenSet = true; m_stackId = std::move(value); }
-    inline void SetStackId(const char* value) { m_stackIdHasBeenSet = true; m_stackId.assign(value); }
-    inline Permission& WithStackId(const Aws::String& value) { SetStackId(value); return *this;}
-    inline Permission& WithStackId(Aws::String&& value) { SetStackId(std::move(value)); return *this;}
-    inline Permission& WithStackId(const char* value) { SetStackId(value); return *this;}
+    template<typename StackIdT = Aws::String>
+    void SetStackId(StackIdT&& value) { m_stackIdHasBeenSet = true; m_stackId = std::forward<StackIdT>(value); }
+    template<typename StackIdT = Aws::String>
+    Permission& WithStackId(StackIdT&& value) { SetStackId(std::forward<StackIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -58,21 +56,19 @@ namespace Model
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">Using
      * Identifiers</a>.</p>
      */
-    inline const Aws::String& GetIamUserArn() const{ return m_iamUserArn; }
+    inline const Aws::String& GetIamUserArn() const { return m_iamUserArn; }
     inline bool IamUserArnHasBeenSet() const { return m_iamUserArnHasBeenSet; }
-    inline void SetIamUserArn(const Aws::String& value) { m_iamUserArnHasBeenSet = true; m_iamUserArn = value; }
-    inline void SetIamUserArn(Aws::String&& value) { m_iamUserArnHasBeenSet = true; m_iamUserArn = std::move(value); }
-    inline void SetIamUserArn(const char* value) { m_iamUserArnHasBeenSet = true; m_iamUserArn.assign(value); }
-    inline Permission& WithIamUserArn(const Aws::String& value) { SetIamUserArn(value); return *this;}
-    inline Permission& WithIamUserArn(Aws::String&& value) { SetIamUserArn(std::move(value)); return *this;}
-    inline Permission& WithIamUserArn(const char* value) { SetIamUserArn(value); return *this;}
+    template<typename IamUserArnT = Aws::String>
+    void SetIamUserArn(IamUserArnT&& value) { m_iamUserArnHasBeenSet = true; m_iamUserArn = std::forward<IamUserArnT>(value); }
+    template<typename IamUserArnT = Aws::String>
+    Permission& WithIamUserArn(IamUserArnT&& value) { SetIamUserArn(std::forward<IamUserArnT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Whether the user can use SSH.</p>
      */
-    inline bool GetAllowSsh() const{ return m_allowSsh; }
+    inline bool GetAllowSsh() const { return m_allowSsh; }
     inline bool AllowSshHasBeenSet() const { return m_allowSshHasBeenSet; }
     inline void SetAllowSsh(bool value) { m_allowSshHasBeenSet = true; m_allowSsh = value; }
     inline Permission& WithAllowSsh(bool value) { SetAllowSsh(value); return *this;}
@@ -82,7 +78,7 @@ namespace Model
     /**
      * <p>Whether the user can use <b>sudo</b>.</p>
      */
-    inline bool GetAllowSudo() const{ return m_allowSudo; }
+    inline bool GetAllowSudo() const { return m_allowSudo; }
     inline bool AllowSudoHasBeenSet() const { return m_allowSudoHasBeenSet; }
     inline void SetAllowSudo(bool value) { m_allowSudoHasBeenSet = true; m_allowSudo = value; }
     inline Permission& WithAllowSudo(bool value) { SetAllowSudo(value); return *this;}
@@ -98,14 +94,12 @@ namespace Model
      * href="https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html">Managing
      * User Permissions</a> </p>
      */
-    inline const Aws::String& GetLevel() const{ return m_level; }
+    inline const Aws::String& GetLevel() const { return m_level; }
     inline bool LevelHasBeenSet() const { return m_levelHasBeenSet; }
-    inline void SetLevel(const Aws::String& value) { m_levelHasBeenSet = true; m_level = value; }
-    inline void SetLevel(Aws::String&& value) { m_levelHasBeenSet = true; m_level = std::move(value); }
-    inline void SetLevel(const char* value) { m_levelHasBeenSet = true; m_level.assign(value); }
-    inline Permission& WithLevel(const Aws::String& value) { SetLevel(value); return *this;}
-    inline Permission& WithLevel(Aws::String&& value) { SetLevel(std::move(value)); return *this;}
-    inline Permission& WithLevel(const char* value) { SetLevel(value); return *this;}
+    template<typename LevelT = Aws::String>
+    void SetLevel(LevelT&& value) { m_levelHasBeenSet = true; m_level = std::forward<LevelT>(value); }
+    template<typename LevelT = Aws::String>
+    Permission& WithLevel(LevelT&& value) { SetLevel(std::forward<LevelT>(value)); return *this;}
     ///@}
   private:
 
@@ -115,10 +109,10 @@ namespace Model
     Aws::String m_iamUserArn;
     bool m_iamUserArnHasBeenSet = false;
 
-    bool m_allowSsh;
+    bool m_allowSsh{false};
     bool m_allowSshHasBeenSet = false;
 
-    bool m_allowSudo;
+    bool m_allowSudo{false};
     bool m_allowSudoHasBeenSet = false;
 
     Aws::String m_level;
