@@ -31,7 +31,7 @@ namespace Model
   class VolumeConfiguration
   {
   public:
-    AWS_OPSWORKS_API VolumeConfiguration();
+    AWS_OPSWORKS_API VolumeConfiguration() = default;
     AWS_OPSWORKS_API VolumeConfiguration(Aws::Utils::Json::JsonView jsonValue);
     AWS_OPSWORKS_API VolumeConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_OPSWORKS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -41,14 +41,12 @@ namespace Model
     /**
      * <p>The volume mount point. For example "/dev/sdh".</p>
      */
-    inline const Aws::String& GetMountPoint() const{ return m_mountPoint; }
+    inline const Aws::String& GetMountPoint() const { return m_mountPoint; }
     inline bool MountPointHasBeenSet() const { return m_mountPointHasBeenSet; }
-    inline void SetMountPoint(const Aws::String& value) { m_mountPointHasBeenSet = true; m_mountPoint = value; }
-    inline void SetMountPoint(Aws::String&& value) { m_mountPointHasBeenSet = true; m_mountPoint = std::move(value); }
-    inline void SetMountPoint(const char* value) { m_mountPointHasBeenSet = true; m_mountPoint.assign(value); }
-    inline VolumeConfiguration& WithMountPoint(const Aws::String& value) { SetMountPoint(value); return *this;}
-    inline VolumeConfiguration& WithMountPoint(Aws::String&& value) { SetMountPoint(std::move(value)); return *this;}
-    inline VolumeConfiguration& WithMountPoint(const char* value) { SetMountPoint(value); return *this;}
+    template<typename MountPointT = Aws::String>
+    void SetMountPoint(MountPointT&& value) { m_mountPointHasBeenSet = true; m_mountPoint = std::forward<MountPointT>(value); }
+    template<typename MountPointT = Aws::String>
+    VolumeConfiguration& WithMountPoint(MountPointT&& value) { SetMountPoint(std::forward<MountPointT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -56,7 +54,7 @@ namespace Model
      * <p>The volume <a href="http://en.wikipedia.org/wiki/Standard_RAID_levels">RAID
      * level</a>.</p>
      */
-    inline int GetRaidLevel() const{ return m_raidLevel; }
+    inline int GetRaidLevel() const { return m_raidLevel; }
     inline bool RaidLevelHasBeenSet() const { return m_raidLevelHasBeenSet; }
     inline void SetRaidLevel(int value) { m_raidLevelHasBeenSet = true; m_raidLevel = value; }
     inline VolumeConfiguration& WithRaidLevel(int value) { SetRaidLevel(value); return *this;}
@@ -66,7 +64,7 @@ namespace Model
     /**
      * <p>The number of disks in the volume.</p>
      */
-    inline int GetNumberOfDisks() const{ return m_numberOfDisks; }
+    inline int GetNumberOfDisks() const { return m_numberOfDisks; }
     inline bool NumberOfDisksHasBeenSet() const { return m_numberOfDisksHasBeenSet; }
     inline void SetNumberOfDisks(int value) { m_numberOfDisksHasBeenSet = true; m_numberOfDisks = value; }
     inline VolumeConfiguration& WithNumberOfDisks(int value) { SetNumberOfDisks(value); return *this;}
@@ -76,7 +74,7 @@ namespace Model
     /**
      * <p>The volume size.</p>
      */
-    inline int GetSize() const{ return m_size; }
+    inline int GetSize() const { return m_size; }
     inline bool SizeHasBeenSet() const { return m_sizeHasBeenSet; }
     inline void SetSize(int value) { m_sizeHasBeenSet = true; m_size = value; }
     inline VolumeConfiguration& WithSize(int value) { SetSize(value); return *this;}
@@ -97,21 +95,19 @@ namespace Model
      * 16384 GiB.</p> </li> <li> <p> <code>sc1</code> - Cold HDD. Cold HDD volumes must
      * have a minimum size of 125 GiB and a maximum size of 16384 GiB.</p> </li> </ul>
      */
-    inline const Aws::String& GetVolumeType() const{ return m_volumeType; }
+    inline const Aws::String& GetVolumeType() const { return m_volumeType; }
     inline bool VolumeTypeHasBeenSet() const { return m_volumeTypeHasBeenSet; }
-    inline void SetVolumeType(const Aws::String& value) { m_volumeTypeHasBeenSet = true; m_volumeType = value; }
-    inline void SetVolumeType(Aws::String&& value) { m_volumeTypeHasBeenSet = true; m_volumeType = std::move(value); }
-    inline void SetVolumeType(const char* value) { m_volumeTypeHasBeenSet = true; m_volumeType.assign(value); }
-    inline VolumeConfiguration& WithVolumeType(const Aws::String& value) { SetVolumeType(value); return *this;}
-    inline VolumeConfiguration& WithVolumeType(Aws::String&& value) { SetVolumeType(std::move(value)); return *this;}
-    inline VolumeConfiguration& WithVolumeType(const char* value) { SetVolumeType(value); return *this;}
+    template<typename VolumeTypeT = Aws::String>
+    void SetVolumeType(VolumeTypeT&& value) { m_volumeTypeHasBeenSet = true; m_volumeType = std::forward<VolumeTypeT>(value); }
+    template<typename VolumeTypeT = Aws::String>
+    VolumeConfiguration& WithVolumeType(VolumeTypeT&& value) { SetVolumeType(std::forward<VolumeTypeT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>For PIOPS volumes, the IOPS per disk.</p>
      */
-    inline int GetIops() const{ return m_iops; }
+    inline int GetIops() const { return m_iops; }
     inline bool IopsHasBeenSet() const { return m_iopsHasBeenSet; }
     inline void SetIops(int value) { m_iopsHasBeenSet = true; m_iops = value; }
     inline VolumeConfiguration& WithIops(int value) { SetIops(value); return *this;}
@@ -124,7 +120,7 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html">Amazon
      * EBS Encryption</a>.</p>
      */
-    inline bool GetEncrypted() const{ return m_encrypted; }
+    inline bool GetEncrypted() const { return m_encrypted; }
     inline bool EncryptedHasBeenSet() const { return m_encryptedHasBeenSet; }
     inline void SetEncrypted(bool value) { m_encryptedHasBeenSet = true; m_encrypted = value; }
     inline VolumeConfiguration& WithEncrypted(bool value) { SetEncrypted(value); return *this;}
@@ -134,22 +130,22 @@ namespace Model
     Aws::String m_mountPoint;
     bool m_mountPointHasBeenSet = false;
 
-    int m_raidLevel;
+    int m_raidLevel{0};
     bool m_raidLevelHasBeenSet = false;
 
-    int m_numberOfDisks;
+    int m_numberOfDisks{0};
     bool m_numberOfDisksHasBeenSet = false;
 
-    int m_size;
+    int m_size{0};
     bool m_sizeHasBeenSet = false;
 
     Aws::String m_volumeType;
     bool m_volumeTypeHasBeenSet = false;
 
-    int m_iops;
+    int m_iops{0};
     bool m_iopsHasBeenSet = false;
 
-    bool m_encrypted;
+    bool m_encrypted{false};
     bool m_encryptedHasBeenSet = false;
   };
 
