@@ -19,7 +19,7 @@ namespace Model
   class DescribeAccountAttributesRequest : public OpsWorksCMRequest
   {
   public:
-    AWS_OPSWORKSCM_API DescribeAccountAttributesRequest();
+    AWS_OPSWORKSCM_API DescribeAccountAttributesRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
