@@ -260,8 +260,8 @@ namespace Model
     ComputeNodeGroupSlurmConfigurationRequest m_slurmConfiguration;
     bool m_slurmConfigurationHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
 
     Aws::Map<Aws::String, Aws::String> m_tags;
     bool m_tagsHasBeenSet = false;
