@@ -21,7 +21,7 @@ namespace Model
   class DescribeFeatureTransformationRequest : public PersonalizeRequest
   {
   public:
-    AWS_PERSONALIZE_API DescribeFeatureTransformationRequest();
+    AWS_PERSONALIZE_API DescribeFeatureTransformationRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -38,14 +38,12 @@ namespace Model
     /**
      * <p>The Amazon Resource Name (ARN) of the feature transformation to describe.</p>
      */
-    inline const Aws::String& GetFeatureTransformationArn() const{ return m_featureTransformationArn; }
+    inline const Aws::String& GetFeatureTransformationArn() const { return m_featureTransformationArn; }
     inline bool FeatureTransformationArnHasBeenSet() const { return m_featureTransformationArnHasBeenSet; }
-    inline void SetFeatureTransformationArn(const Aws::String& value) { m_featureTransformationArnHasBeenSet = true; m_featureTransformationArn = value; }
-    inline void SetFeatureTransformationArn(Aws::String&& value) { m_featureTransformationArnHasBeenSet = true; m_featureTransformationArn = std::move(value); }
-    inline void SetFeatureTransformationArn(const char* value) { m_featureTransformationArnHasBeenSet = true; m_featureTransformationArn.assign(value); }
-    inline DescribeFeatureTransformationRequest& WithFeatureTransformationArn(const Aws::String& value) { SetFeatureTransformationArn(value); return *this;}
-    inline DescribeFeatureTransformationRequest& WithFeatureTransformationArn(Aws::String&& value) { SetFeatureTransformationArn(std::move(value)); return *this;}
-    inline DescribeFeatureTransformationRequest& WithFeatureTransformationArn(const char* value) { SetFeatureTransformationArn(value); return *this;}
+    template<typename FeatureTransformationArnT = Aws::String>
+    void SetFeatureTransformationArn(FeatureTransformationArnT&& value) { m_featureTransformationArnHasBeenSet = true; m_featureTransformationArn = std::forward<FeatureTransformationArnT>(value); }
+    template<typename FeatureTransformationArnT = Aws::String>
+    DescribeFeatureTransformationRequest& WithFeatureTransformationArn(FeatureTransformationArnT&& value) { SetFeatureTransformationArn(std::forward<FeatureTransformationArnT>(value)); return *this;}
     ///@}
   private:
 
