@@ -34,7 +34,7 @@ namespace Model
   class HPOConfig
   {
   public:
-    AWS_PERSONALIZE_API HPOConfig();
+    AWS_PERSONALIZE_API HPOConfig() = default;
     AWS_PERSONALIZE_API HPOConfig(Aws::Utils::Json::JsonView jsonValue);
     AWS_PERSONALIZE_API HPOConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_PERSONALIZE_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -45,36 +45,36 @@ namespace Model
      * <p>The metric to optimize during HPO.</p>  <p>Amazon Personalize doesn't
      * support configuring the <code>hpoObjective</code> at this time.</p> 
      */
-    inline const HPOObjective& GetHpoObjective() const{ return m_hpoObjective; }
+    inline const HPOObjective& GetHpoObjective() const { return m_hpoObjective; }
     inline bool HpoObjectiveHasBeenSet() const { return m_hpoObjectiveHasBeenSet; }
-    inline void SetHpoObjective(const HPOObjective& value) { m_hpoObjectiveHasBeenSet = true; m_hpoObjective = value; }
-    inline void SetHpoObjective(HPOObjective&& value) { m_hpoObjectiveHasBeenSet = true; m_hpoObjective = std::move(value); }
-    inline HPOConfig& WithHpoObjective(const HPOObjective& value) { SetHpoObjective(value); return *this;}
-    inline HPOConfig& WithHpoObjective(HPOObjective&& value) { SetHpoObjective(std::move(value)); return *this;}
+    template<typename HpoObjectiveT = HPOObjective>
+    void SetHpoObjective(HpoObjectiveT&& value) { m_hpoObjectiveHasBeenSet = true; m_hpoObjective = std::forward<HpoObjectiveT>(value); }
+    template<typename HpoObjectiveT = HPOObjective>
+    HPOConfig& WithHpoObjective(HpoObjectiveT&& value) { SetHpoObjective(std::forward<HpoObjectiveT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Describes the resource configuration for HPO.</p>
      */
-    inline const HPOResourceConfig& GetHpoResourceConfig() const{ return m_hpoResourceConfig; }
+    inline const HPOResourceConfig& GetHpoResourceConfig() const { return m_hpoResourceConfig; }
     inline bool HpoResourceConfigHasBeenSet() const { return m_hpoResourceConfigHasBeenSet; }
-    inline void SetHpoResourceConfig(const HPOResourceConfig& value) { m_hpoResourceConfigHasBeenSet = true; m_hpoResourceConfig = value; }
-    inline void SetHpoResourceConfig(HPOResourceConfig&& value) { m_hpoResourceConfigHasBeenSet = true; m_hpoResourceConfig = std::move(value); }
-    inline HPOConfig& WithHpoResourceConfig(const HPOResourceConfig& value) { SetHpoResourceConfig(value); return *this;}
-    inline HPOConfig& WithHpoResourceConfig(HPOResourceConfig&& value) { SetHpoResourceConfig(std::move(value)); return *this;}
+    template<typename HpoResourceConfigT = HPOResourceConfig>
+    void SetHpoResourceConfig(HpoResourceConfigT&& value) { m_hpoResourceConfigHasBeenSet = true; m_hpoResourceConfig = std::forward<HpoResourceConfigT>(value); }
+    template<typename HpoResourceConfigT = HPOResourceConfig>
+    HPOConfig& WithHpoResourceConfig(HpoResourceConfigT&& value) { SetHpoResourceConfig(std::forward<HpoResourceConfigT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The hyperparameters and their allowable ranges.</p>
      */
-    inline const HyperParameterRanges& GetAlgorithmHyperParameterRanges() const{ return m_algorithmHyperParameterRanges; }
+    inline const HyperParameterRanges& GetAlgorithmHyperParameterRanges() const { return m_algorithmHyperParameterRanges; }
     inline bool AlgorithmHyperParameterRangesHasBeenSet() const { return m_algorithmHyperParameterRangesHasBeenSet; }
-    inline void SetAlgorithmHyperParameterRanges(const HyperParameterRanges& value) { m_algorithmHyperParameterRangesHasBeenSet = true; m_algorithmHyperParameterRanges = value; }
-    inline void SetAlgorithmHyperParameterRanges(HyperParameterRanges&& value) { m_algorithmHyperParameterRangesHasBeenSet = true; m_algorithmHyperParameterRanges = std::move(value); }
-    inline HPOConfig& WithAlgorithmHyperParameterRanges(const HyperParameterRanges& value) { SetAlgorithmHyperParameterRanges(value); return *this;}
-    inline HPOConfig& WithAlgorithmHyperParameterRanges(HyperParameterRanges&& value) { SetAlgorithmHyperParameterRanges(std::move(value)); return *this;}
+    template<typename AlgorithmHyperParameterRangesT = HyperParameterRanges>
+    void SetAlgorithmHyperParameterRanges(AlgorithmHyperParameterRangesT&& value) { m_algorithmHyperParameterRangesHasBeenSet = true; m_algorithmHyperParameterRanges = std::forward<AlgorithmHyperParameterRangesT>(value); }
+    template<typename AlgorithmHyperParameterRangesT = HyperParameterRanges>
+    HPOConfig& WithAlgorithmHyperParameterRanges(AlgorithmHyperParameterRangesT&& value) { SetAlgorithmHyperParameterRanges(std::forward<AlgorithmHyperParameterRangesT>(value)); return *this;}
     ///@}
   private:
 
