@@ -22,7 +22,7 @@ namespace Model
   class UpdateSmsChannelRequest : public PinpointRequest
   {
   public:
-    AWS_PINPOINT_API UpdateSmsChannelRequest();
+    AWS_PINPOINT_API UpdateSmsChannelRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -38,24 +38,22 @@ namespace Model
      * <p>The unique identifier for the application. This identifier is displayed as
      * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
      */
-    inline const Aws::String& GetApplicationId() const{ return m_applicationId; }
+    inline const Aws::String& GetApplicationId() const { return m_applicationId; }
     inline bool ApplicationIdHasBeenSet() const { return m_applicationIdHasBeenSet; }
-    inline void SetApplicationId(const Aws::String& value) { m_applicationIdHasBeenSet = true; m_applicationId = value; }
-    inline void SetApplicationId(Aws::String&& value) { m_applicationIdHasBeenSet = true; m_applicationId = std::move(value); }
-    inline void SetApplicationId(const char* value) { m_applicationIdHasBeenSet = true; m_applicationId.assign(value); }
-    inline UpdateSmsChannelRequest& WithApplicationId(const Aws::String& value) { SetApplicationId(value); return *this;}
-    inline UpdateSmsChannelRequest& WithApplicationId(Aws::String&& value) { SetApplicationId(std::move(value)); return *this;}
-    inline UpdateSmsChannelRequest& WithApplicationId(const char* value) { SetApplicationId(value); return *this;}
+    template<typename ApplicationIdT = Aws::String>
+    void SetApplicationId(ApplicationIdT&& value) { m_applicationIdHasBeenSet = true; m_applicationId = std::forward<ApplicationIdT>(value); }
+    template<typename ApplicationIdT = Aws::String>
+    UpdateSmsChannelRequest& WithApplicationId(ApplicationIdT&& value) { SetApplicationId(std::forward<ApplicationIdT>(value)); return *this;}
     ///@}
 
     ///@{
     
-    inline const SMSChannelRequest& GetSMSChannelRequest() const{ return m_sMSChannelRequest; }
+    inline const SMSChannelRequest& GetSMSChannelRequest() const { return m_sMSChannelRequest; }
     inline bool SMSChannelRequestHasBeenSet() const { return m_sMSChannelRequestHasBeenSet; }
-    inline void SetSMSChannelRequest(const SMSChannelRequest& value) { m_sMSChannelRequestHasBeenSet = true; m_sMSChannelRequest = value; }
-    inline void SetSMSChannelRequest(SMSChannelRequest&& value) { m_sMSChannelRequestHasBeenSet = true; m_sMSChannelRequest = std::move(value); }
-    inline UpdateSmsChannelRequest& WithSMSChannelRequest(const SMSChannelRequest& value) { SetSMSChannelRequest(value); return *this;}
-    inline UpdateSmsChannelRequest& WithSMSChannelRequest(SMSChannelRequest&& value) { SetSMSChannelRequest(std::move(value)); return *this;}
+    template<typename SMSChannelRequestT = SMSChannelRequest>
+    void SetSMSChannelRequest(SMSChannelRequestT&& value) { m_sMSChannelRequestHasBeenSet = true; m_sMSChannelRequest = std::forward<SMSChannelRequestT>(value); }
+    template<typename SMSChannelRequestT = SMSChannelRequest>
+    UpdateSmsChannelRequest& WithSMSChannelRequest(SMSChannelRequestT&& value) { SetSMSChannelRequest(std::forward<SMSChannelRequestT>(value)); return *this;}
     ///@}
   private:
 
