@@ -19,7 +19,11 @@ namespace Model
     KNOWLEDGE_CONTENT,
     GENERATIVE_RESPONSE,
     GENERATIVE_ANSWER,
-    DETECTED_INTENT
+    DETECTED_INTENT,
+    GENERATIVE_ANSWER_CHUNK,
+    BLOCKED_GENERATIVE_ANSWER_CHUNK,
+    INTENT_ANSWER_CHUNK,
+    BLOCKED_INTENT_ANSWER_CHUNK
   };
 
 namespace RecommendationTypeMapper
