@@ -6,6 +6,7 @@
 #pragma once
 #include <aws/qconnect/QConnect_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/qconnect/model/MessageConfiguration.h>
 #include <utility>
 
 namespace Aws
@@ -32,17 +33,6 @@ namespace Model
     AWS_QCONNECT_API SendMessageResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
 
 
-    ///@{
-    /**
-     * <p>The token for the next message, used by GetNextMessage.</p>
-     */
-    inline const Aws::String& GetNextMessageToken() const { return m_nextMessageToken; }
-    template<typename NextMessageTokenT = Aws::String>
-    void SetNextMessageToken(NextMessageTokenT&& value) { m_nextMessageTokenHasBeenSet = true; m_nextMessageToken = std::forward<NextMessageTokenT>(value); }
-    template<typename NextMessageTokenT = Aws::String>
-    SendMessageResult& WithNextMessageToken(NextMessageTokenT&& value) { SetNextMessageToken(std::forward<NextMessageTokenT>(value)); return *this;}
-    ///@}
-
     ///@{
     /**
      * <p>The identifier of the submitted message.</p>
@@ -54,6 +44,30 @@ namespace Model
     SendMessageResult& WithRequestMessageId(RequestMessageIdT&& value) { SetRequestMessageId(std::forward<RequestMessageIdT>(value)); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The configuration of the <a
+     * href="https://docs.aws.amazon.com/connect/latest/APIReference/API_amazon-q-connect_SendMessage.html">SendMessage</a>
+     * request.</p>
+     */
+    inline const MessageConfiguration& GetConfiguration() const { return m_configuration; }
+    template<typename ConfigurationT = MessageConfiguration>
+    void SetConfiguration(ConfigurationT&& value) { m_configurationHasBeenSet = true; m_configuration = std::forward<ConfigurationT>(value); }
+    template<typename ConfigurationT = MessageConfiguration>
+    SendMessageResult& WithConfiguration(ConfigurationT&& value) { SetConfiguration(std::forward<ConfigurationT>(value)); return *this;}
+    ///@}
+
+    ///@{
+    /**
+     * <p>The token for the next message, used by GetNextMessage.</p>
+     */
+    inline const Aws::String& GetNextMessageToken() const { return m_nextMessageToken; }
+    template<typename NextMessageTokenT = Aws::String>
+    void SetNextMessageToken(NextMessageTokenT&& value) { m_nextMessageTokenHasBeenSet = true; m_nextMessageToken = std::forward<NextMessageTokenT>(value); }
+    template<typename NextMessageTokenT = Aws::String>
+    SendMessageResult& WithNextMessageToken(NextMessageTokenT&& value) { SetNextMessageToken(std::forward<NextMessageTokenT>(value)); return *this;}
+    ///@}
+
     ///@{
     
     inline const Aws::String& GetRequestId() const { return m_requestId; }
@@ -64,12 +78,15 @@ namespace Model
     ///@}
   private:
 
-    Aws::String m_nextMessageToken;
-    bool m_nextMessageTokenHasBeenSet = false;
-
     Aws::String m_requestMessageId;
     bool m_requestMessageIdHasBeenSet = false;
 
+    MessageConfiguration m_configuration;
+    bool m_configurationHasBeenSet = false;
+
+    Aws::String m_nextMessageToken;
+    bool m_nextMessageTokenHasBeenSet = false;
+
     Aws::String m_requestId;
     bool m_requestIdHasBeenSet = false;
   };
