@@ -31,7 +31,7 @@ namespace Model
   class TemplateSourceTemplate
   {
   public:
-    AWS_QUICKSIGHT_API TemplateSourceTemplate();
+    AWS_QUICKSIGHT_API TemplateSourceTemplate() = default;
     AWS_QUICKSIGHT_API TemplateSourceTemplate(Aws::Utils::Json::JsonView jsonValue);
     AWS_QUICKSIGHT_API TemplateSourceTemplate& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_QUICKSIGHT_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -41,14 +41,12 @@ namespace Model
     /**
      * <p>The Amazon Resource Name (ARN) of the resource.</p>
      */
-    inline const Aws::String& GetArn() const{ return m_arn; }
+    inline const Aws::String& GetArn() const { return m_arn; }
     inline bool ArnHasBeenSet() const { return m_arnHasBeenSet; }
-    inline void SetArn(const Aws::String& value) { m_arnHasBeenSet = true; m_arn = value; }
-    inline void SetArn(Aws::String&& value) { m_arnHasBeenSet = true; m_arn = std::move(value); }
-    inline void SetArn(const char* value) { m_arnHasBeenSet = true; m_arn.assign(value); }
-    inline TemplateSourceTemplate& WithArn(const Aws::String& value) { SetArn(value); return *this;}
-    inline TemplateSourceTemplate& WithArn(Aws::String&& value) { SetArn(std::move(value)); return *this;}
-    inline TemplateSourceTemplate& WithArn(const char* value) { SetArn(value); return *this;}
+    template<typename ArnT = Aws::String>
+    void SetArn(ArnT&& value) { m_arnHasBeenSet = true; m_arn = std::forward<ArnT>(value); }
+    template<typename ArnT = Aws::String>
+    TemplateSourceTemplate& WithArn(ArnT&& value) { SetArn(std::forward<ArnT>(value)); return *this;}
     ///@}
   private:
 
