@@ -32,7 +32,7 @@ namespace Model
   class BatchExecuteStatementException
   {
   public:
-    AWS_REDSHIFTDATAAPISERVICE_API BatchExecuteStatementException();
+    AWS_REDSHIFTDATAAPISERVICE_API BatchExecuteStatementException() = default;
     AWS_REDSHIFTDATAAPISERVICE_API BatchExecuteStatementException(Aws::Utils::Json::JsonView jsonValue);
     AWS_REDSHIFTDATAAPISERVICE_API BatchExecuteStatementException& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_REDSHIFTDATAAPISERVICE_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -40,28 +40,24 @@ namespace Model
 
     ///@{
     
-    inline const Aws::String& GetMessage() const{ return m_message; }
+    inline const Aws::String& GetMessage() const { return m_message; }
     inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }
-    inline void SetMessage(const Aws::String& value) { m_messageHasBeenSet = true; m_message = value; }
-    inline void SetMessage(Aws::String&& value) { m_messageHasBeenSet = true; m_message = std::move(value); }
-    inline void SetMessage(const char* value) { m_messageHasBeenSet = true; m_message.assign(value); }
-    inline BatchExecuteStatementException& WithMessage(const Aws::String& value) { SetMessage(value); return *this;}
-    inline BatchExecuteStatementException& WithMessage(Aws::String&& value) { SetMessage(std::move(value)); return *this;}
-    inline BatchExecuteStatementException& WithMessage(const char* value) { SetMessage(value); return *this;}
+    template<typename MessageT = Aws::String>
+    void SetMessage(MessageT&& value) { m_messageHasBeenSet = true; m_message = std::forward<MessageT>(value); }
+    template<typename MessageT = Aws::String>
+    BatchExecuteStatementException& WithMessage(MessageT&& value) { SetMessage(std::forward<MessageT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Statement identifier of the exception.</p>
      */
-    inline const Aws::String& GetStatementId() const{ return m_statementId; }
+    inline const Aws::String& GetStatementId() const { return m_statementId; }
     inline bool StatementIdHasBeenSet() const { return m_statementIdHasBeenSet; }
-    inline void SetStatementId(const Aws::String& value) { m_statementIdHasBeenSet = true; m_statementId = value; }
-    inline void SetStatementId(Aws::String&& value) { m_statementIdHasBeenSet = true; m_statementId = std::move(value); }
-    inline void SetStatementId(const char* value) { m_statementIdHasBeenSet = true; m_statementId.assign(value); }
-    inline BatchExecuteStatementException& WithStatementId(const Aws::String& value) { SetStatementId(value); return *this;}
-    inline BatchExecuteStatementException& WithStatementId(Aws::String&& value) { SetStatementId(std::move(value)); return *this;}
-    inline BatchExecuteStatementException& WithStatementId(const char* value) { SetStatementId(value); return *this;}
+    template<typename StatementIdT = Aws::String>
+    void SetStatementId(StatementIdT&& value) { m_statementIdHasBeenSet = true; m_statementId = std::forward<StatementIdT>(value); }
+    template<typename StatementIdT = Aws::String>
+    BatchExecuteStatementException& WithStatementId(StatementIdT&& value) { SetStatementId(std::forward<StatementIdT>(value)); return *this;}
     ///@}
   private:
 
