@@ -22,6 +22,7 @@
 #include <aws/redshift-serverless/model/CreateCustomDomainAssociationResult.h>
 #include <aws/redshift-serverless/model/CreateEndpointAccessResult.h>
 #include <aws/redshift-serverless/model/CreateNamespaceResult.h>
+#include <aws/redshift-serverless/model/CreateReservationResult.h>
 #include <aws/redshift-serverless/model/CreateScheduledActionResult.h>
 #include <aws/redshift-serverless/model/CreateSnapshotResult.h>
 #include <aws/redshift-serverless/model/CreateSnapshotCopyConfigurationResult.h>
@@ -41,6 +42,8 @@
 #include <aws/redshift-serverless/model/GetEndpointAccessResult.h>
 #include <aws/redshift-serverless/model/GetNamespaceResult.h>
 #include <aws/redshift-serverless/model/GetRecoveryPointResult.h>
+#include <aws/redshift-serverless/model/GetReservationResult.h>
+#include <aws/redshift-serverless/model/GetReservationOfferingResult.h>
 #include <aws/redshift-serverless/model/GetResourcePolicyResult.h>
 #include <aws/redshift-serverless/model/GetScheduledActionResult.h>
 #include <aws/redshift-serverless/model/GetSnapshotResult.h>
@@ -53,6 +56,8 @@
 #include <aws/redshift-serverless/model/ListManagedWorkgroupsResult.h>
 #include <aws/redshift-serverless/model/ListNamespacesResult.h>
 #include <aws/redshift-serverless/model/ListRecoveryPointsResult.h>
+#include <aws/redshift-serverless/model/ListReservationOfferingsResult.h>
+#include <aws/redshift-serverless/model/ListReservationsResult.h>
 #include <aws/redshift-serverless/model/ListScheduledActionsResult.h>
 #include <aws/redshift-serverless/model/ListSnapshotCopyConfigurationsResult.h>
 #include <aws/redshift-serverless/model/ListSnapshotsResult.h>
@@ -84,10 +89,12 @@
 #include <aws/redshift-serverless/model/ListSnapshotsRequest.h>
 #include <aws/redshift-serverless/model/ListNamespacesRequest.h>
 #include <aws/redshift-serverless/model/ListSnapshotCopyConfigurationsRequest.h>
+#include <aws/redshift-serverless/model/ListReservationsRequest.h>
 #include <aws/redshift-serverless/model/GetCredentialsRequest.h>
 #include <aws/redshift-serverless/model/ListUsageLimitsRequest.h>
 #include <aws/redshift-serverless/model/ListTableRestoreStatusRequest.h>
 #include <aws/redshift-serverless/model/ListManagedWorkgroupsRequest.h>
+#include <aws/redshift-serverless/model/ListReservationOfferingsRequest.h>
 #include <aws/redshift-serverless/model/ListScheduledActionsRequest.h>
 #include <aws/redshift-serverless/model/ListRecoveryPointsRequest.h>
 /* End of service model headers required in RedshiftServerlessClient header */
@@ -134,6 +141,7 @@ namespace Aws
       class CreateCustomDomainAssociationRequest;
       class CreateEndpointAccessRequest;
       class CreateNamespaceRequest;
+      class CreateReservationRequest;
       class CreateScheduledActionRequest;
       class CreateSnapshotRequest;
       class CreateSnapshotCopyConfigurationRequest;
@@ -153,6 +161,8 @@ namespace Aws
       class GetEndpointAccessRequest;
       class GetNamespaceRequest;
       class GetRecoveryPointRequest;
+      class GetReservationRequest;
+      class GetReservationOfferingRequest;
       class GetResourcePolicyRequest;
       class GetScheduledActionRequest;
       class GetSnapshotRequest;
@@ -165,6 +175,8 @@ namespace Aws
       class ListManagedWorkgroupsRequest;
       class ListNamespacesRequest;
       class ListRecoveryPointsRequest;
+      class ListReservationOfferingsRequest;
+      class ListReservationsRequest;
       class ListScheduledActionsRequest;
       class ListSnapshotCopyConfigurationsRequest;
       class ListSnapshotsRequest;
@@ -195,6 +207,7 @@ namespace Aws
       typedef Aws::Utils::Outcome<CreateCustomDomainAssociationResult, RedshiftServerlessError> CreateCustomDomainAssociationOutcome;
       typedef Aws::Utils::Outcome<CreateEndpointAccessResult, RedshiftServerlessError> CreateEndpointAccessOutcome;
       typedef Aws::Utils::Outcome<CreateNamespaceResult, RedshiftServerlessError> CreateNamespaceOutcome;
+      typedef Aws::Utils::Outcome<CreateReservationResult, RedshiftServerlessError> CreateReservationOutcome;
       typedef Aws::Utils::Outcome<CreateScheduledActionResult, RedshiftServerlessError> CreateScheduledActionOutcome;
       typedef Aws::Utils::Outcome<CreateSnapshotResult, RedshiftServerlessError> CreateSnapshotOutcome;
       typedef Aws::Utils::Outcome<CreateSnapshotCopyConfigurationResult, RedshiftServerlessError> CreateSnapshotCopyConfigurationOutcome;
@@ -214,6 +227,8 @@ namespace Aws
       typedef Aws::Utils::Outcome<GetEndpointAccessResult, RedshiftServerlessError> GetEndpointAccessOutcome;
       typedef Aws::Utils::Outcome<GetNamespaceResult, RedshiftServerlessError> GetNamespaceOutcome;
       typedef Aws::Utils::Outcome<GetRecoveryPointResult, RedshiftServerlessError> GetRecoveryPointOutcome;
+      typedef Aws::Utils::Outcome<GetReservationResult, RedshiftServerlessError> GetReservationOutcome;
+      typedef Aws::Utils::Outcome<GetReservationOfferingResult, RedshiftServerlessError> GetReservationOfferingOutcome;
       typedef Aws::Utils::Outcome<GetResourcePolicyResult, RedshiftServerlessError> GetResourcePolicyOutcome;
       typedef Aws::Utils::Outcome<GetScheduledActionResult, RedshiftServerlessError> GetScheduledActionOutcome;
       typedef Aws::Utils::Outcome<GetSnapshotResult, RedshiftServerlessError> GetSnapshotOutcome;
@@ -226,6 +241,8 @@ namespace Aws
       typedef Aws::Utils::Outcome<ListManagedWorkgroupsResult, RedshiftServerlessError> ListManagedWorkgroupsOutcome;
       typedef Aws::Utils::Outcome<ListNamespacesResult, RedshiftServerlessError> ListNamespacesOutcome;
       typedef Aws::Utils::Outcome<ListRecoveryPointsResult, RedshiftServerlessError> ListRecoveryPointsOutcome;
+      typedef Aws::Utils::Outcome<ListReservationOfferingsResult, RedshiftServerlessError> ListReservationOfferingsOutcome;
+      typedef Aws::Utils::Outcome<ListReservationsResult, RedshiftServerlessError> ListReservationsOutcome;
       typedef Aws::Utils::Outcome<ListScheduledActionsResult, RedshiftServerlessError> ListScheduledActionsOutcome;
       typedef Aws::Utils::Outcome<ListSnapshotCopyConfigurationsResult, RedshiftServerlessError> ListSnapshotCopyConfigurationsOutcome;
       typedef Aws::Utils::Outcome<ListSnapshotsResult, RedshiftServerlessError> ListSnapshotsOutcome;
@@ -256,6 +273,7 @@ namespace Aws
       typedef std::future<CreateCustomDomainAssociationOutcome> CreateCustomDomainAssociationOutcomeCallable;
       typedef std::future<CreateEndpointAccessOutcome> CreateEndpointAccessOutcomeCallable;
       typedef std::future<CreateNamespaceOutcome> CreateNamespaceOutcomeCallable;
+      typedef std::future<CreateReservationOutcome> CreateReservationOutcomeCallable;
       typedef std::future<CreateScheduledActionOutcome> CreateScheduledActionOutcomeCallable;
       typedef std::future<CreateSnapshotOutcome> CreateSnapshotOutcomeCallable;
       typedef std::future<CreateSnapshotCopyConfigurationOutcome> CreateSnapshotCopyConfigurationOutcomeCallable;
@@ -275,6 +293,8 @@ namespace Aws
       typedef std::future<GetEndpointAccessOutcome> GetEndpointAccessOutcomeCallable;
       typedef std::future<GetNamespaceOutcome> GetNamespaceOutcomeCallable;
       typedef std::future<GetRecoveryPointOutcome> GetRecoveryPointOutcomeCallable;
+      typedef std::future<GetReservationOutcome> GetReservationOutcomeCallable;
+      typedef std::future<GetReservationOfferingOutcome> GetReservationOfferingOutcomeCallable;
       typedef std::future<GetResourcePolicyOutcome> GetResourcePolicyOutcomeCallable;
       typedef std::future<GetScheduledActionOutcome> GetScheduledActionOutcomeCallable;
       typedef std::future<GetSnapshotOutcome> GetSnapshotOutcomeCallable;
@@ -287,6 +307,8 @@ namespace Aws
       typedef std::future<ListManagedWorkgroupsOutcome> ListManagedWorkgroupsOutcomeCallable;
       typedef std::future<ListNamespacesOutcome> ListNamespacesOutcomeCallable;
       typedef std::future<ListRecoveryPointsOutcome> ListRecoveryPointsOutcomeCallable;
+      typedef std::future<ListReservationOfferingsOutcome> ListReservationOfferingsOutcomeCallable;
+      typedef std::future<ListReservationsOutcome> ListReservationsOutcomeCallable;
       typedef std::future<ListScheduledActionsOutcome> ListScheduledActionsOutcomeCallable;
       typedef std::future<ListSnapshotCopyConfigurationsOutcome> ListSnapshotCopyConfigurationsOutcomeCallable;
       typedef std::future<ListSnapshotsOutcome> ListSnapshotsOutcomeCallable;
@@ -320,6 +342,7 @@ namespace Aws
     typedef std::function<void(const RedshiftServerlessClient*, const Model::CreateCustomDomainAssociationRequest&, const Model::CreateCustomDomainAssociationOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > CreateCustomDomainAssociationResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::CreateEndpointAccessRequest&, const Model::CreateEndpointAccessOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > CreateEndpointAccessResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::CreateNamespaceRequest&, const Model::CreateNamespaceOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > CreateNamespaceResponseReceivedHandler;
+    typedef std::function<void(const RedshiftServerlessClient*, const Model::CreateReservationRequest&, const Model::CreateReservationOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > CreateReservationResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::CreateScheduledActionRequest&, const Model::CreateScheduledActionOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > CreateScheduledActionResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::CreateSnapshotRequest&, const Model::CreateSnapshotOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > CreateSnapshotResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::CreateSnapshotCopyConfigurationRequest&, const Model::CreateSnapshotCopyConfigurationOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > CreateSnapshotCopyConfigurationResponseReceivedHandler;
@@ -339,6 +362,8 @@ namespace Aws
     typedef std::function<void(const RedshiftServerlessClient*, const Model::GetEndpointAccessRequest&, const Model::GetEndpointAccessOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetEndpointAccessResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::GetNamespaceRequest&, const Model::GetNamespaceOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetNamespaceResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::GetRecoveryPointRequest&, const Model::GetRecoveryPointOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetRecoveryPointResponseReceivedHandler;
+    typedef std::function<void(const RedshiftServerlessClient*, const Model::GetReservationRequest&, const Model::GetReservationOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetReservationResponseReceivedHandler;
+    typedef std::function<void(const RedshiftServerlessClient*, const Model::GetReservationOfferingRequest&, const Model::GetReservationOfferingOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetReservationOfferingResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::GetResourcePolicyRequest&, const Model::GetResourcePolicyOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetResourcePolicyResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::GetScheduledActionRequest&, const Model::GetScheduledActionOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetScheduledActionResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::GetSnapshotRequest&, const Model::GetSnapshotOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > GetSnapshotResponseReceivedHandler;
@@ -351,6 +376,8 @@ namespace Aws
     typedef std::function<void(const RedshiftServerlessClient*, const Model::ListManagedWorkgroupsRequest&, const Model::ListManagedWorkgroupsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListManagedWorkgroupsResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::ListNamespacesRequest&, const Model::ListNamespacesOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListNamespacesResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::ListRecoveryPointsRequest&, const Model::ListRecoveryPointsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListRecoveryPointsResponseReceivedHandler;
+    typedef std::function<void(const RedshiftServerlessClient*, const Model::ListReservationOfferingsRequest&, const Model::ListReservationOfferingsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListReservationOfferingsResponseReceivedHandler;
+    typedef std::function<void(const RedshiftServerlessClient*, const Model::ListReservationsRequest&, const Model::ListReservationsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListReservationsResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::ListScheduledActionsRequest&, const Model::ListScheduledActionsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListScheduledActionsResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::ListSnapshotCopyConfigurationsRequest&, const Model::ListSnapshotCopyConfigurationsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListSnapshotCopyConfigurationsResponseReceivedHandler;
     typedef std::function<void(const RedshiftServerlessClient*, const Model::ListSnapshotsRequest&, const Model::ListSnapshotsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListSnapshotsResponseReceivedHandler;
