@@ -6,6 +6,7 @@
 #pragma once
 #include <aws/resource-groups/ResourceGroups_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/resource-groups/model/ResourceQuery.h>
 #include <utility>
 
 namespace Aws
@@ -88,6 +89,15 @@ namespace Model
     StartTagSyncTaskResult& WithTagValue(TagValueT&& value) { SetTagValue(std::forward<TagValueT>(value)); return *this;}
     ///@}
 
+    ///@{
+    
+    inline const ResourceQuery& GetResourceQuery() const { return m_resourceQuery; }
+    template<typename ResourceQueryT = ResourceQuery>
+    void SetResourceQuery(ResourceQueryT&& value) { m_resourceQueryHasBeenSet = true; m_resourceQuery = std::forward<ResourceQueryT>(value); }
+    template<typename ResourceQueryT = ResourceQuery>
+    StartTagSyncTaskResult& WithResourceQuery(ResourceQueryT&& value) { SetResourceQuery(std::forward<ResourceQueryT>(value)); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>The Amazon resource name (ARN) of the role assumed by the service to tag and
@@ -125,6 +135,9 @@ namespace Model
     Aws::String m_tagValue;
     bool m_tagValueHasBeenSet = false;
 
+    ResourceQuery m_resourceQuery;
+    bool m_resourceQueryHasBeenSet = false;
+
     Aws::String m_roleArn;
     bool m_roleArnHasBeenSet = false;
 
