@@ -33,7 +33,7 @@ namespace Model
   class Rule
   {
   public:
-    AWS_ROUTE53RECOVERYCONTROLCONFIG_API Rule();
+    AWS_ROUTE53RECOVERYCONTROLCONFIG_API Rule() = default;
     AWS_ROUTE53RECOVERYCONTROLCONFIG_API Rule(Aws::Utils::Json::JsonView jsonValue);
     AWS_ROUTE53RECOVERYCONTROLCONFIG_API Rule& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_ROUTE53RECOVERYCONTROLCONFIG_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -48,12 +48,12 @@ namespace Model
      * continues to flow to at least one cell for the application. This ensures that
      * you avoid a fail-open scenario.</p>
      */
-    inline const AssertionRule& GetASSERTION() const{ return m_aSSERTION; }
+    inline const AssertionRule& GetASSERTION() const { return m_aSSERTION; }
     inline bool ASSERTIONHasBeenSet() const { return m_aSSERTIONHasBeenSet; }
-    inline void SetASSERTION(const AssertionRule& value) { m_aSSERTIONHasBeenSet = true; m_aSSERTION = value; }
-    inline void SetASSERTION(AssertionRule&& value) { m_aSSERTIONHasBeenSet = true; m_aSSERTION = std::move(value); }
-    inline Rule& WithASSERTION(const AssertionRule& value) { SetASSERTION(value); return *this;}
-    inline Rule& WithASSERTION(AssertionRule&& value) { SetASSERTION(std::move(value)); return *this;}
+    template<typename ASSERTIONT = AssertionRule>
+    void SetASSERTION(ASSERTIONT&& value) { m_aSSERTIONHasBeenSet = true; m_aSSERTION = std::forward<ASSERTIONT>(value); }
+    template<typename ASSERTIONT = AssertionRule>
+    Rule& WithASSERTION(ASSERTIONT&& value) { SetASSERTION(std::forward<ASSERTIONT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -67,12 +67,12 @@ namespace Model
      * "switch" to be "On". When you do that, then you can update the routing control
      * states for the target routing controls that you specify in the gating rule.</p>
      */
-    inline const GatingRule& GetGATING() const{ return m_gATING; }
+    inline const GatingRule& GetGATING() const { return m_gATING; }
     inline bool GATINGHasBeenSet() const { return m_gATINGHasBeenSet; }
-    inline void SetGATING(const GatingRule& value) { m_gATINGHasBeenSet = true; m_gATING = value; }
-    inline void SetGATING(GatingRule&& value) { m_gATINGHasBeenSet = true; m_gATING = std::move(value); }
-    inline Rule& WithGATING(const GatingRule& value) { SetGATING(value); return *this;}
-    inline Rule& WithGATING(GatingRule&& value) { SetGATING(std::move(value)); return *this;}
+    template<typename GATINGT = GatingRule>
+    void SetGATING(GATINGT&& value) { m_gATINGHasBeenSet = true; m_gATING = std::forward<GATINGT>(value); }
+    template<typename GATINGT = GatingRule>
+    Rule& WithGATING(GATINGT&& value) { SetGATING(std::forward<GATINGT>(value)); return *this;}
     ///@}
   private:
 
