@@ -57,7 +57,8 @@ namespace Model
     us_isof_south_1,
     us_isof_east_1,
     ap_southeast_7,
-    ap_east_2
+    ap_east_2,
+    eu_isoe_west_1
   };
 
 namespace CloudWatchRegionMapper
