@@ -24,7 +24,7 @@ namespace Model
   class GetChangeRequest : public Route53Request
   {
   public:
-    AWS_ROUTE53_API GetChangeRequest();
+    AWS_ROUTE53_API GetChangeRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -41,14 +41,12 @@ namespace Model
      * value that <code>ChangeResourceRecordSets</code> returned in the <code>Id</code>
      * element when you submitted the request.</p>
      */
-    inline const Aws::String& GetId() const{ return m_id; }
+    inline const Aws::String& GetId() const { return m_id; }
     inline bool IdHasBeenSet() const { return m_idHasBeenSet; }
-    inline void SetId(const Aws::String& value) { m_idHasBeenSet = true; m_id = value; }
-    inline void SetId(Aws::String&& value) { m_idHasBeenSet = true; m_id = std::move(value); }
-    inline void SetId(const char* value) { m_idHasBeenSet = true; m_id.assign(value); }
-    inline GetChangeRequest& WithId(const Aws::String& value) { SetId(value); return *this;}
-    inline GetChangeRequest& WithId(Aws::String&& value) { SetId(std::move(value)); return *this;}
-    inline GetChangeRequest& WithId(const char* value) { SetId(value); return *this;}
+    template<typename IdT = Aws::String>
+    void SetId(IdT&& value) { m_idHasBeenSet = true; m_id = std::forward<IdT>(value); }
+    template<typename IdT = Aws::String>
+    GetChangeRequest& WithId(IdT&& value) { SetId(std::forward<IdT>(value)); return *this;}
     ///@}
   private:
 
