@@ -20,10 +20,10 @@ namespace Model
    * href="http://docs.aws.amazon.com/goto/WebAPI/route53-2013-04-01/GetTrafficPolicyInstanceCountRequest">AWS
    * API Reference</a></p>
    */
-  class AWS_ROUTE53_API GetTrafficPolicyInstanceCountRequest : public Route53Request
+  class GetTrafficPolicyInstanceCountRequest : public Route53Request
   {
   public:
-    GetTrafficPolicyInstanceCountRequest();
+    AWS_ROUTE53_API GetTrafficPolicyInstanceCountRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -31,7 +31,7 @@ namespace Model
     // so we can not get operation's name from response.
     inline virtual const char* GetServiceRequestName() const override { return "GetTrafficPolicyInstanceCount"; }
 
-    Aws::String SerializePayload() const override;
+    AWS_ROUTE53_API Aws::String SerializePayload() const override;
 
   };
 
