@@ -22,7 +22,7 @@ namespace Model
   class UpdateResolverConfigRequest : public Route53ResolverRequest
   {
   public:
-    AWS_ROUTE53RESOLVER_API UpdateResolverConfigRequest();
+    AWS_ROUTE53RESOLVER_API UpdateResolverConfigRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -37,17 +37,15 @@ namespace Model
 
     ///@{
     /**
-     * <p>Resource ID of the Amazon VPC that you want to update the Resolver
-     * configuration for.</p>
+     * <p>The ID of the Amazon Virtual Private Cloud VPC or a Route 53 Profile that
+     * you're configuring Resolver for.</p>
      */
-    inline const Aws::String& GetResourceId() const{ return m_resourceId; }
+    inline const Aws::String& GetResourceId() const { return m_resourceId; }
     inline bool ResourceIdHasBeenSet() const { return m_resourceIdHasBeenSet; }
-    inline void SetResourceId(const Aws::String& value) { m_resourceIdHasBeenSet = true; m_resourceId = value; }
-    inline void SetResourceId(Aws::String&& value) { m_resourceIdHasBeenSet = true; m_resourceId = std::move(value); }
-    inline void SetResourceId(const char* value) { m_resourceIdHasBeenSet = true; m_resourceId.assign(value); }
-    inline UpdateResolverConfigRequest& WithResourceId(const Aws::String& value) { SetResourceId(value); return *this;}
-    inline UpdateResolverConfigRequest& WithResourceId(Aws::String&& value) { SetResourceId(std::move(value)); return *this;}
-    inline UpdateResolverConfigRequest& WithResourceId(const char* value) { SetResourceId(value); return *this;}
+    template<typename ResourceIdT = Aws::String>
+    void SetResourceId(ResourceIdT&& value) { m_resourceIdHasBeenSet = true; m_resourceId = std::forward<ResourceIdT>(value); }
+    template<typename ResourceIdT = Aws::String>
+    UpdateResolverConfigRequest& WithResourceId(ResourceIdT&& value) { SetResourceId(std::forward<ResourceIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -65,19 +63,17 @@ namespace Model
      * Networking is Retiring – Here’s How to Prepare</a>.</p>  
      * <p>It can take some time for the status change to be completed.</p>  <p/>
      */
-    inline const AutodefinedReverseFlag& GetAutodefinedReverseFlag() const{ return m_autodefinedReverseFlag; }
+    inline AutodefinedReverseFlag GetAutodefinedReverseFlag() const { return m_autodefinedReverseFlag; }
     inline bool AutodefinedReverseFlagHasBeenSet() const { return m_autodefinedReverseFlagHasBeenSet; }
-    inline void SetAutodefinedReverseFlag(const AutodefinedReverseFlag& value) { m_autodefinedReverseFlagHasBeenSet = true; m_autodefinedReverseFlag = value; }
-    inline void SetAutodefinedReverseFlag(AutodefinedReverseFlag&& value) { m_autodefinedReverseFlagHasBeenSet = true; m_autodefinedReverseFlag = std::move(value); }
-    inline UpdateResolverConfigRequest& WithAutodefinedReverseFlag(const AutodefinedReverseFlag& value) { SetAutodefinedReverseFlag(value); return *this;}
-    inline UpdateResolverConfigRequest& WithAutodefinedReverseFlag(AutodefinedReverseFlag&& value) { SetAutodefinedReverseFlag(std::move(value)); return *this;}
+    inline void SetAutodefinedReverseFlag(AutodefinedReverseFlag value) { m_autodefinedReverseFlagHasBeenSet = true; m_autodefinedReverseFlag = value; }
+    inline UpdateResolverConfigRequest& WithAutodefinedReverseFlag(AutodefinedReverseFlag value) { SetAutodefinedReverseFlag(value); return *this;}
     ///@}
   private:
 
     Aws::String m_resourceId;
     bool m_resourceIdHasBeenSet = false;
 
-    AutodefinedReverseFlag m_autodefinedReverseFlag;
+    AutodefinedReverseFlag m_autodefinedReverseFlag{AutodefinedReverseFlag::NOT_SET};
     bool m_autodefinedReverseFlagHasBeenSet = false;
   };
 
