@@ -22,7 +22,7 @@ namespace Model
   class DeleteDomainRequest : public SageMakerRequest
   {
   public:
-    AWS_SAGEMAKER_API DeleteDomainRequest();
+    AWS_SAGEMAKER_API DeleteDomainRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -39,14 +39,12 @@ namespace Model
     /**
      * <p>The domain ID.</p>
      */
-    inline const Aws::String& GetDomainId() const{ return m_domainId; }
+    inline const Aws::String& GetDomainId() const { return m_domainId; }
     inline bool DomainIdHasBeenSet() const { return m_domainIdHasBeenSet; }
-    inline void SetDomainId(const Aws::String& value) { m_domainIdHasBeenSet = true; m_domainId = value; }
-    inline void SetDomainId(Aws::String&& value) { m_domainIdHasBeenSet = true; m_domainId = std::move(value); }
-    inline void SetDomainId(const char* value) { m_domainIdHasBeenSet = true; m_domainId.assign(value); }
-    inline DeleteDomainRequest& WithDomainId(const Aws::String& value) { SetDomainId(value); return *this;}
-    inline DeleteDomainRequest& WithDomainId(Aws::String&& value) { SetDomainId(std::move(value)); return *this;}
-    inline DeleteDomainRequest& WithDomainId(const char* value) { SetDomainId(value); return *this;}
+    template<typename DomainIdT = Aws::String>
+    void SetDomainId(DomainIdT&& value) { m_domainIdHasBeenSet = true; m_domainId = std::forward<DomainIdT>(value); }
+    template<typename DomainIdT = Aws::String>
+    DeleteDomainRequest& WithDomainId(DomainIdT&& value) { SetDomainId(std::forward<DomainIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -55,12 +53,12 @@ namespace Model
      * be retained after the Domain is deleted. By default, all resources are retained
      * (not automatically deleted). </p>
      */
-    inline const RetentionPolicy& GetRetentionPolicy() const{ return m_retentionPolicy; }
+    inline const RetentionPolicy& GetRetentionPolicy() const { return m_retentionPolicy; }
     inline bool RetentionPolicyHasBeenSet() const { return m_retentionPolicyHasBeenSet; }
-    inline void SetRetentionPolicy(const RetentionPolicy& value) { m_retentionPolicyHasBeenSet = true; m_retentionPolicy = value; }
-    inline void SetRetentionPolicy(RetentionPolicy&& value) { m_retentionPolicyHasBeenSet = true; m_retentionPolicy = std::move(value); }
-    inline DeleteDomainRequest& WithRetentionPolicy(const RetentionPolicy& value) { SetRetentionPolicy(value); return *this;}
-    inline DeleteDomainRequest& WithRetentionPolicy(RetentionPolicy&& value) { SetRetentionPolicy(std::move(value)); return *this;}
+    template<typename RetentionPolicyT = RetentionPolicy>
+    void SetRetentionPolicy(RetentionPolicyT&& value) { m_retentionPolicyHasBeenSet = true; m_retentionPolicy = std::forward<RetentionPolicyT>(value); }
+    template<typename RetentionPolicyT = RetentionPolicy>
+    DeleteDomainRequest& WithRetentionPolicy(RetentionPolicyT&& value) { SetRetentionPolicy(std::forward<RetentionPolicyT>(value)); return *this;}
     ///@}
   private:
 
