@@ -21,7 +21,7 @@ namespace Model
   class DescribeImageVersionRequest : public SageMakerRequest
   {
   public:
-    AWS_SAGEMAKER_API DescribeImageVersionRequest();
+    AWS_SAGEMAKER_API DescribeImageVersionRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -38,14 +38,12 @@ namespace Model
     /**
      * <p>The name of the image.</p>
      */
-    inline const Aws::String& GetImageName() const{ return m_imageName; }
+    inline const Aws::String& GetImageName() const { return m_imageName; }
     inline bool ImageNameHasBeenSet() const { return m_imageNameHasBeenSet; }
-    inline void SetImageName(const Aws::String& value) { m_imageNameHasBeenSet = true; m_imageName = value; }
-    inline void SetImageName(Aws::String&& value) { m_imageNameHasBeenSet = true; m_imageName = std::move(value); }
-    inline void SetImageName(const char* value) { m_imageNameHasBeenSet = true; m_imageName.assign(value); }
-    inline DescribeImageVersionRequest& WithImageName(const Aws::String& value) { SetImageName(value); return *this;}
-    inline DescribeImageVersionRequest& WithImageName(Aws::String&& value) { SetImageName(std::move(value)); return *this;}
-    inline DescribeImageVersionRequest& WithImageName(const char* value) { SetImageName(value); return *this;}
+    template<typename ImageNameT = Aws::String>
+    void SetImageName(ImageNameT&& value) { m_imageNameHasBeenSet = true; m_imageName = std::forward<ImageNameT>(value); }
+    template<typename ImageNameT = Aws::String>
+    DescribeImageVersionRequest& WithImageName(ImageNameT&& value) { SetImageName(std::forward<ImageNameT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -53,7 +51,7 @@ namespace Model
      * <p>The version of the image. If not specified, the latest version is
      * described.</p>
      */
-    inline int GetVersion() const{ return m_version; }
+    inline int GetVersion() const { return m_version; }
     inline bool VersionHasBeenSet() const { return m_versionHasBeenSet; }
     inline void SetVersion(int value) { m_versionHasBeenSet = true; m_version = value; }
     inline DescribeImageVersionRequest& WithVersion(int value) { SetVersion(value); return *this;}
@@ -63,21 +61,19 @@ namespace Model
     /**
      * <p>The alias of the image version.</p>
      */
-    inline const Aws::String& GetAlias() const{ return m_alias; }
+    inline const Aws::String& GetAlias() const { return m_alias; }
     inline bool AliasHasBeenSet() const { return m_aliasHasBeenSet; }
-    inline void SetAlias(const Aws::String& value) { m_aliasHasBeenSet = true; m_alias = value; }
-    inline void SetAlias(Aws::String&& value) { m_aliasHasBeenSet = true; m_alias = std::move(value); }
-    inline void SetAlias(const char* value) { m_aliasHasBeenSet = true; m_alias.assign(value); }
-    inline DescribeImageVersionRequest& WithAlias(const Aws::String& value) { SetAlias(value); return *this;}
-    inline DescribeImageVersionRequest& WithAlias(Aws::String&& value) { SetAlias(std::move(value)); return *this;}
-    inline DescribeImageVersionRequest& WithAlias(const char* value) { SetAlias(value); return *this;}
+    template<typename AliasT = Aws::String>
+    void SetAlias(AliasT&& value) { m_aliasHasBeenSet = true; m_alias = std::forward<AliasT>(value); }
+    template<typename AliasT = Aws::String>
+    DescribeImageVersionRequest& WithAlias(AliasT&& value) { SetAlias(std::forward<AliasT>(value)); return *this;}
     ///@}
   private:
 
     Aws::String m_imageName;
     bool m_imageNameHasBeenSet = false;
 
-    int m_version;
+    int m_version{0};
     bool m_versionHasBeenSet = false;
 
     Aws::String m_alias;
