@@ -33,7 +33,7 @@ namespace Model
   class DriftCheckExplainability
   {
   public:
-    AWS_SAGEMAKER_API DriftCheckExplainability();
+    AWS_SAGEMAKER_API DriftCheckExplainability() = default;
     AWS_SAGEMAKER_API DriftCheckExplainability(Aws::Utils::Json::JsonView jsonValue);
     AWS_SAGEMAKER_API DriftCheckExplainability& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SAGEMAKER_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,24 +43,24 @@ namespace Model
     /**
      * <p>The drift check explainability constraints.</p>
      */
-    inline const MetricsSource& GetConstraints() const{ return m_constraints; }
+    inline const MetricsSource& GetConstraints() const { return m_constraints; }
     inline bool ConstraintsHasBeenSet() const { return m_constraintsHasBeenSet; }
-    inline void SetConstraints(const MetricsSource& value) { m_constraintsHasBeenSet = true; m_constraints = value; }
-    inline void SetConstraints(MetricsSource&& value) { m_constraintsHasBeenSet = true; m_constraints = std::move(value); }
-    inline DriftCheckExplainability& WithConstraints(const MetricsSource& value) { SetConstraints(value); return *this;}
-    inline DriftCheckExplainability& WithConstraints(MetricsSource&& value) { SetConstraints(std::move(value)); return *this;}
+    template<typename ConstraintsT = MetricsSource>
+    void SetConstraints(ConstraintsT&& value) { m_constraintsHasBeenSet = true; m_constraints = std::forward<ConstraintsT>(value); }
+    template<typename ConstraintsT = MetricsSource>
+    DriftCheckExplainability& WithConstraints(ConstraintsT&& value) { SetConstraints(std::forward<ConstraintsT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The explainability config file for the model.</p>
      */
-    inline const FileSource& GetConfigFile() const{ return m_configFile; }
+    inline const FileSource& GetConfigFile() const { return m_configFile; }
     inline bool ConfigFileHasBeenSet() const { return m_configFileHasBeenSet; }
-    inline void SetConfigFile(const FileSource& value) { m_configFileHasBeenSet = true; m_configFile = value; }
-    inline void SetConfigFile(FileSource&& value) { m_configFileHasBeenSet = true; m_configFile = std::move(value); }
-    inline DriftCheckExplainability& WithConfigFile(const FileSource& value) { SetConfigFile(value); return *this;}
-    inline DriftCheckExplainability& WithConfigFile(FileSource&& value) { SetConfigFile(std::move(value)); return *this;}
+    template<typename ConfigFileT = FileSource>
+    void SetConfigFile(ConfigFileT&& value) { m_configFileHasBeenSet = true; m_configFile = std::forward<ConfigFileT>(value); }
+    template<typename ConfigFileT = FileSource>
+    DriftCheckExplainability& WithConfigFile(ConfigFileT&& value) { SetConfigFile(std::forward<ConfigFileT>(value)); return *this;}
     ///@}
   private:
 
