@@ -33,7 +33,7 @@ namespace Model
   class LabelingJobDataAttributes
   {
   public:
-    AWS_SAGEMAKER_API LabelingJobDataAttributes();
+    AWS_SAGEMAKER_API LabelingJobDataAttributes() = default;
     AWS_SAGEMAKER_API LabelingJobDataAttributes(Aws::Utils::Json::JsonView jsonValue);
     AWS_SAGEMAKER_API LabelingJobDataAttributes& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SAGEMAKER_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -45,14 +45,13 @@ namespace Model
      * adult content. SageMaker may restrict the Amazon Mechanical Turk workers that
      * can view your task based on this information.</p>
      */
-    inline const Aws::Vector<ContentClassifier>& GetContentClassifiers() const{ return m_contentClassifiers; }
+    inline const Aws::Vector<ContentClassifier>& GetContentClassifiers() const { return m_contentClassifiers; }
     inline bool ContentClassifiersHasBeenSet() const { return m_contentClassifiersHasBeenSet; }
-    inline void SetContentClassifiers(const Aws::Vector<ContentClassifier>& value) { m_contentClassifiersHasBeenSet = true; m_contentClassifiers = value; }
-    inline void SetContentClassifiers(Aws::Vector<ContentClassifier>&& value) { m_contentClassifiersHasBeenSet = true; m_contentClassifiers = std::move(value); }
-    inline LabelingJobDataAttributes& WithContentClassifiers(const Aws::Vector<ContentClassifier>& value) { SetContentClassifiers(value); return *this;}
-    inline LabelingJobDataAttributes& WithContentClassifiers(Aws::Vector<ContentClassifier>&& value) { SetContentClassifiers(std::move(value)); return *this;}
-    inline LabelingJobDataAttributes& AddContentClassifiers(const ContentClassifier& value) { m_contentClassifiersHasBeenSet = true; m_contentClassifiers.push_back(value); return *this; }
-    inline LabelingJobDataAttributes& AddContentClassifiers(ContentClassifier&& value) { m_contentClassifiersHasBeenSet = true; m_contentClassifiers.push_back(std::move(value)); return *this; }
+    template<typename ContentClassifiersT = Aws::Vector<ContentClassifier>>
+    void SetContentClassifiers(ContentClassifiersT&& value) { m_contentClassifiersHasBeenSet = true; m_contentClassifiers = std::forward<ContentClassifiersT>(value); }
+    template<typename ContentClassifiersT = Aws::Vector<ContentClassifier>>
+    LabelingJobDataAttributes& WithContentClassifiers(ContentClassifiersT&& value) { SetContentClassifiers(std::forward<ContentClassifiersT>(value)); return *this;}
+    inline LabelingJobDataAttributes& AddContentClassifiers(ContentClassifier value) { m_contentClassifiersHasBeenSet = true; m_contentClassifiers.push_back(value); return *this; }
     ///@}
   private:
 
