@@ -32,7 +32,7 @@ namespace Model
   class S3StorageConfig
   {
   public:
-    AWS_SAGEMAKER_API S3StorageConfig();
+    AWS_SAGEMAKER_API S3StorageConfig() = default;
     AWS_SAGEMAKER_API S3StorageConfig(Aws::Utils::Json::JsonView jsonValue);
     AWS_SAGEMAKER_API S3StorageConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SAGEMAKER_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,14 +44,12 @@ namespace Model
      * URIs have a format similar to the following:
      * <code>s3://example-bucket/prefix/</code>.</p>
      */
-    inline const Aws::String& GetS3Uri() const{ return m_s3Uri; }
+    inline const Aws::String& GetS3Uri() const { return m_s3Uri; }
     inline bool S3UriHasBeenSet() const { return m_s3UriHasBeenSet; }
-    inline void SetS3Uri(const Aws::String& value) { m_s3UriHasBeenSet = true; m_s3Uri = value; }
-    inline void SetS3Uri(Aws::String&& value) { m_s3UriHasBeenSet = true; m_s3Uri = std::move(value); }
-    inline void SetS3Uri(const char* value) { m_s3UriHasBeenSet = true; m_s3Uri.assign(value); }
-    inline S3StorageConfig& WithS3Uri(const Aws::String& value) { SetS3Uri(value); return *this;}
-    inline S3StorageConfig& WithS3Uri(Aws::String&& value) { SetS3Uri(std::move(value)); return *this;}
-    inline S3StorageConfig& WithS3Uri(const char* value) { SetS3Uri(value); return *this;}
+    template<typename S3UriT = Aws::String>
+    void SetS3Uri(S3UriT&& value) { m_s3UriHasBeenSet = true; m_s3Uri = std::forward<S3UriT>(value); }
+    template<typename S3UriT = Aws::String>
+    S3StorageConfig& WithS3Uri(S3UriT&& value) { SetS3Uri(std::forward<S3UriT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -63,28 +61,24 @@ namespace Model
      * <code>KmsKeyId</code>:</p> <ul> <li> <p> <code>"kms:GenerateDataKey"</code> </p>
      * </li> </ul>
      */
-    inline const Aws::String& GetKmsKeyId() const{ return m_kmsKeyId; }
+    inline const Aws::String& GetKmsKeyId() const { return m_kmsKeyId; }
     inline bool KmsKeyIdHasBeenSet() const { return m_kmsKeyIdHasBeenSet; }
-    inline void SetKmsKeyId(const Aws::String& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = value; }
-    inline void SetKmsKeyId(Aws::String&& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = std::move(value); }
-    inline void SetKmsKeyId(const char* value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId.assign(value); }
-    inline S3StorageConfig& WithKmsKeyId(const Aws::String& value) { SetKmsKeyId(value); return *this;}
-    inline S3StorageConfig& WithKmsKeyId(Aws::String&& value) { SetKmsKeyId(std::move(value)); return *this;}
-    inline S3StorageConfig& WithKmsKeyId(const char* value) { SetKmsKeyId(value); return *this;}
+    template<typename KmsKeyIdT = Aws::String>
+    void SetKmsKeyId(KmsKeyIdT&& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = std::forward<KmsKeyIdT>(value); }
+    template<typename KmsKeyIdT = Aws::String>
+    S3StorageConfig& WithKmsKeyId(KmsKeyIdT&& value) { SetKmsKeyId(std::forward<KmsKeyIdT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The S3 path where offline records are written.</p>
      */
-    inline const Aws::String& GetResolvedOutputS3Uri() const{ return m_resolvedOutputS3Uri; }
+    inline const Aws::String& GetResolvedOutputS3Uri() const { return m_resolvedOutputS3Uri; }
     inline bool ResolvedOutputS3UriHasBeenSet() const { return m_resolvedOutputS3UriHasBeenSet; }
-    inline void SetResolvedOutputS3Uri(const Aws::String& value) { m_resolvedOutputS3UriHasBeenSet = true; m_resolvedOutputS3Uri = value; }
-    inline void SetResolvedOutputS3Uri(Aws::String&& value) { m_resolvedOutputS3UriHasBeenSet = true; m_resolvedOutputS3Uri = std::move(value); }
-    inline void SetResolvedOutputS3Uri(const char* value) { m_resolvedOutputS3UriHasBeenSet = true; m_resolvedOutputS3Uri.assign(value); }
-    inline S3StorageConfig& WithResolvedOutputS3Uri(const Aws::String& value) { SetResolvedOutputS3Uri(value); return *this;}
-    inline S3StorageConfig& WithResolvedOutputS3Uri(Aws::String&& value) { SetResolvedOutputS3Uri(std::move(value)); return *this;}
-    inline S3StorageConfig& WithResolvedOutputS3Uri(const char* value) { SetResolvedOutputS3Uri(value); return *this;}
+    template<typename ResolvedOutputS3UriT = Aws::String>
+    void SetResolvedOutputS3Uri(ResolvedOutputS3UriT&& value) { m_resolvedOutputS3UriHasBeenSet = true; m_resolvedOutputS3Uri = std::forward<ResolvedOutputS3UriT>(value); }
+    template<typename ResolvedOutputS3UriT = Aws::String>
+    S3StorageConfig& WithResolvedOutputS3Uri(ResolvedOutputS3UriT&& value) { SetResolvedOutputS3Uri(std::forward<ResolvedOutputS3UriT>(value)); return *this;}
     ///@}
   private:
 
