@@ -28,6 +28,7 @@ namespace Model
     ap_southeast_3,
     ap_southeast_4,
     ap_southeast_5,
+    ap_southeast_7,
     ca_central_1,
     ca_west_1,
     cn_north_1,
@@ -43,6 +44,7 @@ namespace Model
     il_central_1,
     me_central_1,
     me_south_1,
+    mx_central_1,
     sa_east_1,
     us_east_1,
     us_east_2,
