@@ -209,8 +209,8 @@ namespace Model
     ///@}
   private:
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
 
     ResolverType m_resolverType{ResolverType::NOT_SET};
     bool m_resolverTypeHasBeenSet = false;
