@@ -32,7 +32,7 @@ namespace Model
   class ActionLocalIpDetails
   {
   public:
-    AWS_SECURITYHUB_API ActionLocalIpDetails();
+    AWS_SECURITYHUB_API ActionLocalIpDetails() = default;
     AWS_SECURITYHUB_API ActionLocalIpDetails(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API ActionLocalIpDetails& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,14 +42,12 @@ namespace Model
     /**
      * <p>The IP address.</p>
      */
-    inline const Aws::String& GetIpAddressV4() const{ return m_ipAddressV4; }
+    inline const Aws::String& GetIpAddressV4() const { return m_ipAddressV4; }
     inline bool IpAddressV4HasBeenSet() const { return m_ipAddressV4HasBeenSet; }
-    inline void SetIpAddressV4(const Aws::String& value) { m_ipAddressV4HasBeenSet = true; m_ipAddressV4 = value; }
-    inline void SetIpAddressV4(Aws::String&& value) { m_ipAddressV4HasBeenSet = true; m_ipAddressV4 = std::move(value); }
-    inline void SetIpAddressV4(const char* value) { m_ipAddressV4HasBeenSet = true; m_ipAddressV4.assign(value); }
-    inline ActionLocalIpDetails& WithIpAddressV4(const Aws::String& value) { SetIpAddressV4(value); return *this;}
-    inline ActionLocalIpDetails& WithIpAddressV4(Aws::String&& value) { SetIpAddressV4(std::move(value)); return *this;}
-    inline ActionLocalIpDetails& WithIpAddressV4(const char* value) { SetIpAddressV4(value); return *this;}
+    template<typename IpAddressV4T = Aws::String>
+    void SetIpAddressV4(IpAddressV4T&& value) { m_ipAddressV4HasBeenSet = true; m_ipAddressV4 = std::forward<IpAddressV4T>(value); }
+    template<typename IpAddressV4T = Aws::String>
+    ActionLocalIpDetails& WithIpAddressV4(IpAddressV4T&& value) { SetIpAddressV4(std::forward<IpAddressV4T>(value)); return *this;}
     ///@}
   private:
 
