@@ -32,7 +32,7 @@ namespace Model
   class AwsEcsServiceDeploymentControllerDetails
   {
   public:
-    AWS_SECURITYHUB_API AwsEcsServiceDeploymentControllerDetails();
+    AWS_SECURITYHUB_API AwsEcsServiceDeploymentControllerDetails() = default;
     AWS_SECURITYHUB_API AwsEcsServiceDeploymentControllerDetails(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API AwsEcsServiceDeploymentControllerDetails& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -50,14 +50,12 @@ namespace Model
      * for an Amazon ECS service.</p> <p>Valid values: <code>ECS</code> |
      * <code>CODE_DEPLOY</code> | <code>EXTERNAL</code> </p>
      */
-    inline const Aws::String& GetType() const{ return m_type; }
+    inline const Aws::String& GetType() const { return m_type; }
     inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }
-    inline void SetType(const Aws::String& value) { m_typeHasBeenSet = true; m_type = value; }
-    inline void SetType(Aws::String&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }
-    inline void SetType(const char* value) { m_typeHasBeenSet = true; m_type.assign(value); }
-    inline AwsEcsServiceDeploymentControllerDetails& WithType(const Aws::String& value) { SetType(value); return *this;}
-    inline AwsEcsServiceDeploymentControllerDetails& WithType(Aws::String&& value) { SetType(std::move(value)); return *this;}
-    inline AwsEcsServiceDeploymentControllerDetails& WithType(const char* value) { SetType(value); return *this;}
+    template<typename TypeT = Aws::String>
+    void SetType(TypeT&& value) { m_typeHasBeenSet = true; m_type = std::forward<TypeT>(value); }
+    template<typename TypeT = Aws::String>
+    AwsEcsServiceDeploymentControllerDetails& WithType(TypeT&& value) { SetType(std::forward<TypeT>(value)); return *this;}
     ///@}
   private:
 
