@@ -32,7 +32,7 @@ namespace Model
   class AwsRedshiftClusterEndpoint
   {
   public:
-    AWS_SECURITYHUB_API AwsRedshiftClusterEndpoint();
+    AWS_SECURITYHUB_API AwsRedshiftClusterEndpoint() = default;
     AWS_SECURITYHUB_API AwsRedshiftClusterEndpoint(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API AwsRedshiftClusterEndpoint& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,21 +42,19 @@ namespace Model
     /**
      * <p>The DNS address of the cluster.</p>
      */
-    inline const Aws::String& GetAddress() const{ return m_address; }
+    inline const Aws::String& GetAddress() const { return m_address; }
     inline bool AddressHasBeenSet() const { return m_addressHasBeenSet; }
-    inline void SetAddress(const Aws::String& value) { m_addressHasBeenSet = true; m_address = value; }
-    inline void SetAddress(Aws::String&& value) { m_addressHasBeenSet = true; m_address = std::move(value); }
-    inline void SetAddress(const char* value) { m_addressHasBeenSet = true; m_address.assign(value); }
-    inline AwsRedshiftClusterEndpoint& WithAddress(const Aws::String& value) { SetAddress(value); return *this;}
-    inline AwsRedshiftClusterEndpoint& WithAddress(Aws::String&& value) { SetAddress(std::move(value)); return *this;}
-    inline AwsRedshiftClusterEndpoint& WithAddress(const char* value) { SetAddress(value); return *this;}
+    template<typename AddressT = Aws::String>
+    void SetAddress(AddressT&& value) { m_addressHasBeenSet = true; m_address = std::forward<AddressT>(value); }
+    template<typename AddressT = Aws::String>
+    AwsRedshiftClusterEndpoint& WithAddress(AddressT&& value) { SetAddress(std::forward<AddressT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The port that the database engine listens on.</p>
      */
-    inline int GetPort() const{ return m_port; }
+    inline int GetPort() const { return m_port; }
     inline bool PortHasBeenSet() const { return m_portHasBeenSet; }
     inline void SetPort(int value) { m_portHasBeenSet = true; m_port = value; }
     inline AwsRedshiftClusterEndpoint& WithPort(int value) { SetPort(value); return *this;}
@@ -66,7 +64,7 @@ namespace Model
     Aws::String m_address;
     bool m_addressHasBeenSet = false;
 
-    int m_port;
+    int m_port{0};
     bool m_portHasBeenSet = false;
   };
 
