@@ -29,7 +29,7 @@ namespace Model
   class PortRange
   {
   public:
-    AWS_SECURITYHUB_API PortRange();
+    AWS_SECURITYHUB_API PortRange() = default;
     AWS_SECURITYHUB_API PortRange(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API PortRange& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -39,7 +39,7 @@ namespace Model
     /**
      * <p>The first port in the port range.</p>
      */
-    inline int GetBegin() const{ return m_begin; }
+    inline int GetBegin() const { return m_begin; }
     inline bool BeginHasBeenSet() const { return m_beginHasBeenSet; }
     inline void SetBegin(int value) { m_beginHasBeenSet = true; m_begin = value; }
     inline PortRange& WithBegin(int value) { SetBegin(value); return *this;}
@@ -49,17 +49,17 @@ namespace Model
     /**
      * <p>The last port in the port range.</p>
      */
-    inline int GetEnd() const{ return m_end; }
+    inline int GetEnd() const { return m_end; }
     inline bool EndHasBeenSet() const { return m_endHasBeenSet; }
     inline void SetEnd(int value) { m_endHasBeenSet = true; m_end = value; }
     inline PortRange& WithEnd(int value) { SetEnd(value); return *this;}
     ///@}
   private:
 
-    int m_begin;
+    int m_begin{0};
     bool m_beginHasBeenSet = false;
 
-    int m_end;
+    int m_end{0};
     bool m_endHasBeenSet = false;
   };
 
