@@ -32,7 +32,7 @@ namespace Model
   class StatelessCustomActionDefinition
   {
   public:
-    AWS_SECURITYHUB_API StatelessCustomActionDefinition();
+    AWS_SECURITYHUB_API StatelessCustomActionDefinition() = default;
     AWS_SECURITYHUB_API StatelessCustomActionDefinition(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API StatelessCustomActionDefinition& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,12 +42,12 @@ namespace Model
     /**
      * <p>Information about metrics to publish to CloudWatch.</p>
      */
-    inline const StatelessCustomPublishMetricAction& GetPublishMetricAction() const{ return m_publishMetricAction; }
+    inline const StatelessCustomPublishMetricAction& GetPublishMetricAction() const { return m_publishMetricAction; }
     inline bool PublishMetricActionHasBeenSet() const { return m_publishMetricActionHasBeenSet; }
-    inline void SetPublishMetricAction(const StatelessCustomPublishMetricAction& value) { m_publishMetricActionHasBeenSet = true; m_publishMetricAction = value; }
-    inline void SetPublishMetricAction(StatelessCustomPublishMetricAction&& value) { m_publishMetricActionHasBeenSet = true; m_publishMetricAction = std::move(value); }
-    inline StatelessCustomActionDefinition& WithPublishMetricAction(const StatelessCustomPublishMetricAction& value) { SetPublishMetricAction(value); return *this;}
-    inline StatelessCustomActionDefinition& WithPublishMetricAction(StatelessCustomPublishMetricAction&& value) { SetPublishMetricAction(std::move(value)); return *this;}
+    template<typename PublishMetricActionT = StatelessCustomPublishMetricAction>
+    void SetPublishMetricAction(PublishMetricActionT&& value) { m_publishMetricActionHasBeenSet = true; m_publishMetricAction = std::forward<PublishMetricActionT>(value); }
+    template<typename PublishMetricActionT = StatelessCustomPublishMetricAction>
+    StatelessCustomActionDefinition& WithPublishMetricAction(PublishMetricActionT&& value) { SetPublishMetricAction(std::forward<PublishMetricActionT>(value)); return *this;}
     ///@}
   private:
 
