@@ -17,7 +17,10 @@ namespace Model
   {
     NOT_SET,
     CLOUD_FORMATION_TEMPLATE,
-    MARKETPLACE
+    MARKETPLACE,
+    TERRAFORM_OPEN_SOURCE,
+    TERRAFORM_CLOUD,
+    EXTERNAL
   };
 
 namespace ProductTypeMapper
