@@ -35,7 +35,7 @@ namespace Model
   class ServiceFilter
   {
   public:
-    AWS_SERVICEDISCOVERY_API ServiceFilter();
+    AWS_SERVICEDISCOVERY_API ServiceFilter() = default;
     AWS_SERVICEDISCOVERY_API ServiceFilter(Aws::Utils::Json::JsonView jsonValue);
     AWS_SERVICEDISCOVERY_API ServiceFilter& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SERVICEDISCOVERY_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -45,12 +45,10 @@ namespace Model
     /**
      * <p>Specify <code>NAMESPACE_ID</code>.</p>
      */
-    inline const ServiceFilterName& GetName() const{ return m_name; }
+    inline ServiceFilterName GetName() const { return m_name; }
     inline bool NameHasBeenSet() const { return m_nameHasBeenSet; }
-    inline void SetName(const ServiceFilterName& value) { m_nameHasBeenSet = true; m_name = value; }
-    inline void SetName(ServiceFilterName&& value) { m_nameHasBeenSet = true; m_name = std::move(value); }
-    inline ServiceFilter& WithName(const ServiceFilterName& value) { SetName(value); return *this;}
-    inline ServiceFilter& WithName(ServiceFilterName&& value) { SetName(std::move(value)); return *this;}
+    inline void SetName(ServiceFilterName value) { m_nameHasBeenSet = true; m_name = value; }
+    inline ServiceFilter& WithName(ServiceFilterName value) { SetName(value); return *this;}
     ///@}
 
     ///@{
@@ -58,15 +56,14 @@ namespace Model
      * <p>The values that are applicable to the value that you specify for
      * <code>Condition</code> to filter the list of services.</p>
      */
-    inline const Aws::Vector<Aws::String>& GetValues() const{ return m_values; }
+    inline const Aws::Vector<Aws::String>& GetValues() const { return m_values; }
     inline bool ValuesHasBeenSet() const { return m_valuesHasBeenSet; }
-    inline void SetValues(const Aws::Vector<Aws::String>& value) { m_valuesHasBeenSet = true; m_values = value; }
-    inline void SetValues(Aws::Vector<Aws::String>&& value) { m_valuesHasBeenSet = true; m_values = std::move(value); }
-    inline ServiceFilter& WithValues(const Aws::Vector<Aws::String>& value) { SetValues(value); return *this;}
-    inline ServiceFilter& WithValues(Aws::Vector<Aws::String>&& value) { SetValues(std::move(value)); return *this;}
-    inline ServiceFilter& AddValues(const Aws::String& value) { m_valuesHasBeenSet = true; m_values.push_back(value); return *this; }
-    inline ServiceFilter& AddValues(Aws::String&& value) { m_valuesHasBeenSet = true; m_values.push_back(std::move(value)); return *this; }
-    inline ServiceFilter& AddValues(const char* value) { m_valuesHasBeenSet = true; m_values.push_back(value); return *this; }
+    template<typename ValuesT = Aws::Vector<Aws::String>>
+    void SetValues(ValuesT&& value) { m_valuesHasBeenSet = true; m_values = std::forward<ValuesT>(value); }
+    template<typename ValuesT = Aws::Vector<Aws::String>>
+    ServiceFilter& WithValues(ValuesT&& value) { SetValues(std::forward<ValuesT>(value)); return *this;}
+    template<typename ValuesT = Aws::String>
+    ServiceFilter& AddValues(ValuesT&& value) { m_valuesHasBeenSet = true; m_values.emplace_back(std::forward<ValuesT>(value)); return *this; }
     ///@}
 
     ///@{
@@ -77,22 +74,20 @@ namespace Model
      * <code>EQ</code>, specify one namespace ID for <code>Values</code>.
      * <code>EQ</code> is the default condition and can be omitted.</p> </li> </ul>
      */
-    inline const FilterCondition& GetCondition() const{ return m_condition; }
+    inline FilterCondition GetCondition() const { return m_condition; }
     inline bool ConditionHasBeenSet() const { return m_conditionHasBeenSet; }
-    inline void SetCondition(const FilterCondition& value) { m_conditionHasBeenSet = true; m_condition = value; }
-    inline void SetCondition(FilterCondition&& value) { m_conditionHasBeenSet = true; m_condition = std::move(value); }
-    inline ServiceFilter& WithCondition(const FilterCondition& value) { SetCondition(value); return *this;}
-    inline ServiceFilter& WithCondition(FilterCondition&& value) { SetCondition(std::move(value)); return *this;}
+    inline void SetCondition(FilterCondition value) { m_conditionHasBeenSet = true; m_condition = value; }
+    inline ServiceFilter& WithCondition(FilterCondition value) { SetCondition(value); return *this;}
     ///@}
   private:
 
-    ServiceFilterName m_name;
+    ServiceFilterName m_name{ServiceFilterName::NOT_SET};
     bool m_nameHasBeenSet = false;
 
     Aws::Vector<Aws::String> m_values;
     bool m_valuesHasBeenSet = false;
 
-    FilterCondition m_condition;
+    FilterCondition m_condition{FilterCondition::NOT_SET};
     bool m_conditionHasBeenSet = false;
   };
 
