@@ -21,7 +21,7 @@ namespace Model
   class GetAppValidationOutputRequest : public SMSRequest
   {
   public:
-    AWS_SMS_API GetAppValidationOutputRequest();
+    AWS_SMS_API GetAppValidationOutputRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -38,14 +38,12 @@ namespace Model
     /**
      * <p>The ID of the application.</p>
      */
-    inline const Aws::String& GetAppId() const{ return m_appId; }
+    inline const Aws::String& GetAppId() const { return m_appId; }
     inline bool AppIdHasBeenSet() const { return m_appIdHasBeenSet; }
-    inline void SetAppId(const Aws::String& value) { m_appIdHasBeenSet = true; m_appId = value; }
-    inline void SetAppId(Aws::String&& value) { m_appIdHasBeenSet = true; m_appId = std::move(value); }
-    inline void SetAppId(const char* value) { m_appIdHasBeenSet = true; m_appId.assign(value); }
-    inline GetAppValidationOutputRequest& WithAppId(const Aws::String& value) { SetAppId(value); return *this;}
-    inline GetAppValidationOutputRequest& WithAppId(Aws::String&& value) { SetAppId(std::move(value)); return *this;}
-    inline GetAppValidationOutputRequest& WithAppId(const char* value) { SetAppId(value); return *this;}
+    template<typename AppIdT = Aws::String>
+    void SetAppId(AppIdT&& value) { m_appIdHasBeenSet = true; m_appId = std::forward<AppIdT>(value); }
+    template<typename AppIdT = Aws::String>
+    GetAppValidationOutputRequest& WithAppId(AppIdT&& value) { SetAppId(std::forward<AppIdT>(value)); return *this;}
     ///@}
   private:
 
