@@ -25,7 +25,7 @@ namespace Model
   class GetIncidentRecordRequest : public SSMIncidentsRequest
   {
   public:
-    AWS_SSMINCIDENTS_API GetIncidentRecordRequest();
+    AWS_SSMINCIDENTS_API GetIncidentRecordRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -42,14 +42,12 @@ namespace Model
     /**
      * <p>The Amazon Resource Name (ARN) of the incident record.</p>
      */
-    inline const Aws::String& GetArn() const{ return m_arn; }
+    inline const Aws::String& GetArn() const { return m_arn; }
     inline bool ArnHasBeenSet() const { return m_arnHasBeenSet; }
-    inline void SetArn(const Aws::String& value) { m_arnHasBeenSet = true; m_arn = value; }
-    inline void SetArn(Aws::String&& value) { m_arnHasBeenSet = true; m_arn = std::move(value); }
-    inline void SetArn(const char* value) { m_arnHasBeenSet = true; m_arn.assign(value); }
-    inline GetIncidentRecordRequest& WithArn(const Aws::String& value) { SetArn(value); return *this;}
-    inline GetIncidentRecordRequest& WithArn(Aws::String&& value) { SetArn(std::move(value)); return *this;}
-    inline GetIncidentRecordRequest& WithArn(const char* value) { SetArn(value); return *this;}
+    template<typename ArnT = Aws::String>
+    void SetArn(ArnT&& value) { m_arnHasBeenSet = true; m_arn = std::forward<ArnT>(value); }
+    template<typename ArnT = Aws::String>
+    GetIncidentRecordRequest& WithArn(ArnT&& value) { SetArn(std::forward<ArnT>(value)); return *this;}
     ///@}
   private:
 
