@@ -32,7 +32,7 @@ namespace Model
   class CompliantSummary
   {
   public:
-    AWS_SSM_API CompliantSummary();
+    AWS_SSM_API CompliantSummary() = default;
     AWS_SSM_API CompliantSummary(Aws::Utils::Json::JsonView jsonValue);
     AWS_SSM_API CompliantSummary& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SSM_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,7 +42,7 @@ namespace Model
     /**
      * <p>The total number of resources that are compliant.</p>
      */
-    inline int GetCompliantCount() const{ return m_compliantCount; }
+    inline int GetCompliantCount() const { return m_compliantCount; }
     inline bool CompliantCountHasBeenSet() const { return m_compliantCountHasBeenSet; }
     inline void SetCompliantCount(int value) { m_compliantCountHasBeenSet = true; m_compliantCount = value; }
     inline CompliantSummary& WithCompliantCount(int value) { SetCompliantCount(value); return *this;}
@@ -52,16 +52,16 @@ namespace Model
     /**
      * <p>A summary of the compliance severity by compliance type.</p>
      */
-    inline const SeveritySummary& GetSeveritySummary() const{ return m_severitySummary; }
+    inline const SeveritySummary& GetSeveritySummary() const { return m_severitySummary; }
     inline bool SeveritySummaryHasBeenSet() const { return m_severitySummaryHasBeenSet; }
-    inline void SetSeveritySummary(const SeveritySummary& value) { m_severitySummaryHasBeenSet = true; m_severitySummary = value; }
-    inline void SetSeveritySummary(SeveritySummary&& value) { m_severitySummaryHasBeenSet = true; m_severitySummary = std::move(value); }
-    inline CompliantSummary& WithSeveritySummary(const SeveritySummary& value) { SetSeveritySummary(value); return *this;}
-    inline CompliantSummary& WithSeveritySummary(SeveritySummary&& value) { SetSeveritySummary(std::move(value)); return *this;}
+    template<typename SeveritySummaryT = SeveritySummary>
+    void SetSeveritySummary(SeveritySummaryT&& value) { m_severitySummaryHasBeenSet = true; m_severitySummary = std::forward<SeveritySummaryT>(value); }
+    template<typename SeveritySummaryT = SeveritySummary>
+    CompliantSummary& WithSeveritySummary(SeveritySummaryT&& value) { SetSeveritySummary(std::forward<SeveritySummaryT>(value)); return *this;}
     ///@}
   private:
 
-    int m_compliantCount;
+    int m_compliantCount{0};
     bool m_compliantCountHasBeenSet = false;
 
     SeveritySummary m_severitySummary;
