@@ -30,7 +30,7 @@ namespace Model
   class CacheAttributes
   {
   public:
-    AWS_STORAGEGATEWAY_API CacheAttributes();
+    AWS_STORAGEGATEWAY_API CacheAttributes() = default;
     AWS_STORAGEGATEWAY_API CacheAttributes(Aws::Utils::Json::JsonView jsonValue);
     AWS_STORAGEGATEWAY_API CacheAttributes& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_STORAGEGATEWAY_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,14 +44,14 @@ namespace Model
      * bucket or Amazon FSx file system. The TTL duration is in seconds.</p> <p>Valid
      * Values:0, 300 to 2,592,000 seconds (5 minutes to 30 days)</p>
      */
-    inline int GetCacheStaleTimeoutInSeconds() const{ return m_cacheStaleTimeoutInSeconds; }
+    inline int GetCacheStaleTimeoutInSeconds() const { return m_cacheStaleTimeoutInSeconds; }
     inline bool CacheStaleTimeoutInSecondsHasBeenSet() const { return m_cacheStaleTimeoutInSecondsHasBeenSet; }
     inline void SetCacheStaleTimeoutInSeconds(int value) { m_cacheStaleTimeoutInSecondsHasBeenSet = true; m_cacheStaleTimeoutInSeconds = value; }
     inline CacheAttributes& WithCacheStaleTimeoutInSeconds(int value) { SetCacheStaleTimeoutInSeconds(value); return *this;}
     ///@}
   private:
 
-    int m_cacheStaleTimeoutInSeconds;
+    int m_cacheStaleTimeoutInSeconds{0};
     bool m_cacheStaleTimeoutInSecondsHasBeenSet = false;
   };
 
