@@ -7,6 +7,8 @@
 #include <aws/synthetics/Synthetics_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/Array.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/synthetics/model/Dependency.h>
 #include <utility>
 
 namespace Aws
@@ -128,6 +130,22 @@ namespace Model
     template<typename HandlerT = Aws::String>
     CanaryCodeInput& WithHandler(HandlerT&& value) { SetHandler(std::forward<HandlerT>(value)); return *this;}
     ///@}
+
+    ///@{
+    /**
+     * <p>A list of dependencies that should be used for running this canary. Specify
+     * the dependencies as a key-value pair, where the key is the type of dependency
+     * and the value is the dependency reference.</p>
+     */
+    inline const Aws::Vector<Dependency>& GetDependencies() const { return m_dependencies; }
+    inline bool DependenciesHasBeenSet() const { return m_dependenciesHasBeenSet; }
+    template<typename DependenciesT = Aws::Vector<Dependency>>
+    void SetDependencies(DependenciesT&& value) { m_dependenciesHasBeenSet = true; m_dependencies = std::forward<DependenciesT>(value); }
+    template<typename DependenciesT = Aws::Vector<Dependency>>
+    CanaryCodeInput& WithDependencies(DependenciesT&& value) { SetDependencies(std::forward<DependenciesT>(value)); return *this;}
+    template<typename DependenciesT = Dependency>
+    CanaryCodeInput& AddDependencies(DependenciesT&& value) { m_dependenciesHasBeenSet = true; m_dependencies.emplace_back(std::forward<DependenciesT>(value)); return *this; }
+    ///@}
   private:
 
     Aws::String m_s3Bucket;
@@ -144,6 +162,9 @@ namespace Model
 
     Aws::String m_handler;
     bool m_handlerHasBeenSet = false;
+
+    Aws::Vector<Dependency> m_dependencies;
+    bool m_dependenciesHasBeenSet = false;
   };
 
 } // namespace Model
