@@ -21,7 +21,7 @@ namespace Model
   class DetectDocumentTextRequest : public TextractRequest
   {
   public:
-    AWS_TEXTRACT_API DetectDocumentTextRequest();
+    AWS_TEXTRACT_API DetectDocumentTextRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -42,12 +42,12 @@ namespace Model
      * SDK to call Amazon Textract, you might not need to base64-encode image bytes
      * that are passed using the <code>Bytes</code> field. </p>
      */
-    inline const Document& GetDocument() const{ return m_document; }
+    inline const Document& GetDocument() const { return m_document; }
     inline bool DocumentHasBeenSet() const { return m_documentHasBeenSet; }
-    inline void SetDocument(const Document& value) { m_documentHasBeenSet = true; m_document = value; }
-    inline void SetDocument(Document&& value) { m_documentHasBeenSet = true; m_document = std::move(value); }
-    inline DetectDocumentTextRequest& WithDocument(const Document& value) { SetDocument(value); return *this;}
-    inline DetectDocumentTextRequest& WithDocument(Document&& value) { SetDocument(std::move(value)); return *this;}
+    template<typename DocumentT = Document>
+    void SetDocument(DocumentT&& value) { m_documentHasBeenSet = true; m_document = std::forward<DocumentT>(value); }
+    template<typename DocumentT = Document>
+    DetectDocumentTextRequest& WithDocument(DocumentT&& value) { SetDocument(std::forward<DocumentT>(value)); return *this;}
     ///@}
   private:
 
