@@ -21,7 +21,7 @@ namespace Model
   class DeleteSpeakerRequest : public VoiceIDRequest
   {
   public:
-    AWS_VOICEID_API DeleteSpeakerRequest();
+    AWS_VOICEID_API DeleteSpeakerRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -38,28 +38,24 @@ namespace Model
     /**
      * <p>The identifier of the domain that contains the speaker.</p>
      */
-    inline const Aws::String& GetDomainId() const{ return m_domainId; }
+    inline const Aws::String& GetDomainId() const { return m_domainId; }
     inline bool DomainIdHasBeenSet() const { return m_domainIdHasBeenSet; }
-    inline void SetDomainId(const Aws::String& value) { m_domainIdHasBeenSet = true; m_domainId = value; }
-    inline void SetDomainId(Aws::String&& value) { m_domainIdHasBeenSet = true; m_domainId = std::move(value); }
-    inline void SetDomainId(const char* value) { m_domainIdHasBeenSet = true; m_domainId.assign(value); }
-    inline DeleteSpeakerRequest& WithDomainId(const Aws::String& value) { SetDomainId(value); return *this;}
-    inline DeleteSpeakerRequest& WithDomainId(Aws::String&& value) { SetDomainId(std::move(value)); return *this;}
-    inline DeleteSpeakerRequest& WithDomainId(const char* value) { SetDomainId(value); return *this;}
+    template<typename DomainIdT = Aws::String>
+    void SetDomainId(DomainIdT&& value) { m_domainIdHasBeenSet = true; m_domainId = std::forward<DomainIdT>(value); }
+    template<typename DomainIdT = Aws::String>
+    DeleteSpeakerRequest& WithDomainId(DomainIdT&& value) { SetDomainId(std::forward<DomainIdT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The identifier of the speaker you want to delete.</p>
      */
-    inline const Aws::String& GetSpeakerId() const{ return m_speakerId; }
+    inline const Aws::String& GetSpeakerId() const { return m_speakerId; }
     inline bool SpeakerIdHasBeenSet() const { return m_speakerIdHasBeenSet; }
-    inline void SetSpeakerId(const Aws::String& value) { m_speakerIdHasBeenSet = true; m_speakerId = value; }
-    inline void SetSpeakerId(Aws::String&& value) { m_speakerIdHasBeenSet = true; m_speakerId = std::move(value); }
-    inline void SetSpeakerId(const char* value) { m_speakerIdHasBeenSet = true; m_speakerId.assign(value); }
-    inline DeleteSpeakerRequest& WithSpeakerId(const Aws::String& value) { SetSpeakerId(value); return *this;}
-    inline DeleteSpeakerRequest& WithSpeakerId(Aws::String&& value) { SetSpeakerId(std::move(value)); return *this;}
-    inline DeleteSpeakerRequest& WithSpeakerId(const char* value) { SetSpeakerId(value); return *this;}
+    template<typename SpeakerIdT = Aws::String>
+    void SetSpeakerId(SpeakerIdT&& value) { m_speakerIdHasBeenSet = true; m_speakerId = std::forward<SpeakerIdT>(value); }
+    template<typename SpeakerIdT = Aws::String>
+    DeleteSpeakerRequest& WithSpeakerId(SpeakerIdT&& value) { SetSpeakerId(std::forward<SpeakerIdT>(value)); return *this;}
     ///@}
   private:
 
