@@ -23,7 +23,7 @@ namespace Model
   class GetLoggingConfigurationRequest : public WAFV2Request
   {
   public:
-    AWS_WAFV2_API GetLoggingConfigurationRequest();
+    AWS_WAFV2_API GetLoggingConfigurationRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -41,14 +41,12 @@ namespace Model
      * <p>The Amazon Resource Name (ARN) of the web ACL for which you want to get the
      * <a>LoggingConfiguration</a>.</p>
      */
-    inline const Aws::String& GetResourceArn() const{ return m_resourceArn; }
+    inline const Aws::String& GetResourceArn() const { return m_resourceArn; }
     inline bool ResourceArnHasBeenSet() const { return m_resourceArnHasBeenSet; }
-    inline void SetResourceArn(const Aws::String& value) { m_resourceArnHasBeenSet = true; m_resourceArn = value; }
-    inline void SetResourceArn(Aws::String&& value) { m_resourceArnHasBeenSet = true; m_resourceArn = std::move(value); }
-    inline void SetResourceArn(const char* value) { m_resourceArnHasBeenSet = true; m_resourceArn.assign(value); }
-    inline GetLoggingConfigurationRequest& WithResourceArn(const Aws::String& value) { SetResourceArn(value); return *this;}
-    inline GetLoggingConfigurationRequest& WithResourceArn(Aws::String&& value) { SetResourceArn(std::move(value)); return *this;}
-    inline GetLoggingConfigurationRequest& WithResourceArn(const char* value) { SetResourceArn(value); return *this;}
+    template<typename ResourceArnT = Aws::String>
+    void SetResourceArn(ResourceArnT&& value) { m_resourceArnHasBeenSet = true; m_resourceArn = std::forward<ResourceArnT>(value); }
+    template<typename ResourceArnT = Aws::String>
+    GetLoggingConfigurationRequest& WithResourceArn(ResourceArnT&& value) { SetResourceArn(std::forward<ResourceArnT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -56,12 +54,10 @@ namespace Model
      * <p>Used to distinguish between various logging options. Currently, there is one
      * option.</p> <p>Default: <code>WAF_LOGS</code> </p>
      */
-    inline const LogType& GetLogType() const{ return m_logType; }
+    inline LogType GetLogType() const { return m_logType; }
     inline bool LogTypeHasBeenSet() const { return m_logTypeHasBeenSet; }
-    inline void SetLogType(const LogType& value) { m_logTypeHasBeenSet = true; m_logType = value; }
-    inline void SetLogType(LogType&& value) { m_logTypeHasBeenSet = true; m_logType = std::move(value); }
-    inline GetLoggingConfigurationRequest& WithLogType(const LogType& value) { SetLogType(value); return *this;}
-    inline GetLoggingConfigurationRequest& WithLogType(LogType&& value) { SetLogType(std::move(value)); return *this;}
+    inline void SetLogType(LogType value) { m_logTypeHasBeenSet = true; m_logType = value; }
+    inline GetLoggingConfigurationRequest& WithLogType(LogType value) { SetLogType(value); return *this;}
     ///@}
 
     ///@{
@@ -76,22 +72,20 @@ namespace Model
      * data from Amazon Web Services services</a> in the <i>Amazon Security Lake user
      * guide</i>. </p> <p>Default: <code>CUSTOMER</code> </p>
      */
-    inline const LogScope& GetLogScope() const{ return m_logScope; }
+    inline LogScope GetLogScope() const { return m_logScope; }
     inline bool LogScopeHasBeenSet() const { return m_logScopeHasBeenSet; }
-    inline void SetLogScope(const LogScope& value) { m_logScopeHasBeenSet = true; m_logScope = value; }
-    inline void SetLogScope(LogScope&& value) { m_logScopeHasBeenSet = true; m_logScope = std::move(value); }
-    inline GetLoggingConfigurationRequest& WithLogScope(const LogScope& value) { SetLogScope(value); return *this;}
-    inline GetLoggingConfigurationRequest& WithLogScope(LogScope&& value) { SetLogScope(std::move(value)); return *this;}
+    inline void SetLogScope(LogScope value) { m_logScopeHasBeenSet = true; m_logScope = value; }
+    inline GetLoggingConfigurationRequest& WithLogScope(LogScope value) { SetLogScope(value); return *this;}
     ///@}
   private:
 
     Aws::String m_resourceArn;
     bool m_resourceArnHasBeenSet = false;
 
-    LogType m_logType;
+    LogType m_logType{LogType::NOT_SET};
     bool m_logTypeHasBeenSet = false;
 
-    LogScope m_logScope;
+    LogScope m_logScope{LogScope::NOT_SET};
     bool m_logScopeHasBeenSet = false;
   };
 
