@@ -27,7 +27,7 @@ namespace Model
   class PutManagedRuleSetVersionsResult
   {
   public:
-    AWS_WAFV2_API PutManagedRuleSetVersionsResult();
+    AWS_WAFV2_API PutManagedRuleSetVersionsResult() = default;
     AWS_WAFV2_API PutManagedRuleSetVersionsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
     AWS_WAFV2_API PutManagedRuleSetVersionsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
 
@@ -43,30 +43,28 @@ namespace Model
      * fails with a <code>WAFOptimisticLockException</code>. If this happens, perform
      * another <code>get</code>, and use the new token returned by that operation. </p>
      */
-    inline const Aws::String& GetNextLockToken() const{ return m_nextLockToken; }
-    inline void SetNextLockToken(const Aws::String& value) { m_nextLockToken = value; }
-    inline void SetNextLockToken(Aws::String&& value) { m_nextLockToken = std::move(value); }
-    inline void SetNextLockToken(const char* value) { m_nextLockToken.assign(value); }
-    inline PutManagedRuleSetVersionsResult& WithNextLockToken(const Aws::String& value) { SetNextLockToken(value); return *this;}
-    inline PutManagedRuleSetVersionsResult& WithNextLockToken(Aws::String&& value) { SetNextLockToken(std::move(value)); return *this;}
-    inline PutManagedRuleSetVersionsResult& WithNextLockToken(const char* value) { SetNextLockToken(value); return *this;}
+    inline const Aws::String& GetNextLockToken() const { return m_nextLockToken; }
+    template<typename NextLockTokenT = Aws::String>
+    void SetNextLockToken(NextLockTokenT&& value) { m_nextLockTokenHasBeenSet = true; m_nextLockToken = std::forward<NextLockTokenT>(value); }
+    template<typename NextLockTokenT = Aws::String>
+    PutManagedRuleSetVersionsResult& WithNextLockToken(NextLockTokenT&& value) { SetNextLockToken(std::forward<NextLockTokenT>(value)); return *this;}
     ///@}
 
     ///@{
     
-    inline const Aws::String& GetRequestId() const{ return m_requestId; }
-    inline void SetRequestId(const Aws::String& value) { m_requestId = value; }
-    inline void SetRequestId(Aws::String&& value) { m_requestId = std::move(value); }
-    inline void SetRequestId(const char* value) { m_requestId.assign(value); }
-    inline PutManagedRuleSetVersionsResult& WithRequestId(const Aws::String& value) { SetRequestId(value); return *this;}
-    inline PutManagedRuleSetVersionsResult& WithRequestId(Aws::String&& value) { SetRequestId(std::move(value)); return *this;}
-    inline PutManagedRuleSetVersionsResult& WithRequestId(const char* value) { SetRequestId(value); return *this;}
+    inline const Aws::String& GetRequestId() const { return m_requestId; }
+    template<typename RequestIdT = Aws::String>
+    void SetRequestId(RequestIdT&& value) { m_requestIdHasBeenSet = true; m_requestId = std::forward<RequestIdT>(value); }
+    template<typename RequestIdT = Aws::String>
+    PutManagedRuleSetVersionsResult& WithRequestId(RequestIdT&& value) { SetRequestId(std::forward<RequestIdT>(value)); return *this;}
     ///@}
   private:
 
     Aws::String m_nextLockToken;
+    bool m_nextLockTokenHasBeenSet = false;
 
     Aws::String m_requestId;
+    bool m_requestIdHasBeenSet = false;
   };
 
 } // namespace Model
