@@ -34,7 +34,7 @@ namespace Model
   class ChoiceAnswerSummary
   {
   public:
-    AWS_WELLARCHITECTED_API ChoiceAnswerSummary();
+    AWS_WELLARCHITECTED_API ChoiceAnswerSummary() = default;
     AWS_WELLARCHITECTED_API ChoiceAnswerSummary(Aws::Utils::Json::JsonView jsonValue);
     AWS_WELLARCHITECTED_API ChoiceAnswerSummary& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_WELLARCHITECTED_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,48 +42,42 @@ namespace Model
 
     ///@{
     
-    inline const Aws::String& GetChoiceId() const{ return m_choiceId; }
+    inline const Aws::String& GetChoiceId() const { return m_choiceId; }
     inline bool ChoiceIdHasBeenSet() const { return m_choiceIdHasBeenSet; }
-    inline void SetChoiceId(const Aws::String& value) { m_choiceIdHasBeenSet = true; m_choiceId = value; }
-    inline void SetChoiceId(Aws::String&& value) { m_choiceIdHasBeenSet = true; m_choiceId = std::move(value); }
-    inline void SetChoiceId(const char* value) { m_choiceIdHasBeenSet = true; m_choiceId.assign(value); }
-    inline ChoiceAnswerSummary& WithChoiceId(const Aws::String& value) { SetChoiceId(value); return *this;}
-    inline ChoiceAnswerSummary& WithChoiceId(Aws::String&& value) { SetChoiceId(std::move(value)); return *this;}
-    inline ChoiceAnswerSummary& WithChoiceId(const char* value) { SetChoiceId(value); return *this;}
+    template<typename ChoiceIdT = Aws::String>
+    void SetChoiceId(ChoiceIdT&& value) { m_choiceIdHasBeenSet = true; m_choiceId = std::forward<ChoiceIdT>(value); }
+    template<typename ChoiceIdT = Aws::String>
+    ChoiceAnswerSummary& WithChoiceId(ChoiceIdT&& value) { SetChoiceId(std::forward<ChoiceIdT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The status of a choice.</p>
      */
-    inline const ChoiceStatus& GetStatus() const{ return m_status; }
+    inline ChoiceStatus GetStatus() const { return m_status; }
     inline bool StatusHasBeenSet() const { return m_statusHasBeenSet; }
-    inline void SetStatus(const ChoiceStatus& value) { m_statusHasBeenSet = true; m_status = value; }
-    inline void SetStatus(ChoiceStatus&& value) { m_statusHasBeenSet = true; m_status = std::move(value); }
-    inline ChoiceAnswerSummary& WithStatus(const ChoiceStatus& value) { SetStatus(value); return *this;}
-    inline ChoiceAnswerSummary& WithStatus(ChoiceStatus&& value) { SetStatus(std::move(value)); return *this;}
+    inline void SetStatus(ChoiceStatus value) { m_statusHasBeenSet = true; m_status = value; }
+    inline ChoiceAnswerSummary& WithStatus(ChoiceStatus value) { SetStatus(value); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The reason why a choice is non-applicable to a question in your workload.</p>
      */
-    inline const ChoiceReason& GetReason() const{ return m_reason; }
+    inline ChoiceReason GetReason() const { return m_reason; }
     inline bool ReasonHasBeenSet() const { return m_reasonHasBeenSet; }
-    inline void SetReason(const ChoiceReason& value) { m_reasonHasBeenSet = true; m_reason = value; }
-    inline void SetReason(ChoiceReason&& value) { m_reasonHasBeenSet = true; m_reason = std::move(value); }
-    inline ChoiceAnswerSummary& WithReason(const ChoiceReason& value) { SetReason(value); return *this;}
-    inline ChoiceAnswerSummary& WithReason(ChoiceReason&& value) { SetReason(std::move(value)); return *this;}
+    inline void SetReason(ChoiceReason value) { m_reasonHasBeenSet = true; m_reason = value; }
+    inline ChoiceAnswerSummary& WithReason(ChoiceReason value) { SetReason(value); return *this;}
     ///@}
   private:
 
     Aws::String m_choiceId;
     bool m_choiceIdHasBeenSet = false;
 
-    ChoiceStatus m_status;
+    ChoiceStatus m_status{ChoiceStatus::NOT_SET};
     bool m_statusHasBeenSet = false;
 
-    ChoiceReason m_reason;
+    ChoiceReason m_reason{ChoiceReason::NOT_SET};
     bool m_reasonHasBeenSet = false;
   };
 
