@@ -35,7 +35,7 @@ namespace Model
   class Permission
   {
   public:
-    AWS_WORKMAIL_API Permission();
+    AWS_WORKMAIL_API Permission() = default;
     AWS_WORKMAIL_API Permission(Aws::Utils::Json::JsonView jsonValue);
     AWS_WORKMAIL_API Permission& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_WORKMAIL_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -46,26 +46,22 @@ namespace Model
      * <p>The identifier of the user, group, or resource to which the permissions are
      * granted.</p>
      */
-    inline const Aws::String& GetGranteeId() const{ return m_granteeId; }
+    inline const Aws::String& GetGranteeId() const { return m_granteeId; }
     inline bool GranteeIdHasBeenSet() const { return m_granteeIdHasBeenSet; }
-    inline void SetGranteeId(const Aws::String& value) { m_granteeIdHasBeenSet = true; m_granteeId = value; }
-    inline void SetGranteeId(Aws::String&& value) { m_granteeIdHasBeenSet = true; m_granteeId = std::move(value); }
-    inline void SetGranteeId(const char* value) { m_granteeIdHasBeenSet = true; m_granteeId.assign(value); }
-    inline Permission& WithGranteeId(const Aws::String& value) { SetGranteeId(value); return *this;}
-    inline Permission& WithGranteeId(Aws::String&& value) { SetGranteeId(std::move(value)); return *this;}
-    inline Permission& WithGranteeId(const char* value) { SetGranteeId(value); return *this;}
+    template<typename GranteeIdT = Aws::String>
+    void SetGranteeId(GranteeIdT&& value) { m_granteeIdHasBeenSet = true; m_granteeId = std::forward<GranteeIdT>(value); }
+    template<typename GranteeIdT = Aws::String>
+    Permission& WithGranteeId(GranteeIdT&& value) { SetGranteeId(std::forward<GranteeIdT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The type of user, group, or resource referred to in GranteeId.</p>
      */
-    inline const MemberType& GetGranteeType() const{ return m_granteeType; }
+    inline MemberType GetGranteeType() const { return m_granteeType; }
     inline bool GranteeTypeHasBeenSet() const { return m_granteeTypeHasBeenSet; }
-    inline void SetGranteeType(const MemberType& value) { m_granteeTypeHasBeenSet = true; m_granteeType = value; }
-    inline void SetGranteeType(MemberType&& value) { m_granteeTypeHasBeenSet = true; m_granteeType = std::move(value); }
-    inline Permission& WithGranteeType(const MemberType& value) { SetGranteeType(value); return *this;}
-    inline Permission& WithGranteeType(MemberType&& value) { SetGranteeType(std::move(value)); return *this;}
+    inline void SetGranteeType(MemberType value) { m_granteeTypeHasBeenSet = true; m_granteeType = value; }
+    inline Permission& WithGranteeType(MemberType value) { SetGranteeType(value); return *this;}
     ///@}
 
     ///@{
@@ -77,21 +73,20 @@ namespace Model
      * emails). FULL_ACCESS allows the grantee full access to the mailbox, irrespective
      * of other folder-level permissions set on the mailbox.</p>
      */
-    inline const Aws::Vector<PermissionType>& GetPermissionValues() const{ return m_permissionValues; }
+    inline const Aws::Vector<PermissionType>& GetPermissionValues() const { return m_permissionValues; }
     inline bool PermissionValuesHasBeenSet() const { return m_permissionValuesHasBeenSet; }
-    inline void SetPermissionValues(const Aws::Vector<PermissionType>& value) { m_permissionValuesHasBeenSet = true; m_permissionValues = value; }
-    inline void SetPermissionValues(Aws::Vector<PermissionType>&& value) { m_permissionValuesHasBeenSet = true; m_permissionValues = std::move(value); }
-    inline Permission& WithPermissionValues(const Aws::Vector<PermissionType>& value) { SetPermissionValues(value); return *this;}
-    inline Permission& WithPermissionValues(Aws::Vector<PermissionType>&& value) { SetPermissionValues(std::move(value)); return *this;}
-    inline Permission& AddPermissionValues(const PermissionType& value) { m_permissionValuesHasBeenSet = true; m_permissionValues.push_back(value); return *this; }
-    inline Permission& AddPermissionValues(PermissionType&& value) { m_permissionValuesHasBeenSet = true; m_permissionValues.push_back(std::move(value)); return *this; }
+    template<typename PermissionValuesT = Aws::Vector<PermissionType>>
+    void SetPermissionValues(PermissionValuesT&& value) { m_permissionValuesHasBeenSet = true; m_permissionValues = std::forward<PermissionValuesT>(value); }
+    template<typename PermissionValuesT = Aws::Vector<PermissionType>>
+    Permission& WithPermissionValues(PermissionValuesT&& value) { SetPermissionValues(std::forward<PermissionValuesT>(value)); return *this;}
+    inline Permission& AddPermissionValues(PermissionType value) { m_permissionValuesHasBeenSet = true; m_permissionValues.push_back(value); return *this; }
     ///@}
   private:
 
     Aws::String m_granteeId;
     bool m_granteeIdHasBeenSet = false;
 
-    MemberType m_granteeType;
+    MemberType m_granteeType{MemberType::NOT_SET};
     bool m_granteeTypeHasBeenSet = false;
 
     Aws::Vector<PermissionType> m_permissionValues;
