@@ -84,8 +84,8 @@ namespace Model
     TargetDeviceStatus m_targetDeviceStatus{TargetDeviceStatus::NOT_SET};
     bool m_targetDeviceStatusHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
   };
 
 } // namespace Model
