@@ -138,8 +138,8 @@ namespace Model
     Aws::Map<Aws::String, Aws::String> m_additionalEncryptionContext;
     bool m_additionalEncryptionContextHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
 
     Aws::String m_customerManagedKey;
     bool m_customerManagedKeyHasBeenSet = false;
